@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 
 /**
  * Controller to handle actions relative to categories.
@@ -11,6 +12,7 @@ class FreshRSS_category_Controller extends FreshRSS_ActionController {
 	 * underlying framework.
 	 *
 	 */
+	#[\Override]
 	public function firstAction(): void {
 		if (!FreshRSS_Auth::hasAccess()) {
 			Minz_Error::error(403);
@@ -26,13 +28,13 @@ class FreshRSS_category_Controller extends FreshRSS_ActionController {
 	 * Request parameter is:
 	 *   - new-category
 	 */
-	public function createAction() :void {
+	public function createAction(): void {
 		$catDAO = FreshRSS_Factory::createCategoryDao();
 		$tagDAO = FreshRSS_Factory::createTagDao();
 
 		$url_redirect = ['c' => 'subscription', 'a' => 'add'];
 
-		$limits = FreshRSS_Context::$system_conf->limits;
+		$limits = FreshRSS_Context::systemConf()->limits;
 		$this->view->categories = $catDAO->listCategories(false) ?: [];
 
 		if (count($this->view->categories) >= $limits['max_categories']) {
@@ -60,10 +62,10 @@ class FreshRSS_category_Controller extends FreshRSS_ActionController {
 			$opml_url = checkUrl(Minz_Request::paramString('opml_url'));
 			if ($opml_url != '') {
 				$cat->_kind(FreshRSS_Category::KIND_DYNAMIC_OPML);
-				$cat->_attributes('opml_url', $opml_url);
+				$cat->_attribute('opml_url', $opml_url);
 			} else {
 				$cat->_kind(FreshRSS_Category::KIND_NORMAL);
-				$cat->_attributes('opml_url', null);
+				$cat->_attribute('opml_url', null);
 			}
 
 			if ($catDAO->addCategoryObject($cat)) {
@@ -79,45 +81,80 @@ class FreshRSS_category_Controller extends FreshRSS_ActionController {
 
 	/**
 	 * This action updates the given category.
-	 * @todo Check whether this function is used at all
-	 * @see FreshRSS_subscription_Controller::categoryAction() (consider merging)
-	 *
-	 * Request parameters are:
-	 *   - id
-	 *   - name
 	 */
 	public function updateAction(): void {
-		$catDAO = FreshRSS_Factory::createCategoryDao();
-		$url_redirect = ['c' => 'subscription', 'a' => 'index'];
+		if (Minz_Request::paramBoolean('ajax')) {
+			$this->view->_layout(null);
+		}
+
+		$categoryDAO = FreshRSS_Factory::createCategoryDao();
+
+		$id = Minz_Request::paramInt('id');
+		$category = $categoryDAO->searchById($id);
+		if ($id === 0 || null === $category) {
+			Minz_Error::error(404);
+			return;
+		}
+		$this->view->category = $category;
+
+		FreshRSS_View::prependTitle($category->name() . ' · ' . _t('sub.title') . ' · ');
 
 		if (Minz_Request::isPost()) {
-			invalidateHttpCache();
+			$category->_filtersAction('read', Minz_Request::paramTextToArray('filteractions_read'));
 
-			$id = Minz_Request::paramInt('id');
-			$name = Minz_Request::paramString('name');
-			if (strlen($name) <= 0) {
-				Minz_Request::bad(_t('feedback.sub.category.no_name'), $url_redirect);
+			if (Minz_Request::paramBoolean('use_default_purge_options')) {
+				$category->_attribute('archiving', null);
+			} else {
+				if (!Minz_Request::paramBoolean('enable_keep_max')) {
+					$keepMax = false;
+				} elseif (($keepMax = Minz_Request::paramInt('keep_max')) !== 0) {
+					$keepMax = FreshRSS_Feed::ARCHIVING_RETENTION_COUNT_LIMIT;
+				}
+				if (Minz_Request::paramBoolean('enable_keep_period')) {
+					$keepPeriod = FreshRSS_Feed::ARCHIVING_RETENTION_PERIOD;
+					if (is_numeric(Minz_Request::paramString('keep_period_count')) && preg_match('/^PT?1[YMWDH]$/', Minz_Request::paramString('keep_period_unit'))) {
+						$keepPeriod = str_replace('1', Minz_Request::paramString('keep_period_count'), Minz_Request::paramString('keep_period_unit'));
+					}
+				} else {
+					$keepPeriod = false;
+				}
+				$category->_attribute('archiving', [
+					'keep_period' => $keepPeriod,
+					'keep_max' => $keepMax,
+					'keep_min' => Minz_Request::paramInt('keep_min'),
+					'keep_favourites' => Minz_Request::paramBoolean('keep_favourites'),
+					'keep_labels' => Minz_Request::paramBoolean('keep_labels'),
+					'keep_unreads' => Minz_Request::paramBoolean('keep_unreads'),
+				]);
 			}
 
-			$cat = $catDAO->searchById($id);
-			if ($cat === null) {
-				Minz_Request::bad(_t('feedback.sub.category.not_exist'), $url_redirect);
+			$position = Minz_Request::paramInt('position') ?: null;
+			$category->_attribute('position', $position);
+
+			$opml_url = checkUrl(Minz_Request::paramString('opml_url'));
+			if ($opml_url != '') {
+				$category->_kind(FreshRSS_Category::KIND_DYNAMIC_OPML);
+				$category->_attribute('opml_url', $opml_url);
+			} else {
+				$category->_kind(FreshRSS_Category::KIND_NORMAL);
+				$category->_attribute('opml_url', null);
 			}
 
 			$values = [
-				'name' => $cat->name(),
-				'kind' => $cat->kind(),
-				'attributes' => $cat->attributes(),
+				'kind' => $category->kind(),
+				'name' => Minz_Request::paramString('name'),
+				'attributes' => $category->attributes(),
 			];
 
-			if ($catDAO->updateCategory($id, $values)) {
+			invalidateHttpCache();
+
+			$url_redirect = ['c' => 'subscription', 'params' => ['id' => $id, 'type' => 'category']];
+			if (false !== $categoryDAO->updateCategory($id, $values)) {
 				Minz_Request::good(_t('feedback.sub.category.updated'), $url_redirect);
 			} else {
 				Minz_Request::bad(_t('feedback.sub.category.error'), $url_redirect);
 			}
 		}
-
-		Minz_Request::forward($url_redirect, true);
 	}
 
 	/**
@@ -154,9 +191,10 @@ class FreshRSS_category_Controller extends FreshRSS_ActionController {
 			}
 
 			// Remove related queries.
-			FreshRSS_Context::$user_conf->queries = remove_query_by_get(
-				'c_' . $id, FreshRSS_Context::$user_conf->queries);
-			FreshRSS_Context::$user_conf->save();
+			/** @var array<array{'get'?:string,'name'?:string,'order'?:string,'search'?:string,'state'?:int,'url'?:string}> $queries */
+			$queries = remove_query_by_get('c_' . $id, FreshRSS_Context::userConf()->queries);
+			FreshRSS_Context::userConf()->queries = $queries;
+			FreshRSS_Context::userConf()->save();
 
 			Minz_Request::good(_t('feedback.sub.category.deleted'), $url_redirect);
 		}
@@ -194,10 +232,11 @@ class FreshRSS_category_Controller extends FreshRSS_ActionController {
 
 				// Remove related queries
 				foreach ($feeds as $feed) {
-					FreshRSS_Context::$user_conf->queries = remove_query_by_get(
-						'f_' . $feed->id(), FreshRSS_Context::$user_conf->queries);
+					/** @var array<array{'get'?:string,'name'?:string,'order'?:string,'search'?:string,'state'?:int,'url'?:string}> */
+					$queries = remove_query_by_get('f_' . $feed->id(), FreshRSS_Context::userConf()->queries);
+					FreshRSS_Context::userConf()->queries = $queries;
 				}
-				FreshRSS_Context::$user_conf->save();
+				FreshRSS_Context::userConf()->save();
 
 				Minz_Request::good(_t('feedback.sub.category.emptied'), $url_redirect);
 			} else {
@@ -222,11 +261,13 @@ class FreshRSS_category_Controller extends FreshRSS_ActionController {
 			$id = Minz_Request::paramInt('id');
 			if ($id === 0) {
 				Minz_Request::bad(_t('feedback.sub.category.no_id'), $url_redirect);
+				return;
 			}
 
 			$category = $catDAO->searchById($id);
 			if ($category === null) {
 				Minz_Request::bad(_t('feedback.sub.category.not_exist'), $url_redirect);
+				return;
 			}
 
 			invalidateHttpCache();
@@ -252,7 +293,7 @@ class FreshRSS_category_Controller extends FreshRSS_ActionController {
 		$successes = 0;
 		$errors = 0;
 		$catDAO = FreshRSS_Factory::createCategoryDao();
-		$categories = $catDAO->listCategoriesOrderUpdate(FreshRSS_Context::$user_conf->dynamic_opml_ttl_default ?? 86400);
+		$categories = $catDAO->listCategoriesOrderUpdate(FreshRSS_Context::userConf()->dynamic_opml_ttl_default ?? 86400);
 		foreach ($categories as $category) {
 			if ($category->refreshDynamicOpml()) {
 				$successes++;
