@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 
 /**
  * Controller to handle every feed actions.
@@ -6,19 +7,20 @@
 class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 	/**
 	 * This action is called before every other action in that class. It is
-	 * the common boiler plate for every action. It is triggered by the
+	 * the common boilerplate for every action. It is triggered by the
 	 * underlying framework.
 	 */
+	#[\Override]
 	public function firstAction(): void {
 		if (!FreshRSS_Auth::hasAccess()) {
 			// Token is useful in the case that anonymous refresh is forbidden
 			// and CRON task cannot be used with php command so the user can
 			// set a CRON task to refresh his feeds by using token inside url
-			$token = FreshRSS_Context::$user_conf->token;
+			$token = FreshRSS_Context::userConf()->token;
 			$token_param = Minz_Request::paramString('token');
 			$token_is_ok = ($token != '' && $token == $token_param);
 			$action = Minz_Request::actionName();
-			$allow_anonymous_refresh = FreshRSS_Context::$system_conf->allow_anonymous_refresh;
+			$allow_anonymous_refresh = FreshRSS_Context::systemConf()->allow_anonymous_refresh;
 			if ($action !== 'actualize' ||
 					!($allow_anonymous_refresh || $token_is_ok)) {
 				Minz_Error::error(403);
@@ -29,8 +31,9 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 	/**
 	 * @param array<string,mixed> $attributes
 	 * @throws FreshRSS_AlreadySubscribed_Exception
-	 * @throws FreshRSS_FeedNotAdded_Exception
+	 * @throws FreshRSS_BadUrl_Exception
 	 * @throws FreshRSS_Feed_Exception
+	 * @throws FreshRSS_FeedNotAdded_Exception
 	 * @throws Minz_FileNotExistException
 	 */
 	public static function addFeed(string $url, string $title = '', int $cat_id = 0, string $new_cat_name = '',
@@ -44,7 +47,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 
 		$url = trim($url);
 
-		/** @var string|null $url */
+		/** @var string|null $urlHooked */
 		$urlHooked = Minz_ExtensionManager::callHook('check_url_before_add', $url);
 		if ($urlHooked === null) {
 			throw new FreshRSS_FeedNotAdded_Exception($url);
@@ -63,7 +66,6 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 		if ($cat === null) {
 			$catDAO->checkDefault();
 		}
-		$cat_id = $cat === null ? FreshRSS_CategoryDAO::DEFAULTCATEGORYID : $cat->id();
 
 		$feed = new FreshRSS_Feed($url);	//Throws FreshRSS_BadUrl_Exception
 		$title = trim($title);
@@ -71,9 +73,13 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 			$feed->_name($title);
 		}
 		$feed->_kind($kind);
-		$feed->_attributes('', $attributes);
+		$feed->_attributes($attributes);
 		$feed->_httpAuth($http_auth);
-		$feed->_categoryId($cat_id);
+		if ($cat === null) {
+			$feed->_categoryId(FreshRSS_CategoryDAO::DEFAULTCATEGORYID);
+		} else {
+			$feed->_category($cat);
+		}
 		switch ($kind) {
 			case FreshRSS_Feed::KIND_RSS:
 			case FreshRSS_Feed::KIND_RSS_FORCED:
@@ -104,8 +110,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 		$feed->_id($id);
 
 		// Ok, feed has been added in database. Now we have to refresh entries.
-		self::actualizeFeed($id, $url, false, null);
-
+		self::actualizeFeedsAndCommit($id, $url);
 		return $feed;
 	}
 
@@ -147,7 +152,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 			'params' => [],
 		];
 
-		$limits = FreshRSS_Context::$system_conf->limits;
+		$limits = FreshRSS_Context::systemConf()->limits;
 		$this->view->feeds = $feedDAO->listFeeds();
 		if (count($this->view->feeds) >= $limits['max_feeds']) {
 			Minz_Request::bad(_t('feedback.sub.feed.over_max', $limits['max_feeds']), $url_redirect);
@@ -171,6 +176,9 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 			$useragent = Minz_Request::paramString('curl_params_useragent');
 			$proxy_address = Minz_Request::paramString('curl_params');
 			$proxy_type = Minz_Request::paramString('proxy_type');
+			$request_method = Minz_Request::paramString('curl_method');
+			$request_fields = Minz_Request::paramString('curl_fields', true);
+
 			$opts = [];
 			if ($proxy_type !== '') {
 				$opts[CURLOPT_PROXY] = $proxy_address;
@@ -191,6 +199,15 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 			if ($useragent !== '') {
 				$opts[CURLOPT_USERAGENT] = $useragent;
 			}
+			if ($request_method === 'POST') {
+				$opts[CURLOPT_POST] = true;
+				if ($request_fields !== '') {
+					$opts[CURLOPT_POSTFIELDS] = $request_fields;
+					if (json_decode($request_fields, true) !== null) {
+						$opts[CURLOPT_HTTPHEADER] = ['Content-Type: application/json'];
+					}
+				}
+			}
 
 			$attributes = [
 				'curl_params' => empty($opts) ? null : $opts,
@@ -238,6 +255,44 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 				if (!empty($xPathSettings)) {
 					$attributes['xpath'] = $xPathSettings;
 				}
+			} elseif ($feed_kind === FreshRSS_Feed::KIND_JSON_DOTNOTATION) {
+				$jsonSettings = [];
+				if (Minz_Request::paramString('jsonFeedTitle') !== '') {
+					$jsonSettings['feedTitle'] = Minz_Request::paramString('jsonFeedTitle', true);
+				}
+				if (Minz_Request::paramString('jsonItem') !== '') {
+					$jsonSettings['item'] = Minz_Request::paramString('jsonItem', true);
+				}
+				if (Minz_Request::paramString('jsonItemTitle') !== '') {
+					$jsonSettings['itemTitle'] = Minz_Request::paramString('jsonItemTitle', true);
+				}
+				if (Minz_Request::paramString('jsonItemContent') !== '') {
+					$jsonSettings['itemContent'] = Minz_Request::paramString('jsonItemContent', true);
+				}
+				if (Minz_Request::paramString('jsonItemUri') !== '') {
+					$jsonSettings['itemUri'] = Minz_Request::paramString('jsonItemUri', true);
+				}
+				if (Minz_Request::paramString('jsonItemAuthor') !== '') {
+					$jsonSettings['itemAuthor'] = Minz_Request::paramString('jsonItemAuthor', true);
+				}
+				if (Minz_Request::paramString('jsonItemTimestamp') !== '') {
+					$jsonSettings['itemTimestamp'] = Minz_Request::paramString('jsonItemTimestamp', true);
+				}
+				if (Minz_Request::paramString('jsonItemTimeFormat') !== '') {
+					$jsonSettings['itemTimeFormat'] = Minz_Request::paramString('jsonItemTimeFormat', true);
+				}
+				if (Minz_Request::paramString('jsonItemThumbnail') !== '') {
+					$jsonSettings['itemThumbnail'] = Minz_Request::paramString('jsonItemThumbnail', true);
+				}
+				if (Minz_Request::paramString('jsonItemCategories') !== '') {
+					$jsonSettings['itemCategories'] = Minz_Request::paramString('jsonItemCategories', true);
+				}
+				if (Minz_Request::paramString('jsonItemUid') !== '') {
+					$jsonSettings['itemUid'] = Minz_Request::paramString('jsonItemUid', true);
+				}
+				if (!empty($jsonSettings)) {
+					$attributes['json_dotnotation'] = $jsonSettings;
+				}
 			}
 
 			try {
@@ -326,73 +381,91 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 	}
 
 	/**
-	 * @return array{0:int,1:FreshRSS_Feed|false,2:int}
+	 * @return array{0:int,1:FreshRSS_Feed|null,2:int,3:array<FreshRSS_Feed>} Number of updated feeds, first feed or null, number of new articles,
+	 * 	list of feeds for which a cache refresh is needed
 	 * @throws FreshRSS_BadUrl_Exception
 	 */
-	public static function actualizeFeed(int $feed_id, string $feed_url, bool $force, ?SimplePie $simplePiePush = null,
-		bool $noCommit = false, int $maxFeeds = 10): array {
+	public static function actualizeFeeds(?int $feed_id = null, ?string $feed_url = null, ?int $maxFeeds = null, ?SimplePie $simplePiePush = null): array {
 		if (function_exists('set_time_limit')) {
 			@set_time_limit(300);
 		}
 
+		if (!is_int($feed_id) || $feed_id <= 0) {
+			$feed_id = null;
+		}
+		if (!is_string($feed_url) || trim($feed_url) === '') {
+			$feed_url = null;
+		}
+		if (!is_int($maxFeeds) || $maxFeeds <= 0) {
+			$maxFeeds = PHP_INT_MAX;
+		}
+
 		$feedDAO = FreshRSS_Factory::createFeedDao();
 		$entryDAO = FreshRSS_Factory::createEntryDao();
 
 		// Create a list of feeds to actualize.
-		// If feed_id is set and valid, corresponding feed is added to the list but
-		// alone in order to automatize further process.
 		$feeds = [];
-		if ($feed_id > 0 || $feed_url) {
-			$feed = $feed_id > 0 ? $feedDAO->searchById($feed_id) : $feedDAO->searchByUrl($feed_url);
-			if ($feed) {
+		if ($feed_id !== null || $feed_url !== null) {
+			$feed = $feed_id !== null ? $feedDAO->searchById($feed_id) : $feedDAO->searchByUrl($feed_url);
+			if ($feed !== null && $feed->id() > 0) {
 				$feeds[] = $feed;
+				$feed_id = $feed->id();
 			}
 		} else {
 			$feeds = $feedDAO->listFeedsOrderUpdate(-1);
-		}
 
-		// Set maxFeeds to a minimum of 10
-		if ($maxFeeds < 10) {
-			$maxFeeds = 10;
+			// Hydrate category for each feed to avoid that each feed has to make an SQL request
+			$categories = [];
+			$catDAO = FreshRSS_Factory::createCategoryDao();
+			foreach ($catDAO->listCategories(false, false) as $category) {
+				$categories[$category->id()] = $category;
+			}
+			foreach ($feeds as $feed) {
+				$category = $categories[$feed->categoryId()] ?? null;
+				if ($category !== null) {
+					$feed->_category($category);
+				}
+			}
 		}
 
 		// WebSub (PubSubHubbub) support
-		$pubsubhubbubEnabledGeneral = FreshRSS_Context::$system_conf->pubsubhubbub_enabled;
+		$pubsubhubbubEnabledGeneral = FreshRSS_Context::systemConf()->pubsubhubbub_enabled;
 		$pshbMinAge = time() - (3600 * 24);  //TODO: Make a configuration.
 
-		$updated_feeds = 0;
-		$nb_new_articles = 0;
+		$nbUpdatedFeeds = 0;
+		$nbNewArticles = 0;
+		$feedsCacheToRefresh = [];
+
 		foreach ($feeds as $feed) {
-			/** @var FreshRSS_Feed|null $feed */
 			$feed = Minz_ExtensionManager::callHook('feed_before_actualize', $feed);
-			if (null === $feed) {
+			if (!($feed instanceof FreshRSS_Feed)) {
 				continue;
 			}
 
 			$url = $feed->url();	//For detection of HTTP 301
 
 			$pubSubHubbubEnabled = $pubsubhubbubEnabledGeneral && $feed->pubSubHubbubEnabled();
-			if ($simplePiePush === null && $feed_id === 0 && $pubSubHubbubEnabled && ($feed->lastUpdate() > $pshbMinAge)) {
+			if ($simplePiePush === null && $feed_id === null && $pubSubHubbubEnabled && ($feed->lastUpdate() > $pshbMinAge)) {
 				//$text = 'Skip pull of feed using PubSubHubbub: ' . $url;
 				//Minz_Log::debug($text);
 				//Minz_Log::debug($text, PSHB_LOG);
 				continue;	//When PubSubHubbub is used, do not pull refresh so often
 			}
 
-			if ($feed->mute()) {
-				continue;	//Feed refresh is disabled
+			if ($feed->mute() && ($feed_id === null || $simplePiePush !== null)) {
+				continue;	// If the feed is disabled, only allow refresh if manually requested for that specific feed
 			}
 			$mtime = $feed->cacheModifiedTime() ?: 0;
 			$ttl = $feed->ttl();
 			if ($ttl === FreshRSS_Feed::TTL_DEFAULT) {
-				$ttl = FreshRSS_Context::$user_conf->ttl_default;
+				$ttl = FreshRSS_Context::userConf()->ttl_default;
 			}
-			if ($simplePiePush === null && $feed_id === 0 && (time() <= $feed->lastUpdate() + $ttl)) {
+			if ($simplePiePush === null && $feed_id === null && (time() <= $feed->lastUpdate() + $ttl)) {
 				//Too early to refresh from source, but check whether the feed was updated by another user
 				$ε = 10;	// negligible offset errors in seconds
 				if ($mtime <= 0 ||
 					$feed->lastUpdate() + $ε >= $mtime ||
-					time() + $ε >= $mtime + FreshRSS_Context::$system_conf->limits['cache_duration']) {	// is cache still valid?
+					time() + $ε >= $mtime + FreshRSS_Context::systemConf()->limits['cache_duration']) {	// is cache still valid?
 					continue;	//Nothing newer from other users
 				}
 				Minz_Log::debug('Feed ' . $feed->url(false) . ' was updated at ' . date('c', $feed->lastUpdate()) .
@@ -405,8 +478,6 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 			}
 
 			$feedIsNew = $feed->lastUpdate() <= 0;
-			$feedIsEmpty = false;
-			$feedIsUnchanged = false;
 
 			try {
 				if ($simplePiePush !== null) {
@@ -421,6 +492,16 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 					if ($simplePie === null) {
 						throw new FreshRSS_Feed_Exception('XML+XPath parsing failed for [' . $feed->url(false) . ']');
 					}
+				} elseif ($feed->kind() === FreshRSS_Feed::KIND_JSON_DOTNOTATION) {
+					$simplePie = $feed->loadJson();
+					if ($simplePie === null) {
+						throw new FreshRSS_Feed_Exception('JSON dot notation parsing failed for [' . $feed->url(false) . ']');
+					}
+				} elseif ($feed->kind() === FreshRSS_Feed::KIND_JSONFEED) {
+					$simplePie = $feed->loadJson();
+					if ($simplePie === null) {
+						throw new FreshRSS_Feed_Exception('JSON Feed parsing failed for [' . $feed->url(false) . ']');
+					}
 				} else {
 					$simplePie = $feed->load(false, $feedIsNew);
 				}
@@ -434,7 +515,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 				} else {
 					$newGuids = $feed->loadGuids($simplePie);
 					$entries = $feed->loadEntries($simplePie);
-					$feedIsEmpty = $simplePiePush !== null && empty($newGuids);
+					$feedIsEmpty = $simplePiePush === null && empty($newGuids);
 					$feedIsUnchanged = false;
 				}
 				$mtime = $feed->cacheModifiedTime() ?: time();
@@ -451,19 +532,23 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 			}
 
 			$needFeedCacheRefresh = false;
+			$nbMarkedUnread = 0;
 
 			if (count($newGuids) > 0) {
-				$titlesAsRead = [];
-				$readWhenSameTitleInFeed = $feed->attributes('read_when_same_title_in_feed');
-				if ($readWhenSameTitleInFeed == false) {
-					$readWhenSameTitleInFeed = FreshRSS_Context::$user_conf->mark_when['same_title_in_feed'];
+				if (!$feed->hasAttribute('read_when_same_title_in_feed')) {
+					$readWhenSameTitleInFeed = (int)FreshRSS_Context::userConf()->mark_when['same_title_in_feed'];
+				} elseif ($feed->attributeBoolean('read_when_same_title_in_feed') === false) {
+					$readWhenSameTitleInFeed = 0;
+				} else {
+					$readWhenSameTitleInFeed = $feed->attributeInt('read_when_same_title_in_feed') ?? 0;
 				}
 				if ($readWhenSameTitleInFeed > 0) {
-					/** @var array<string,bool> $titlesAsRead*/
-					$titlesAsRead = array_flip($feedDAO->listTitles($feed->id(), (int)$readWhenSameTitleInFeed));
+					$titlesAsRead = array_fill_keys($feedDAO->listTitles($feed->id(), $readWhenSameTitleInFeed), true);
+				} else {
+					$titlesAsRead = [];
 				}
 
-				$mark_updated_article_unread = $feed->attributes('mark_updated_article_unread') ?? FreshRSS_Context::$user_conf->mark_updated_article_unread;
+				$mark_updated_article_unread = $feed->attributeBoolean('mark_updated_article_unread') ?? FreshRSS_Context::userConf()->mark_updated_article_unread;
 
 				// For this feed, check existing GUIDs already in database.
 				$existingHashForGuids = $entryDAO->listHashForFeedGuids($feed->id(), $newGuids) ?: [];
@@ -483,6 +568,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 						$existingHash = $existingHashForGuids[$entry->guid()];
 						if (strcasecmp($existingHash, $entry->hash()) !== 0) {
 							//This entry already exists but has been updated
+							$entry->_isUpdated(true);
 							//Minz_Log::debug('Entry with GUID `' . $entry->guid() . '` updated in feed ' . $feed->url(false) .
 								//', old hash ' . $existingHash . ', new hash ' . $entry->hash());
 							$entry->_isFavorite(null);	// Do not change favourite state
@@ -497,26 +583,26 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 								continue;
 							}
 
+							// NB: Do not mark updated articles as read based on their title, as the duplicate title maybe be from the same article.
+							$entry->applyFilterActions([]);
+							if ($readWhenSameTitleInFeed > 0) {
+								$titlesAsRead[$entry->title()] = true;
+							}
+
 							if (!$entry->isRead()) {
-								$needFeedCacheRefresh = true;
-								$feed->incPendingUnread();	//Maybe
+								$needFeedCacheRefresh = true;	//Maybe
+								$nbMarkedUnread++;
 							}
 
 							// If the entry has changed, there is a good chance for the full content to have changed as well.
 							$entry->loadCompleteContent(true);
 
-							if (!$entryDAO->inTransaction()) {
-								$entryDAO->beginTransaction();
-							}
 							$entryDAO->updateEntry($entry->toArray());
 						}
 					} else {
+						$entry->_isUpdated(false);
 						$id = uTimeString();
 						$entry->_id($id);
-						$entry->applyFilterActions($titlesAsRead);
-						if ($readWhenSameTitleInFeed > 0) {
-							$titlesAsRead[$entry->title()] = true;
-						}
 
 						$entry = Minz_ExtensionManager::callHook('entry_before_insert', $entry);
 						if (!($entry instanceof FreshRSS_Entry)) {
@@ -524,6 +610,13 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 							continue;
 						}
 
+						$entry->applyFilterActions($titlesAsRead);
+						if ($readWhenSameTitleInFeed > 0) {
+							$titlesAsRead[$entry->title()] = true;
+						}
+
+						$needFeedCacheRefresh = true;
+
 						if ($pubSubHubbubEnabled && !$simplePiePush) {	//We use push, but have discovered an article by pull!
 							$text = 'An article was discovered by pull although we use PubSubHubbub!: Feed ' .
 								SimplePie_Misc::url_remove_credentials($url) .
@@ -534,32 +627,20 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 							$feed->pubSubHubbubError(true);
 						}
 
-						if (!$entryDAO->inTransaction()) {
-							$entryDAO->beginTransaction();
+						if ($entryDAO->addEntry($entry->toArray(), true)) {
+							$nbNewArticles++;
 						}
-						$entryDAO->addEntry($entry->toArray(), true);
-
-						if (!$entry->isRead()) {
-							$feed->incPendingUnread();
-						}
-						$nb_new_articles++;
 					}
 				}
 				// N.B.: Applies to _entry table and not _entrytmp:
 				$entryDAO->updateLastSeen($feed->id(), array_keys($newGuids), $mtime);
 			} elseif ($feedIsUnchanged) {
 				// Feed cache was unchanged, so mark as seen the same entries as last time
-				if (!$entryDAO->inTransaction()) {
-					$entryDAO->beginTransaction();
-				}
 				$entryDAO->updateLastSeenUnchanged($feed->id(), $mtime);
 			}
 			unset($entries);
 
 			if (rand(0, 30) === 1) {	// Remove old entries once in 30.
-				if (!$entryDAO->inTransaction()) {
-					$entryDAO->beginTransaction();
-				}
 				$nb = $feed->cleanOldEntries();
 				if ($nb > 0) {
 					$needFeedCacheRefresh = true;
@@ -567,16 +648,12 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 			}
 
 			$feedDAO->updateLastUpdate($feed->id(), false, $mtime);
-			$needFeedCacheRefresh |= ($feed->keepMaxUnread() != false);
 			if ($simplePiePush === null) {
 				// Do not call for WebSub events, as we do not know the list of articles still on the upstream feed.
 				$needFeedCacheRefresh |= ($feed->markAsReadUponGone($feedIsEmpty, $mtime) != false);
 			}
 			if ($needFeedCacheRefresh) {
-				$feedDAO->updateCachedValues($feed->id());
-			}
-			if ($entryDAO->inTransaction()) {
-				$entryDAO->commit();
+				$feedsCacheToRefresh[] = $feed;
 			}
 
 			$feedProperties = [];
@@ -639,66 +716,164 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 				}
 			}
 			$feed->unlock();
-			$updated_feeds++;
+			$nbUpdatedFeeds++;
 			unset($feed);
 			gc_collect_cycles();
 
-			// No more than $maxFeeds feeds unless $force is true to avoid overloading
-			// the server.
-			if ($updated_feeds >= $maxFeeds && !$force) {
+			if ($nbUpdatedFeeds >= $maxFeeds) {
 				break;
 			}
 		}
-		if (!$noCommit && ($nb_new_articles > 0 || $updated_feeds > 0)) {
-			if (!$entryDAO->inTransaction()) {
-				$entryDAO->beginTransaction();
-			}
-			$entryDAO->commitNewEntries();
-			$feedDAO->updateCachedValues();
-			if ($entryDAO->inTransaction()) {
-				$entryDAO->commit();
-			}
+		return [$nbUpdatedFeeds, reset($feeds) ?: null, $nbNewArticles, $feedsCacheToRefresh];
+	}
 
-			$databaseDAO = FreshRSS_Factory::createDatabaseDAO();
-			$databaseDAO->minorDbMaintenance();
+	/**
+	 * Feeds on which to apply a the keep max unreads policy, or all feeds if none specified.
+	 * @return int The number of articles marked as read
+	 */
+	private static function keepMaxUnreads(FreshRSS_Feed ...$feeds): int {
+		$affected = 0;
+
+		if (empty($feeds)) {
+			$feedDAO = FreshRSS_Factory::createFeedDao();
+			$feeds = $feedDAO->listFeedsOrderUpdate(-1);
 		}
-		return [$updated_feeds, reset($feeds), $nb_new_articles];
+
+		foreach ($feeds as $feed) {
+			$n = $feed->markAsReadMaxUnread();
+			if ($n !== false && $n > 0) {
+				Minz_Log::debug($n . ' unread entries exceeding max number of ' . $feed->keepMaxUnread() .  ' for [' . $feed->url(false) . ']');
+				$affected += $n;
+			}
+		}
+
+		return $affected;
+	}
+
+	/**
+	 * Auto-add labels to new articles.
+	 * @param int $nbNewEntries The number of top recent entries to process.
+	 * @return int|false The number of new labels added, or false in case of error.
+	 */
+	private static function applyLabelActions(int $nbNewEntries) {
+		$tagDAO = FreshRSS_Factory::createTagDao();
+		$labels = FreshRSS_Context::labels();
+		$labels = array_filter($labels, static function (FreshRSS_Tag $label) {
+			return !empty($label->filtersAction('label'));
+		});
+		if (count($labels) <= 0) {
+			return 0;
+		}
+
+		$entryDAO = FreshRSS_Factory::createEntryDao();
+		/** @var array<array{id_tag:int,id_entry:string}> $applyLabels */
+		$applyLabels = [];
+		foreach (FreshRSS_Entry::fromTraversable($entryDAO->selectAll($nbNewEntries)) as $entry) {
+			foreach ($labels as $label) {
+				$label->applyFilterActions($entry, $applyLabel);
+				if ($applyLabel) {
+					$applyLabels[] = [
+						'id_tag' => $label->id(),
+						'id_entry' => $entry->id(),
+					];
+				}
+			}
+		}
+		return $tagDAO->tagEntries($applyLabels);
+	}
+
+	public static function commitNewEntries(): int {
+		$entryDAO = FreshRSS_Factory::createEntryDao();
+		$nbNewEntries = $entryDAO->countNewEntries();
+		if ($nbNewEntries > 0) {
+			if ($entryDAO->commitNewEntries()) {
+				self::applyLabelActions($nbNewEntries);
+			}
+		}
+		return $nbNewEntries;
+	}
+
+	/**
+	 * @return array{0:int,1:FreshRSS_Feed|null,2:int,3:array<FreshRSS_Feed>} Number of updated feeds, first feed or null, number of new articles,
+	 * 	list of feeds for which a cache refresh is needed
+	 * @throws FreshRSS_BadUrl_Exception
+	 */
+	public static function actualizeFeedsAndCommit(?int $feed_id = null, ?string $feed_url = null, ?int $maxFeeds = null, ?SimplePie $simplePiePush = null): array {
+		$entryDAO = FreshRSS_Factory::createEntryDao();
+		[$nbUpdatedFeeds, $feed, $nbNewArticles, $feedsCacheToRefresh] = FreshRSS_feed_Controller::actualizeFeeds($feed_id, $feed_url, $maxFeeds, $simplePiePush);
+		if ($nbNewArticles > 0) {
+			$entryDAO->beginTransaction();
+			FreshRSS_feed_Controller::commitNewEntries();
+		}
+		if (count($feedsCacheToRefresh) > 0) {
+			$feedDAO = FreshRSS_Factory::createFeedDao();
+			self::keepMaxUnreads(...$feedsCacheToRefresh);
+			$feedDAO->updateCachedValues(...array_map(fn(FreshRSS_Feed $f) => $f->id(), $feedsCacheToRefresh));
+		}
+		if ($entryDAO->inTransaction()) {
+			$entryDAO->commit();
+		}
+		return [$nbUpdatedFeeds, $feed, $nbNewArticles, $feedsCacheToRefresh];
 	}
 
 	/**
 	 * This action actualizes entries from one or several feeds.
 	 *
 	 * Parameters are:
-	 *   - id (default: false): Feed ID
-	 *   - url (default: false): Feed URL
-	 *   - force (default: false)
+	 *   - id (default: null): Feed ID, or set to -1 to commit new articles to the main database
+	 *   - url (default: null): Feed URL (instead of feed ID)
+	 *   - maxFeeds (default: 10): Max number of feeds to refresh
 	 *   - noCommit (default: 0): Set to 1 to prevent committing the new articles to the main database
-	 * If id and url are not specified, all the feeds are actualized. But if force is
-	 * false, process stops at 10 feeds to avoid time execution problem.
+	 * If id and url are not specified, all the feeds are actualized, within the limits of maxFeeds.
 	 */
 	public function actualizeAction(): int {
 		Minz_Session::_param('actualize_feeds', false);
 		$id = Minz_Request::paramInt('id');
 		$url = Minz_Request::paramString('url');
-		$force = Minz_Request::paramBoolean('force');
-		$maxFeeds = Minz_Request::paramInt('maxFeeds');
+		$maxFeeds = Minz_Request::paramInt('maxFeeds') ?: 10;
 		$noCommit = ($_POST['noCommit'] ?? 0) == 1;
-		$feed = null;
 
-		if ($id == -1 && !$noCommit) {	//Special request only to commit & refresh DB cache
-			$updated_feeds = 0;
-			$entryDAO = FreshRSS_Factory::createEntryDao();
+		if ($id === -1 && !$noCommit) {	//Special request only to commit & refresh DB cache
+			$nbUpdatedFeeds = 0;
+			$feed = null;
+			FreshRSS_feed_Controller::commitNewEntries();
 			$feedDAO = FreshRSS_Factory::createFeedDao();
-			$entryDAO->beginTransaction();
-			$entryDAO->commitNewEntries();
 			$feedDAO->updateCachedValues();
-			$entryDAO->commit();
-
-			$databaseDAO = FreshRSS_Factory::createDatabaseDAO();
-			$databaseDAO->minorDbMaintenance();
 		} else {
-			FreshRSS_category_Controller::refreshDynamicOpmls();
-			[$updated_feeds, $feed] = self::actualizeFeed($id, $url, $force, null, $noCommit, $maxFeeds);
+			if ($id === 0 && $url === '') {
+				// Case of a batch refresh (e.g. cron)
+				$databaseDAO = FreshRSS_Factory::createDatabaseDAO();
+				$databaseDAO->minorDbMaintenance();
+				Minz_ExtensionManager::callHookVoid('freshrss_user_maintenance');
+
+				FreshRSS_feed_Controller::commitNewEntries();
+				$feedDAO = FreshRSS_Factory::createFeedDao();
+				$feedDAO->updateCachedValues();
+				FreshRSS_category_Controller::refreshDynamicOpmls();
+			}
+			$entryDAO = FreshRSS_Factory::createEntryDao();
+			[$nbUpdatedFeeds, $feed, $nbNewArticles, $feedsCacheToRefresh] = self::actualizeFeeds($id, $url, $maxFeeds);
+			if (!$noCommit) {
+				if ($nbNewArticles > 0) {
+					$entryDAO->beginTransaction();
+					FreshRSS_feed_Controller::commitNewEntries();
+				}
+				$feedDAO = FreshRSS_Factory::createFeedDao();
+				if ($id !== 0 && $id !== -1) {
+					if ($feed instanceof FreshRSS_Feed) {
+						self::keepMaxUnreads($feed);
+					}
+					// Case of single feed refreshed, always update its cache
+					$feedDAO->updateCachedValues($id);
+				} elseif (count($feedsCacheToRefresh) > 0) {
+					self::keepMaxUnreads(...$feedsCacheToRefresh);
+					// Case of multiple feeds refreshed, only update cache of affected feeds
+					$feedDAO->updateCachedValues(...array_map(fn(FreshRSS_Feed $f) => $f->id(), $feedsCacheToRefresh));
+				}
+			}
+			if ($entryDAO->inTransaction()) {
+				$entryDAO->commit();
+			}
 		}
 
 		if (Minz_Request::paramBoolean('ajax')) {
@@ -710,22 +885,19 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 			$this->view->_layout(null);
 		} elseif ($feed instanceof FreshRSS_Feed) {
 			// Redirect to the main page with correct notification.
-			if ($updated_feeds === 1) {
-				Minz_Request::good(_t('feedback.sub.feed.actualized', $feed->name()), [
-					'params' => ['get' => 'f_' . $feed->id()]
-				]);
-			} elseif ($updated_feeds > 1) {
-				Minz_Request::good(_t('feedback.sub.feed.n_actualized', $updated_feeds), []);
-			} else {
-				Minz_Request::good(_t('feedback.sub.feed.no_refresh'), []);
-			}
+			Minz_Request::good(_t('feedback.sub.feed.actualized', $feed->name()), [
+				'params' => ['get' => 'f_' . $id]
+			]);
+		} elseif ($nbUpdatedFeeds >= 1) {
+			Minz_Request::good(_t('feedback.sub.feed.n_actualized', $nbUpdatedFeeds), []);
+		} else {
+			Minz_Request::good(_t('feedback.sub.feed.no_refresh'), []);
 		}
-		return $updated_feeds;
+		return $nbUpdatedFeeds;
 	}
 
 	/**
 	 * @throws Minz_ConfigurationNamespaceException
-	 * @throws JsonException
 	 * @throws Minz_PDOConnectionException
 	 */
 	public static function renameFeed(int $feed_id, string $feed_name): bool {
@@ -797,10 +969,10 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 			// TODO: Delete old favicon
 
 			// Remove related queries
-			FreshRSS_Context::$user_conf->queries = remove_query_by_get(
-				'f_' . $feed_id, FreshRSS_Context::$user_conf->queries);
-			FreshRSS_Context::$user_conf->save();
-
+			/** @var array<array{'get'?:string,'name'?:string,'order'?:string,'search'?:string,'state'?:int,'url'?:string}> $queries */
+			$queries = remove_query_by_get('f_' . $feed_id, FreshRSS_Context::userConf()->queries);
+			FreshRSS_Context::userConf()->queries = $queries;
+			FreshRSS_Context::userConf()->save();
 			return true;
 		}
 		return false;
@@ -888,8 +1060,6 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 		$limit = Minz_Request::paramInt('reload_limit') ?: 10;
 
 		$feedDAO = FreshRSS_Factory::createFeedDao();
-		$entryDAO = FreshRSS_Factory::createEntryDao();
-
 		$feed = $feedDAO->searchById($feed_id);
 		if ($feed === null) {
 			Minz_Request::bad(_t('feedback.sub.feed.not_found'), []);
@@ -898,14 +1068,15 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 
 		//Re-fetch articles as if the feed was new.
 		$feedDAO->updateFeed($feed->id(), [ 'lastUpdate' => 0 ]);
-		self::actualizeFeed($feed_id, '', false);
+		self::actualizeFeedsAndCommit($feed_id);
 
 		//Extract all feed entries from database, load complete content and store them back in database.
+		$entryDAO = FreshRSS_Factory::createEntryDao();
 		$entries = $entryDAO->listWhere('f', $feed_id, FreshRSS_Entry::STATE_ALL, 'DESC', $limit);
 
 		//We need another DB connection in parallel for unbuffered streaming
 		Minz_ModelPdo::$usesSharedPdo = false;
-		if (FreshRSS_Context::$system_conf->db['type'] === 'mysql') {
+		if (FreshRSS_Context::systemConf()->db['type'] === 'mysql') {
 			// Second parallel connection for unbuffered streaming: MySQL
 			$entryDAO2 = FreshRSS_Factory::createEntryDao();
 		} else {
@@ -956,7 +1127,7 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 		$feed_id = Minz_Request::paramInt('id');
 		$content_selector = Minz_Request::paramString('selector');
 
-		if (!$content_selector) {
+		if ($content_selector === '') {
 			$this->view->fatalError = _t('feedback.sub.feed.selector_preview.selector_empty');
 			return;
 		}
@@ -978,22 +1149,16 @@ class FreshRSS_feed_Controller extends FreshRSS_ActionController {
 
 		//Get feed.
 		$feed = $entry->feed();
-
 		if ($feed === null) {
 			$this->view->fatalError = _t('feedback.sub.feed.selector_preview.no_feed');
 			return;
 		}
-
-		$attributes = $feed->attributes();
-		$attributes['path_entries_filter'] = Minz_Request::paramString('selector_filter', true);
+		$feed->_pathEntries($content_selector);
+		$feed->_attribute('path_entries_filter', Minz_Request::paramString('selector_filter', true));
 
 		//Fetch & select content.
 		try {
-			$fullContent = FreshRSS_Entry::getContentByParsing(
-				htmlspecialchars_decode($entry->link(), ENT_QUOTES),
-				htmlspecialchars_decode($content_selector, ENT_QUOTES),
-				$attributes
-			);
+			$fullContent = $entry->getContentByParsing();
 
 			if ($fullContent != '') {
 				$this->view->selectorSuccess = true;
