@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 
 /**
  * Controller to handle subscription actions.
@@ -9,6 +10,7 @@ class FreshRSS_subscription_Controller extends FreshRSS_ActionController {
 	 * the common boilerplate for every action. It is triggered by the
 	 * underlying framework.
 	 */
+	#[\Override]
 	public function firstAction(): void {
 		if (!FreshRSS_Auth::hasAccess()) {
 			Minz_Error::error(403);
@@ -17,7 +19,6 @@ class FreshRSS_subscription_Controller extends FreshRSS_ActionController {
 		$catDAO = FreshRSS_Factory::createCategoryDao();
 		$catDAO->checkDefault();
 		$this->view->categories = $catDAO->listSortedCategories(false, true) ?: [];
-		$this->view->default_category = $catDAO->getDefault();
 
 		$signalError = false;
 		foreach ($this->view->categories as $cat) {
@@ -59,7 +60,7 @@ class FreshRSS_subscription_Controller extends FreshRSS_ActionController {
 					break;
 				default:
 					$feedDAO = FreshRSS_Factory::createFeedDao();
-					$this->view->feed = $feedDAO->searchById($id);
+					$this->view->feed = $feedDAO->searchById($id) ?? FreshRSS_Feed::default();
 					break;
 			}
 		}
@@ -118,13 +119,13 @@ class FreshRSS_subscription_Controller extends FreshRSS_ActionController {
 			$feed->_ttl(Minz_Request::paramInt('ttl') ?: FreshRSS_Feed::TTL_DEFAULT);
 			$feed->_mute(Minz_Request::paramBoolean('mute'));
 
-			$feed->_attributes('read_upon_gone', Minz_Request::paramTernary('read_upon_gone'));
-			$feed->_attributes('mark_updated_article_unread', Minz_Request::paramTernary('mark_updated_article_unread'));
-			$feed->_attributes('read_upon_reception', Minz_Request::paramTernary('read_upon_reception'));
-			$feed->_attributes('clear_cache', Minz_Request::paramTernary('clear_cache'));
+			$feed->_attribute('read_upon_gone', Minz_Request::paramTernary('read_upon_gone'));
+			$feed->_attribute('mark_updated_article_unread', Minz_Request::paramTernary('mark_updated_article_unread'));
+			$feed->_attribute('read_upon_reception', Minz_Request::paramTernary('read_upon_reception'));
+			$feed->_attribute('clear_cache', Minz_Request::paramTernary('clear_cache'));
 
-			$keep_max_n_unread = Minz_Request::paramInt('keep_max_n_unread');
-			$feed->_attributes('keep_max_n_unread', $keep_max_n_unread > 0 ? $keep_max_n_unread : null);
+			$keep_max_n_unread = Minz_Request::paramTernary('keep_max_n_unread') === true ? Minz_Request::paramInt('keep_max_n_unread') : null;
+			$feed->_attribute('keep_max_n_unread', $keep_max_n_unread >= 0 ? $keep_max_n_unread : null);
 
 			$read_when_same_title_in_feed = Minz_Request::paramString('read_when_same_title_in_feed');
 			if ($read_when_same_title_in_feed === '') {
@@ -135,7 +136,7 @@ class FreshRSS_subscription_Controller extends FreshRSS_ActionController {
 					$read_when_same_title_in_feed = false;
 				}
 			}
-			$feed->_attributes('read_when_same_title_in_feed', $read_when_same_title_in_feed);
+			$feed->_attribute('read_when_same_title_in_feed', $read_when_same_title_in_feed);
 
 			$cookie = Minz_Request::paramString('curl_params_cookie');
 			$cookie_file = Minz_Request::paramBoolean('curl_params_cookiefile');
@@ -143,6 +144,8 @@ class FreshRSS_subscription_Controller extends FreshRSS_ActionController {
 			$useragent = Minz_Request::paramString('curl_params_useragent');
 			$proxy_address = Minz_Request::paramString('curl_params');
 			$proxy_type = Minz_Request::paramString('proxy_type');
+			$request_method = Minz_Request::paramString('curl_method');
+			$request_fields = Minz_Request::paramString('curl_fields', true);
 			$opts = [];
 			if ($proxy_type !== '') {
 				$opts[CURLOPT_PROXY] = $proxy_address;
@@ -163,16 +166,27 @@ class FreshRSS_subscription_Controller extends FreshRSS_ActionController {
 			if ($useragent !== '') {
 				$opts[CURLOPT_USERAGENT] = $useragent;
 			}
-			$feed->_attributes('curl_params', empty($opts) ? null : $opts);
 
-			$feed->_attributes('content_action', Minz_Request::paramString('content_action', true) ?: 'replace');
+			if ($request_method === 'POST') {
+				$opts[CURLOPT_POST] = true;
+				if ($request_fields !== '') {
+					$opts[CURLOPT_POSTFIELDS] = $request_fields;
+					if (json_decode($request_fields, true) !== null) {
+						$opts[CURLOPT_HTTPHEADER] = ['Content-Type: application/json'];
+					}
+				}
+			}
 
-			$feed->_attributes('ssl_verify', Minz_Request::paramTernary('ssl_verify'));
+			$feed->_attribute('curl_params', empty($opts) ? null : $opts);
+
+			$feed->_attribute('content_action', Minz_Request::paramString('content_action', true) ?: 'replace');
+
+			$feed->_attribute('ssl_verify', Minz_Request::paramTernary('ssl_verify'));
 			$timeout = Minz_Request::paramInt('timeout');
-			$feed->_attributes('timeout', $timeout > 0 ? $timeout : null);
+			$feed->_attribute('timeout', $timeout > 0 ? $timeout : null);
 
 			if (Minz_Request::paramBoolean('use_default_purge_options')) {
-				$feed->_attributes('archiving', null);
+				$feed->_attribute('archiving', null);
 			} else {
 				if (Minz_Request::paramBoolean('enable_keep_max')) {
 					$keepMax = Minz_Request::paramInt('keep_max') ?: FreshRSS_Feed::ARCHIVING_RETENTION_COUNT_LIMIT;
@@ -187,7 +201,7 @@ class FreshRSS_subscription_Controller extends FreshRSS_ActionController {
 				} else {
 					$keepPeriod = false;
 				}
-				$feed->_attributes('archiving', [
+				$feed->_attribute('archiving', [
 					'keep_period' => $keepPeriod,
 					'keep_max' => $keepMax,
 					'keep_min' => Minz_Request::paramInt('keep_min'),
@@ -197,7 +211,7 @@ class FreshRSS_subscription_Controller extends FreshRSS_ActionController {
 				]);
 			}
 
-			$feed->_filtersAction('read', preg_split('/[\n\r]+/', Minz_Request::paramString('filteractions_read')) ?: []);
+			$feed->_filtersAction('read', Minz_Request::paramTextToArray('filteractions_read'));
 
 			$feed->_kind(Minz_Request::paramInt('feed_kind') ?: FreshRSS_Feed::KIND_RSS);
 			if ($feed->kind() === FreshRSS_Feed::KIND_HTML_XPATH || $feed->kind() === FreshRSS_Feed::KIND_XML_XPATH) {
@@ -223,10 +237,48 @@ class FreshRSS_subscription_Controller extends FreshRSS_ActionController {
 				if (Minz_Request::paramString('xPathItemUid') != '')
 					$xPathSettings['itemUid'] = Minz_Request::paramString('xPathItemUid', true);
 				if (!empty($xPathSettings))
-					$feed->_attributes('xpath', $xPathSettings);
+					$feed->_attribute('xpath', $xPathSettings);
+			} elseif ($feed->kind() === FreshRSS_Feed::KIND_JSON_DOTNOTATION) {
+				$jsonSettings = [];
+				if (Minz_Request::paramString('jsonFeedTitle') !== '') {
+					$jsonSettings['feedTitle'] = Minz_Request::paramString('jsonFeedTitle', true);
+				}
+				if (Minz_Request::paramString('jsonItem') !== '') {
+					$jsonSettings['item'] = Minz_Request::paramString('jsonItem', true);
+				}
+				if (Minz_Request::paramString('jsonItemTitle') !== '') {
+					$jsonSettings['itemTitle'] = Minz_Request::paramString('jsonItemTitle', true);
+				}
+				if (Minz_Request::paramString('jsonItemContent') !== '') {
+					$jsonSettings['itemContent'] = Minz_Request::paramString('jsonItemContent', true);
+				}
+				if (Minz_Request::paramString('jsonItemUri') !== '') {
+					$jsonSettings['itemUri'] = Minz_Request::paramString('jsonItemUri', true);
+				}
+				if (Minz_Request::paramString('jsonItemAuthor') !== '') {
+					$jsonSettings['itemAuthor'] = Minz_Request::paramString('jsonItemAuthor', true);
+				}
+				if (Minz_Request::paramString('jsonItemTimestamp') !== '') {
+					$jsonSettings['itemTimestamp'] = Minz_Request::paramString('jsonItemTimestamp', true);
+				}
+				if (Minz_Request::paramString('jsonItemTimeFormat') !== '') {
+					$jsonSettings['itemTimeFormat'] = Minz_Request::paramString('jsonItemTimeFormat', true);
+				}
+				if (Minz_Request::paramString('jsonItemThumbnail') !== '') {
+					$jsonSettings['itemThumbnail'] = Minz_Request::paramString('jsonItemThumbnail', true);
+				}
+				if (Minz_Request::paramString('jsonItemCategories') !== '') {
+					$jsonSettings['itemCategories'] = Minz_Request::paramString('jsonItemCategories', true);
+				}
+				if (Minz_Request::paramString('jsonItemUid') !== '') {
+					$jsonSettings['itemUid'] = Minz_Request::paramString('jsonItemUid', true);
+				}
+				if (!empty($jsonSettings)) {
+					$feed->_attribute('json_dotnotation', $jsonSettings);
+				}
 			}
 
-			$feed->_attributes('path_entries_filter', Minz_Request::paramString('path_entries_filter', true));
+			$feed->_attribute('path_entries_filter', Minz_Request::paramString('path_entries_filter', true));
 
 			$values = [
 				'name' => Minz_Request::paramString('name'),
@@ -279,79 +331,6 @@ class FreshRSS_subscription_Controller extends FreshRSS_ActionController {
 		}
 	}
 
-	public function categoryAction(): void {
-		if (Minz_Request::paramBoolean('ajax')) {
-			$this->view->_layout(null);
-		}
-
-		$categoryDAO = FreshRSS_Factory::createCategoryDao();
-
-		$id = Minz_Request::paramInt('id');
-		$category = $categoryDAO->searchById($id);
-		if ($id === 0 || null === $category) {
-			Minz_Error::error(404);
-			return;
-		}
-		$this->view->category = $category;
-
-		FreshRSS_View::prependTitle($category->name() . ' · ' . _t('sub.title') . ' · ');
-
-		if (Minz_Request::isPost()) {
-			if (Minz_Request::paramBoolean('use_default_purge_options')) {
-				$category->_attributes('archiving', null);
-			} else {
-				if (!Minz_Request::paramBoolean('enable_keep_max')) {
-					$keepMax = false;
-				} elseif (($keepMax = Minz_Request::paramInt('keep_max')) !== 0) {
-					$keepMax = FreshRSS_Feed::ARCHIVING_RETENTION_COUNT_LIMIT;
-				}
-				if (Minz_Request::paramBoolean('enable_keep_period')) {
-					$keepPeriod = FreshRSS_Feed::ARCHIVING_RETENTION_PERIOD;
-					if (is_numeric(Minz_Request::paramString('keep_period_count')) && preg_match('/^PT?1[YMWDH]$/', Minz_Request::paramString('keep_period_unit'))) {
-						$keepPeriod = str_replace('1', Minz_Request::paramString('keep_period_count'), Minz_Request::paramString('keep_period_unit'));
-					}
-				} else {
-					$keepPeriod = false;
-				}
-				$category->_attributes('archiving', [
-					'keep_period' => $keepPeriod,
-					'keep_max' => $keepMax,
-					'keep_min' => Minz_Request::paramInt('keep_min'),
-					'keep_favourites' => Minz_Request::paramBoolean('keep_favourites'),
-					'keep_labels' => Minz_Request::paramBoolean('keep_labels'),
-					'keep_unreads' => Minz_Request::paramBoolean('keep_unreads'),
-				]);
-			}
-
-			$position = Minz_Request::paramInt('position') ?: null;
-			$category->_attributes('position', $position);
-
-			$opml_url = checkUrl(Minz_Request::paramString('opml_url'));
-			if ($opml_url != '') {
-				$category->_kind(FreshRSS_Category::KIND_DYNAMIC_OPML);
-				$category->_attributes('opml_url', $opml_url);
-			} else {
-				$category->_kind(FreshRSS_Category::KIND_NORMAL);
-				$category->_attributes('opml_url', null);
-			}
-
-			$values = [
-				'kind' => $category->kind(),
-				'name' => Minz_Request::paramString('name'),
-				'attributes' => $category->attributes(),
-			];
-
-			invalidateHttpCache();
-
-			$url_redirect = ['c' => 'subscription', 'params' => ['id' => $id, 'type' => 'category']];
-			if (false !== $categoryDAO->updateCategory($id, $values)) {
-				Minz_Request::good(_t('feedback.sub.category.updated'), $url_redirect);
-			} else {
-				Minz_Request::bad(_t('feedback.sub.category.error'), $url_redirect);
-			}
-		}
-	}
-
 	/**
 	 * This action displays the bookmarklet page.
 	 */
