@@ -1,9 +1,9 @@
 <?php
+declare(strict_types=1);
 
-class FreshRSS_AlreadySubscribed_Exception extends Exception {
+class FreshRSS_AlreadySubscribed_Exception extends Minz_Exception {
 
-	/** @var string */
-	private $feedName = '';
+	private string $feedName = '';
 
 	public function __construct(string $url, string $feedName) {
 		parent::__construct('Already subscribed! ' . $url, 2135);
