@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 
 class FreshRSS extends Minz_FrontController {
 	/**
@@ -15,7 +16,6 @@ class FreshRSS extends Minz_FrontController {
 	 * - Init i18n (need context)
 	 * - Init sharing system (need user conf and i18n)
 	 * - Init generic styles and scripts (need user conf)
-	 * - Init notifications
 	 * - Enable user extensions (need all the other initializations)
 	 */
 	public function init(): void {
@@ -23,16 +23,14 @@ class FreshRSS extends Minz_FrontController {
 			Minz_Session::init('FreshRSS');
 		}
 
-		Minz_ActionController::$defaultViewType = FreshRSS_View::class;
-
 		FreshRSS_Context::initSystem();
-		if (FreshRSS_Context::$system_conf == null) {
+		if (!FreshRSS_Context::hasSystemConf()) {
 			$message = 'Error during context system init!';
 			Minz_Error::error(500, $message, false);
 			die($message);
 		}
 
-		if (FreshRSS_Context::$system_conf->logo_html != '') {
+		if (FreshRSS_Context::systemConf()->logo_html != '') {
 			// Relax Content Security Policy to allow external images if a custom logo HTML is used
 			Minz_ActionController::_defaultCsp([
 				'default-src' => "'self'",
@@ -46,10 +44,10 @@ class FreshRSS extends Minz_FrontController {
 		// Auth has to be initialized before using currentUser session parameter
 		// because it’s this part which create this parameter.
 		self::initAuth();
-		if (FreshRSS_Context::$user_conf == null) {
+		if (!FreshRSS_Context::hasUserConf()) {
 			FreshRSS_Context::initUser();
 		}
-		if (FreshRSS_Context::$user_conf == null) {
+		if (!FreshRSS_Context::hasUserConf()) {
 			$message = 'Error during context user init!';
 			Minz_Error::error(500, $message, false);
 			die($message);
@@ -57,30 +55,29 @@ class FreshRSS extends Minz_FrontController {
 
 		// Complete initialization of the other FreshRSS / Minz components.
 		self::initI18n();
-		self::loadNotifications();
 		// Enable extensions for the current (logged) user.
-		if (FreshRSS_Auth::hasAccess() || FreshRSS_Context::$system_conf->allow_anonymous) {
-			$ext_list = FreshRSS_Context::$user_conf->extensions_enabled;
+		if (FreshRSS_Auth::hasAccess() || FreshRSS_Context::systemConf()->allow_anonymous) {
+			$ext_list = FreshRSS_Context::userConf()->extensions_enabled;
 			Minz_ExtensionManager::enableByList($ext_list, 'user');
 		}
 
-		if (FreshRSS_Context::$system_conf->force_email_validation && !FreshRSS_Auth::hasAccess('admin')) {
+		if (FreshRSS_Context::systemConf()->force_email_validation && !FreshRSS_Auth::hasAccess('admin')) {
 			self::checkEmailValidated();
 		}
 
-		Minz_ExtensionManager::callHook('freshrss_init');
+		Minz_ExtensionManager::callHookVoid('freshrss_init');
 	}
 
 	private static function initAuth(): void {
 		FreshRSS_Auth::init();
 		if (Minz_Request::isPost()) {
-			if (FreshRSS_Context::$system_conf == null || !(FreshRSS_Auth::isCsrfOk() ||
+			if (!FreshRSS_Context::hasSystemConf() || !(FreshRSS_Auth::isCsrfOk() ||
 				(Minz_Request::controllerName() === 'auth' && Minz_Request::actionName() === 'login') ||
 				(Minz_Request::controllerName() === 'user' && Minz_Request::actionName() === 'create' && !FreshRSS_Auth::hasAccess('admin')) ||
-				(Minz_Request::controllerName() === 'feed' && Minz_Request::actionName() === 'actualize'
-					&& FreshRSS_Context::$system_conf->allow_anonymous_refresh) ||
-				(Minz_Request::controllerName() === 'javascript' && Minz_Request::actionName() === 'actualize'
-					&& FreshRSS_Context::$system_conf->allow_anonymous)
+				(Minz_Request::controllerName() === 'feed' && Minz_Request::actionName() === 'actualize' &&
+					FreshRSS_Context::systemConf()->allow_anonymous_refresh) ||
+				(Minz_Request::controllerName() === 'javascript' && Minz_Request::actionName() === 'actualize' &&
+					FreshRSS_Context::systemConf()->allow_anonymous)
 				)) {
 				// Token-based protection against XSRF attacks, except for the login or self-create user forms
 				self::initI18n();
@@ -90,14 +87,14 @@ class FreshRSS extends Minz_FrontController {
 	}
 
 	private static function initI18n(): void {
-		$userLanguage = isset(FreshRSS_Context::$user_conf) ? FreshRSS_Context::$user_conf->language : null;
-		$systemLanguage = isset(FreshRSS_Context::$system_conf) ? FreshRSS_Context::$system_conf->language : null;
+		$userLanguage = FreshRSS_Context::hasUserConf() ? FreshRSS_Context::userConf()->language : null;
+		$systemLanguage = FreshRSS_Context::hasSystemConf() ? FreshRSS_Context::systemConf()->language : null;
 		$language = Minz_Translate::getLanguage($userLanguage, Minz_Request::getPreferredLanguages(), $systemLanguage);
 
 		Minz_Session::_param('language', $language);
 		Minz_Translate::init($language);
 
-		$timezone = isset(FreshRSS_Context::$user_conf) ? FreshRSS_Context::$user_conf->timezone : '';
+		$timezone = FreshRSS_Context::hasUserConf() ? FreshRSS_Context::userConf()->timezone : '';
 		if ($timezone == '') {
 			$timezone = FreshRSS_Context::defaultTimeZone();
 		}
@@ -110,12 +107,12 @@ class FreshRSS extends Minz_FrontController {
 	}
 
 	public static function loadStylesAndScripts(): void {
-		if (FreshRSS_Context::$user_conf == null) {
+		if (!FreshRSS_Context::hasUserConf()) {
 			return;
 		}
-		$theme = FreshRSS_Themes::load(FreshRSS_Context::$user_conf->theme);
+		$theme = FreshRSS_Themes::load(FreshRSS_Context::userConf()->theme);
 		if ($theme) {
-			foreach(array_reverse($theme['files']) as $file) {
+			foreach (array_reverse($theme['files']) as $file) {
 				switch (substr($file, -3)) {
 					case '.js':
 						$theme_id = $theme['id'];
@@ -144,19 +141,12 @@ class FreshRSS extends Minz_FrontController {
 			}
 		}
 		//Use prepend to insert before extensions. Added in reverse order.
-		if (Minz_Request::controllerName() !== 'index') {
+		if (!in_array(Minz_Request::controllerName(), ['index', ''], true)) {
 			FreshRSS_View::prependScript(Minz_Url::display('/scripts/extra.js?' . @filemtime(PUBLIC_PATH . '/scripts/extra.js')));
 		}
 		FreshRSS_View::prependScript(Minz_Url::display('/scripts/main.js?' . @filemtime(PUBLIC_PATH . '/scripts/main.js')));
 	}
 
-	private static function loadNotifications(): void {
-		$notif = Minz_Request::getNotification();
-		if (!empty($notif)) {
-			FreshRSS_View::_param('notification', $notif);
-		}
-	}
-
 	public static function preLayout(): void {
 		header("X-Content-Type-Options: nosniff");
 
@@ -166,7 +156,7 @@ class FreshRSS extends Minz_FrontController {
 
 	private static function checkEmailValidated(): void {
 		$email_not_verified = FreshRSS_Auth::hasAccess() &&
-			FreshRSS_Context::$user_conf !== null && FreshRSS_Context::$user_conf->email_validation_token !== '';
+			FreshRSS_Context::hasUserConf() && FreshRSS_Context::userConf()->email_validation_token !== '';
 		$action_is_allowed = (
 			Minz_Request::is('user', 'validateEmail') ||
 			Minz_Request::is('user', 'sendValidationEmail') ||
