@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 
 /**
  * Manage the emails sent to the users.
@@ -7,17 +8,20 @@ class FreshRSS_User_Mailer extends Minz_Mailer {
 
 	/**
 	 * @var FreshRSS_View
-	 * @phpstan-ignore-next-line
 	 */
 	protected $view;
 
+	public function __construct() {
+		parent::__construct(FreshRSS_View::class);
+	}
+
 	public function send_email_need_validation(string $username, FreshRSS_UserConfiguration $user_config): bool {
 		Minz_Translate::reset($user_config->language);
 
 		$this->view->_path('user_mailer/email_need_validation.txt.php');
 
 		$this->view->username = $username;
-		$this->view->site_title = FreshRSS_Context::$system_conf->title;
+		$this->view->site_title = FreshRSS_Context::systemConf()->title;
 		$this->view->validation_url = Minz_Url::display(
 			[
 				'c' => 'user',
@@ -31,10 +35,10 @@ class FreshRSS_User_Mailer extends Minz_Mailer {
 			true
 		);
 
-		$subject_prefix = '[' . FreshRSS_Context::$system_conf->title . ']';
+		$subject_prefix = '[' . FreshRSS_Context::systemConf()->title . ']';
 		return $this->mail(
 			$user_config->mail_login,
-			$subject_prefix . ' ' ._t('user.mailer.email_need_validation.title')
+			$subject_prefix . ' ' . _t('user.mailer.email_need_validation.title')
 		);
 	}
 }
