@@ -1,8 +1,10 @@
 <?php
+declare(strict_types=1);
 
 class FreshRSS_CategoryDAOSQLite extends FreshRSS_CategoryDAO {
 
-	/** @param array<string> $errorInfo */
+	/** @param array<int|string> $errorInfo */
+	#[\Override]
 	protected function autoUpdateDb(array $errorInfo): bool {
 		if ($tableInfo = $this->pdo->query("PRAGMA table_info('category')")) {
 			$columns = $tableInfo->fetchAll(PDO::FETCH_COLUMN, 1);
@@ -14,5 +16,4 @@ class FreshRSS_CategoryDAOSQLite extends FreshRSS_CategoryDAO {
 		}
 		return false;
 	}
-
 }
