@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 
 /**
  * This class is used to test database is well-constructed.
@@ -9,8 +10,9 @@ class FreshRSS_DatabaseDAOPGSQL extends FreshRSS_DatabaseDAOSQLite {
 	public const UNDEFINED_COLUMN = '42703';
 	public const UNDEFINED_TABLE = '42P01';
 
+	#[\Override]
 	public function tablesAreCorrect(): bool {
-		$db = FreshRSS_Context::$system_conf->db;
+		$db = FreshRSS_Context::systemConf()->db;
 		$sql = 'SELECT * FROM pg_catalog.pg_tables where tableowner=:tableowner';
 		$res = $this->fetchAssoc($sql, [':tableowner' => $db['user']]);
 		if ($res == null) {
@@ -32,7 +34,8 @@ class FreshRSS_DatabaseDAOPGSQL extends FreshRSS_DatabaseDAOSQLite {
 		return count(array_keys($tables, true, true)) === count($tables);
 	}
 
-	/** @return array<array<string,string|int|bool|null>> */
+	/** @return array<array{name:string,type:string,notnull:bool,default:mixed}> */
+	#[\Override]
 	public function getSchema(string $table): array {
 		$sql = <<<'SQL'
 SELECT column_name AS field, data_type AS type, column_default AS default, is_nullable AS null
@@ -46,6 +49,7 @@ SQL;
 	 * @param array<string,string|int|bool|null> $dao
 	 * @return array{'name':string,'type':string,'notnull':bool,'default':mixed}
 	 */
+	#[\Override]
 	public function daoToSchema(array $dao): array {
 		return [
 			'name' => (string)($dao['field']),
@@ -55,9 +59,10 @@ SQL;
 		];
 	}
 
+	#[\Override]
 	public function size(bool $all = false): int {
 		if ($all) {
-			$db = FreshRSS_Context::$system_conf->db;
+			$db = FreshRSS_Context::systemConf()->db;
 			$res = $this->fetchColumn('SELECT pg_database_size(:base)', 0, [':base' => $db['base']]);
 		} else {
 			$sql = <<<SQL
@@ -74,7 +79,7 @@ SQL;
 		return (int)($res[0] ?? -1);
 	}
 
-
+	#[\Override]
 	public function optimize(): bool {
 		$ok = true;
 		$tables = ['category', 'feed', 'entry', 'entrytmp', 'tag', 'entrytag'];
