@@ -1,12 +1,14 @@
 <?php
+declare(strict_types=1);
 
 /**
  * This class is used to test database is well-constructed (SQLite).
  */
 class FreshRSS_DatabaseDAOSQLite extends FreshRSS_DatabaseDAO {
 
+	#[\Override]
 	public function tablesAreCorrect(): bool {
-		$sql = 'SELECT name FROM sqlite_master WHERE type="table"';
+		$sql = "SELECT name FROM sqlite_master WHERE type='table'";
 		$stm = $this->pdo->query($sql);
 		$res = $stm ? $stm->fetchAll(PDO::FETCH_ASSOC) : false;
 		if ($res === false) {
@@ -28,19 +30,22 @@ class FreshRSS_DatabaseDAOSQLite extends FreshRSS_DatabaseDAO {
 		return count(array_keys($tables, true, true)) == count($tables);
 	}
 
-	/** @return array<array<string,string|int|bool|null>> */
+	/** @return array<array{name:string,type:string,notnull:bool,default:mixed}> */
+	#[\Override]
 	public function getSchema(string $table): array {
 		$sql = 'PRAGMA table_info(' . $table . ')';
 		$stm = $this->pdo->query($sql);
 		return $stm ? $this->listDaoToSchema($stm->fetchAll(PDO::FETCH_ASSOC) ?: []) : [];
 	}
 
+	#[\Override]
 	public function entryIsCorrect(): bool {
 		return $this->checkTable('entry', [
 			'id', 'guid', 'title', 'author', 'content', 'link', 'date', 'lastSeen', 'hash', 'is_read', 'is_favorite', 'id_feed', 'tags',
 		]);
 	}
 
+	#[\Override]
 	public function entrytmpIsCorrect(): bool {
 		return $this->checkTable('entrytmp', [
 			'id', 'guid', 'title', 'author', 'content', 'link', 'date', 'lastSeen', 'hash', 'is_read', 'is_favorite', 'id_feed', 'tags'
@@ -51,6 +56,7 @@ class FreshRSS_DatabaseDAOSQLite extends FreshRSS_DatabaseDAO {
 	 * @param array<string,string|int|bool|null> $dao
 	 * @return array{'name':string,'type':string,'notnull':bool,'default':mixed}
 	 */
+	#[\Override]
 	public function daoToSchema(array $dao): array {
 		return [
 			'name'    => (string)$dao['name'],
@@ -60,18 +66,20 @@ class FreshRSS_DatabaseDAOSQLite extends FreshRSS_DatabaseDAO {
 		];
 	}
 
+	#[\Override]
 	public function size(bool $all = false): int {
 		$sum = 0;
 		if ($all) {
 			foreach (glob(DATA_PATH . '/users/*/db.sqlite') ?: [] as $filename) {
-				$sum += @filesize($filename);
+				$sum += (@filesize($filename) ?: 0);
 			}
 		} else {
-			$sum = @filesize(DATA_PATH . '/users/' . $this->current_user . '/db.sqlite');
+			$sum = (@filesize(DATA_PATH . '/users/' . $this->current_user . '/db.sqlite') ?: 0);
 		}
-		return intval($sum);
+		return $sum;
 	}
 
+	#[\Override]
 	public function optimize(): bool {
 		$ok = $this->pdo->exec('VACUUM') !== false;
 		if (!$ok) {
