@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 
 class FreshRSS_EntryDAO extends Minz_ModelPdo {
 
@@ -65,11 +66,11 @@ SQL;
 	}
 
 	//TODO: Move the database auto-updates to DatabaseDAO
-	/** @param array<string> $errorInfo */
+	/** @param array<string|int> $errorInfo */
 	protected function autoUpdateDb(array $errorInfo): bool {
 		if (isset($errorInfo[0])) {
 			if ($errorInfo[0] === FreshRSS_DatabaseDAO::ER_BAD_FIELD_ERROR || $errorInfo[0] === FreshRSS_DatabaseDAOPGSQL::UNDEFINED_COLUMN) {
-				$errorLines = explode("\n", $errorInfo[2], 2);	// The relevant column name is on the first line, other lines are noise
+				$errorLines = explode("\n", (string)$errorInfo[2], 2);	// The relevant column name is on the first line, other lines are noise
 				foreach (['attributes'] as $column) {
 					if (stripos($errorLines[0], $column) !== false) {
 						return $this->addColumn($column);
@@ -78,8 +79,9 @@ SQL;
 			}
 		}
 		if (isset($errorInfo[1])) {
+			// May be a string or an int
 			if ($errorInfo[1] == FreshRSS_DatabaseDAO::ER_DATA_TOO_LONG) {
-				if (stripos($errorInfo[2], 'content_bin') !== false) {
+				if (stripos((string)$errorInfo[2], 'content_bin') !== false) {
 					return $this->updateToMediumBlob();	//v1.15.0
 				}
 			}
@@ -93,7 +95,7 @@ SQL;
 	private $addEntryPrepared = false;
 
 	/** @param array{'id':string,'guid':string,'title':string,'author':string,'content':string,'link':string,'date':int,'lastSeen':int,'hash':string,
-	 *		'is_read':bool|int|null,'is_favorite':bool|int|null,'id_feed':int,'tags':string,'attributes':array<string,mixed>} $valuesTmp */
+	 *		'is_read':bool|int|null,'is_favorite':bool|int|null,'id_feed':int,'tags':string,'attributes'?:null|string|array<string,mixed>} $valuesTmp */
 	public function addEntry(array $valuesTmp, bool $useTmpTable = true): bool {
 		if ($this->addEntryPrepared == null) {
 			$sql = static::sqlIgnoreConflict(
@@ -109,21 +111,20 @@ SQL;
 		}
 		if ($this->addEntryPrepared) {
 			$this->addEntryPrepared->bindParam(':id', $valuesTmp['id']);
-			$valuesTmp['guid'] = substr($valuesTmp['guid'], 0, 760);
+			$valuesTmp['guid'] = substr($valuesTmp['guid'], 0, 767);
 			$valuesTmp['guid'] = safe_ascii($valuesTmp['guid']);
 			$this->addEntryPrepared->bindParam(':guid', $valuesTmp['guid']);
-			$valuesTmp['title'] = mb_strcut($valuesTmp['title'], 0, 255, 'UTF-8');
+			$valuesTmp['title'] = mb_strcut($valuesTmp['title'], 0, 8192, 'UTF-8');
 			$valuesTmp['title'] = safe_utf8($valuesTmp['title']);
 			$this->addEntryPrepared->bindParam(':title', $valuesTmp['title']);
-			$valuesTmp['author'] = mb_strcut($valuesTmp['author'], 0, 255, 'UTF-8');
+			$valuesTmp['author'] = mb_strcut($valuesTmp['author'], 0, 1024, 'UTF-8');
 			$valuesTmp['author'] = safe_utf8($valuesTmp['author']);
 			$this->addEntryPrepared->bindParam(':author', $valuesTmp['author']);
 			$valuesTmp['content'] = safe_utf8($valuesTmp['content']);
 			$this->addEntryPrepared->bindParam(':content', $valuesTmp['content']);
-			$valuesTmp['link'] = substr($valuesTmp['link'], 0, 1023);
+			$valuesTmp['link'] = substr($valuesTmp['link'], 0, 16383);
 			$valuesTmp['link'] = safe_ascii($valuesTmp['link']);
 			$this->addEntryPrepared->bindParam(':link', $valuesTmp['link']);
-			$valuesTmp['date'] = min($valuesTmp['date'], 2147483647);
 			$this->addEntryPrepared->bindParam(':date', $valuesTmp['date'], PDO::PARAM_INT);
 			if (empty($valuesTmp['lastSeen'])) {
 				$valuesTmp['lastSeen'] = time();
@@ -134,7 +135,7 @@ SQL;
 			$valuesTmp['is_favorite'] = $valuesTmp['is_favorite'] ? 1 : 0;
 			$this->addEntryPrepared->bindParam(':is_favorite', $valuesTmp['is_favorite'], PDO::PARAM_INT);
 			$this->addEntryPrepared->bindParam(':id_feed', $valuesTmp['id_feed'], PDO::PARAM_INT);
-			$valuesTmp['tags'] = mb_strcut($valuesTmp['tags'], 0, 1023, 'UTF-8');
+			$valuesTmp['tags'] = mb_strcut($valuesTmp['tags'], 0, 2048, 'UTF-8');
 			$valuesTmp['tags'] = safe_utf8($valuesTmp['tags']);
 			$this->addEntryPrepared->bindParam(':tags', $valuesTmp['tags']);
 			if (!isset($valuesTmp['attributes'])) {
@@ -190,8 +191,7 @@ SQL;
 		return $result;
 	}
 
-	/** @var PDOStatement|null */
-	private $updateEntryPrepared = null;
+	private ?PDOStatement $updateEntryPrepared = null;
 
 	/** @param array{'id':string,'guid':string,'title':string,'author':string,'content':string,'link':string,'date':int,'lastSeen':int,'hash':string,
 	 *		'is_read':bool|int|null,'is_favorite':bool|int|null,'id_feed':int,'tags':string,'attributes':array<string,mixed>} $valuesTmp */
@@ -216,21 +216,20 @@ SQL;
 			$this->updateEntryPrepared = $this->pdo->prepare($sql) ?: null;
 		}
 		if ($this->updateEntryPrepared) {
-			$valuesTmp['guid'] = substr($valuesTmp['guid'], 0, 760);
+			$valuesTmp['guid'] = substr($valuesTmp['guid'], 0, 767);
 			$valuesTmp['guid'] = safe_ascii($valuesTmp['guid']);
 			$this->updateEntryPrepared->bindParam(':guid', $valuesTmp['guid']);
-			$valuesTmp['title'] = mb_strcut($valuesTmp['title'], 0, 255, 'UTF-8');
+			$valuesTmp['title'] = mb_strcut($valuesTmp['title'], 0, 8192, 'UTF-8');
 			$valuesTmp['title'] = safe_utf8($valuesTmp['title']);
 			$this->updateEntryPrepared->bindParam(':title', $valuesTmp['title']);
-			$valuesTmp['author'] = mb_strcut($valuesTmp['author'], 0, 255, 'UTF-8');
+			$valuesTmp['author'] = mb_strcut($valuesTmp['author'], 0, 1024, 'UTF-8');
 			$valuesTmp['author'] = safe_utf8($valuesTmp['author']);
 			$this->updateEntryPrepared->bindParam(':author', $valuesTmp['author']);
 			$valuesTmp['content'] = safe_utf8($valuesTmp['content']);
 			$this->updateEntryPrepared->bindParam(':content', $valuesTmp['content']);
-			$valuesTmp['link'] = substr($valuesTmp['link'], 0, 1023);
+			$valuesTmp['link'] = substr($valuesTmp['link'], 0, 16383);
 			$valuesTmp['link'] = safe_ascii($valuesTmp['link']);
 			$this->updateEntryPrepared->bindParam(':link', $valuesTmp['link']);
-			$valuesTmp['date'] = min($valuesTmp['date'], 2147483647);
 			$this->updateEntryPrepared->bindParam(':date', $valuesTmp['date'], PDO::PARAM_INT);
 			$this->updateEntryPrepared->bindParam(':last_seen', $valuesTmp['lastSeen'], PDO::PARAM_INT);
 			if ($valuesTmp['is_read'] === null) {
@@ -244,7 +243,7 @@ SQL;
 				$this->updateEntryPrepared->bindValue(':is_favorite', $valuesTmp['is_favorite'] ? 1 : 0, PDO::PARAM_INT);
 			}
 			$this->updateEntryPrepared->bindParam(':id_feed', $valuesTmp['id_feed'], PDO::PARAM_INT);
-			$valuesTmp['tags'] = mb_strcut($valuesTmp['tags'], 0, 1023, 'UTF-8');
+			$valuesTmp['tags'] = mb_strcut($valuesTmp['tags'], 0, 2048, 'UTF-8');
 			$valuesTmp['tags'] = safe_utf8($valuesTmp['tags']);
 			$this->updateEntryPrepared->bindParam(':tags', $valuesTmp['tags']);
 			if (!isset($valuesTmp['attributes'])) {
@@ -274,13 +273,24 @@ SQL;
 		}
 	}
 
+	/**
+	 * Count the number of new entries in the temporary table (which have not yet been committed).
+	 */
+	public function countNewEntries(): int {
+		$sql = <<<'SQL'
+		SELECT COUNT(id) AS nb_entries FROM `_entrytmp`
+		SQL;
+		$res = $this->fetchColumn($sql, 0);
+		return isset($res[0]) ? (int)$res[0] : -1;
+	}
+
 	/**
 	 * Toggle favorite marker on one or more article
 	 *
 	 * @todo simplify the query by removing the str_repeat. I am pretty sure
 	 * there is an other way to do that.
 	 *
-	 * @param string|array<string> $ids
+	 * @param numeric-string|array<numeric-string> $ids
 	 * @return int|false
 	 */
 	public function markFavorite($ids, bool $is_favorite = true) {
@@ -296,13 +306,13 @@ SQL;
 			$affected = 0;
 			$idsChunks = array_chunk($ids, FreshRSS_DatabaseDAO::MAX_VARIABLE_NUMBER);
 			foreach ($idsChunks as $idsChunk) {
-				$affected += $this->markFavorite($idsChunk, $is_favorite);
+				$affected += ($this->markFavorite($idsChunk, $is_favorite) ?: 0);
 			}
 			return $affected;
 		}
 		$sql = 'UPDATE `_entry` '
 			. 'SET is_favorite=? '
-			. 'WHERE id IN (' . str_repeat('?,', count($ids) - 1). '?)';
+			. 'WHERE id IN (' . str_repeat('?,', count($ids) - 1) . '?)';
 		$values = [$is_favorite ? 1 : 0];
 		$values = array_merge($values, $ids);
 		$stm = $this->pdo->prepare($sql);
@@ -358,17 +368,16 @@ SQL;
 	 * Toggle the read marker on one or more article.
 	 * Then the cache is updated.
 	 *
-	 * @param string|array<string> $ids
+	 * @param numeric-string|array<numeric-string> $ids
 	 * @param bool $is_read
 	 * @return int|false affected rows
 	 */
 	public function markRead($ids, bool $is_read = true) {
-		FreshRSS_UserDAO::touch();
 		if (is_array($ids)) {	//Many IDs at once
 			if (count($ids) < 6) {	//Speed heuristics
 				$affected = 0;
 				foreach ($ids as $id) {
-					$affected += $this->markRead($id, $is_read);
+					$affected += ($this->markRead($id, $is_read) ?: 0);
 				}
 				return $affected;
 			} elseif (count($ids) > FreshRSS_DatabaseDAO::MAX_VARIABLE_NUMBER) {
@@ -376,14 +385,15 @@ SQL;
 				$affected = 0;
 				$idsChunks = array_chunk($ids, FreshRSS_DatabaseDAO::MAX_VARIABLE_NUMBER);
 				foreach ($idsChunks as $idsChunk) {
-					$affected += $this->markRead($idsChunk, $is_read);
+					$affected += ($this->markRead($idsChunk, $is_read) ?: 0);
 				}
 				return $affected;
 			}
 
+			FreshRSS_UserDAO::touch();
 			$sql = 'UPDATE `_entry` '
 				 . 'SET is_read=? '
-				 . 'WHERE id IN (' . str_repeat('?,', count($ids) - 1). '?)';
+				 . 'WHERE id IN (' . str_repeat('?,', count($ids) - 1) . '?)';
 			$values = [$is_read ? 1 : 0];
 			$values = array_merge($values, $ids);
 			$stm = $this->pdo->prepare($sql);
@@ -398,6 +408,7 @@ SQL;
 			}
 			return $affected;
 		} else {
+			FreshRSS_UserDAO::touch();
 			$sql = 'UPDATE `_entry` e INNER JOIN `_feed` f ON e.id_feed=f.id '
 				 . 'SET e.is_read=?,'
 				 . 'f.`cache_nbUnreads`=f.`cache_nbUnreads`' . ($is_read ? '-' : '+') . '1 '
@@ -424,10 +435,10 @@ SQL;
 	 *
 	 * If $idMax equals 0, a deprecated debug message is logged
 	 *
-	 * @param string $idMax fail safe article ID
+	 * @param numeric-string $idMax fail safe article ID
 	 * @return int|false affected rows
 	 */
-	public function markReadEntries(string $idMax = '0', bool $onlyFavorites = false, int $priorityMin = 0,
+	public function markReadEntries(string $idMax = '0', bool $onlyFavorites = false, ?int $priorityMin = null, ?int $prioritMax = null,
 		?FreshRSS_BooleanSearch $filters = null, int $state = 0, bool $is_read = true) {
 		FreshRSS_UserDAO::touch();
 		if ($idMax == '0') {
@@ -436,12 +447,22 @@ SQL;
 		}
 
 		$sql = 'UPDATE `_entry` SET is_read = ? WHERE is_read <> ? AND id <= ?';
+		$values = [$is_read ? 1 : 0, $is_read ? 1 : 0, $idMax];
 		if ($onlyFavorites) {
 			$sql .= ' AND is_favorite=1';
-		} elseif ($priorityMin >= 0) {
-			$sql .= ' AND id_feed IN (SELECT f.id FROM `_feed` f WHERE f.priority > ' . intval($priorityMin) . ')';
 		}
-		$values = [$is_read ? 1 : 0, $is_read ? 1 : 0, $idMax];
+		if ($priorityMin !== null || $prioritMax !== null) {
+			$sql .= ' AND id_feed IN (SELECT f.id FROM `_feed` f WHERE 1=1';
+			if ($priorityMin !== null) {
+				$sql .= ' AND f.priority >= ?';
+				$values[] = $priorityMin;
+			}
+			if ($prioritMax !== null) {
+				$sql .= ' AND f.priority < ?';
+				$values[] = $prioritMax;
+			}
+			$sql .= ')';
+		}
 
 		[$searchValues, $search] = $this->sqlListEntriesWhere('', $filters, $state);
 
@@ -466,7 +487,7 @@ SQL;
 	 * If $idMax equals 0, a deprecated debug message is logged
 	 *
 	 * @param int $id category ID
-	 * @param string $idMax fail safe article ID
+	 * @param numeric-string $idMax fail safe article ID
 	 * @return int|false affected rows
 	 */
 	public function markReadCat(int $id, string $idMax = '0', ?FreshRSS_BooleanSearch $filters = null, int $state = 0, bool $is_read = true) {
@@ -507,7 +528,7 @@ SQL;
 	 * If $idMax equals 0, a deprecated debug message is logged
 	 *
 	 * @param int $id_feed feed ID
-	 * @param string $idMax fail safe article ID
+	 * @param numeric-string $idMax fail safe article ID
 	 * @return int|false affected rows
 	 */
 	public function markReadFeed(int $id_feed, string $idMax = '0', ?FreshRSS_BooleanSearch $filters = null, int $state = 0, bool $is_read = true) {
@@ -561,7 +582,7 @@ SQL;
 	/**
 	 * Mark all the articles in a tag as read.
 	 * @param int $id tag ID, or empty for targeting any tag
-	 * @param string $idMax max article ID
+	 * @param numeric-string $idMax max article ID
 	 * @return int|false affected rows
 	 */
 	public function markReadTag(int $id = 0, string $idMax = '0', ?FreshRSS_BooleanSearch $filters = null,
@@ -600,8 +621,8 @@ SQL;
 	}
 
 	/**
-	 * Remember to call updateCachedValue($id_feed) or updateCachedValues() just after.
-	 * @param array<string,int|bool|string> $options
+	 * Remember to call updateCachedValues($id_feed) or updateCachedValues() just after.
+	 * @param array<string,bool|int|string> $options
 	 * @return int|false
 	 */
 	public function cleanOldEntries(int $id_feed, array $options = []) {
@@ -664,17 +685,22 @@ SQL;
 	}
 
 	/** @return Traversable<array{'id':string,'guid':string,'title':string,'author':string,'content':string,'link':string,'date':int,'lastSeen':int,
-	 *		'hash':string,'is_read':?bool,'is_favorite':?bool,'id_feed':int,'tags':string,'attributes':array<string,mixed>}> */
-	public function selectAll(): Traversable {
+	 *		'hash':string,'is_read':bool,'is_favorite':bool,'id_feed':int,'tags':string,'attributes':?string}> */
+	public function selectAll(?int $limit = null): Traversable {
 		$content = static::isCompressed() ? 'UNCOMPRESS(content_bin) AS content' : 'content';
 		$hash = static::sqlHexEncode('hash');
 		$sql = <<<SQL
 SELECT id, guid, title, author, {$content}, link, date, `lastSeen`, {$hash} AS hash, is_read, is_favorite, id_feed, tags, attributes
 FROM `_entry`
 SQL;
+		if (is_int($limit) && $limit >= 0) {
+			$sql .= ' ORDER BY id DESC LIMIT ' . $limit;
+		}
 		$stm = $this->pdo->query($sql);
 		if ($stm != false) {
 			while ($row = $stm->fetch(PDO::FETCH_ASSOC)) {
+				/** @var array{'id':string,'guid':string,'title':string,'author':string,'content':string,'link':string,'date':int,'lastSeen':int,
+				 *	'hash':string,'is_read':bool,'is_favorite':bool,'id_feed':int,'tags':string,'attributes':?string} $row */
 				yield $row;
 			}
 		} else {
@@ -696,7 +722,7 @@ FROM `_entry` WHERE id_feed=:id_feed AND guid=:guid
 SQL;
 		$res = $this->fetchAssoc($sql, [':id_feed' => $id_feed, ':guid' => $guid]);
 		/** @var array<array{'id':string,'id_feed':int,'guid':string,'title':string,'author':string,'content':string,'link':string,'date':int,
-		 *		'is_read':int,'is_favorite':int,'tags':string,'attributes'?:string}> $res */
+		 *		'is_read':int,'is_favorite':int,'tags':string,'attributes':?string}> $res */
 		return isset($res[0]) ? FreshRSS_Entry::fromArray($res[0]) : null;
 	}
 
@@ -709,7 +735,7 @@ FROM `_entry` WHERE id=:id
 SQL;
 		$res = $this->fetchAssoc($sql, [':id' => $id]);
 		/** @var array<array{'id':string,'id_feed':int,'guid':string,'title':string,'author':string,'content':string,'link':string,'date':int,
-		 *		'is_read':int,'is_favorite':int,'tags':string,'attributes'?:string}> $res */
+		 *		'is_read':int,'is_favorite':int,'tags':string,'attributes':?string}> $res */
 		return isset($res[0]) ? FreshRSS_Entry::fromArray($res[0]) : null;
 	}
 
@@ -737,7 +763,7 @@ SQL;
 				if ($filterSearch !== '') {
 					if ($search !== '') {
 						$search .= $filter->operator();
-					} elseif ($filter->operator() === 'AND NOT') {
+					} elseif (in_array($filter->operator(), ['AND NOT', 'OR NOT'], true)) {
 						// Special case if we start with a negation (there is already the default AND before)
 						$search .= ' NOT';
 					}
@@ -748,7 +774,7 @@ SQL;
 			}
 			// Searches are combined by OR and are not recursive
 			$sub_search = '';
-			if ($filter->getEntryIds()) {
+			if ($filter->getEntryIds() !== null) {
 				$sub_search .= 'AND ' . $alias . 'id IN (';
 				foreach ($filter->getEntryIds() as $entry_id) {
 					$sub_search .= '?,';
@@ -757,7 +783,7 @@ SQL;
 				$sub_search = rtrim($sub_search, ',');
 				$sub_search .= ') ';
 			}
-			if ($filter->getNotEntryIds()) {
+			if ($filter->getNotEntryIds() !== null) {
 				$sub_search .= 'AND ' . $alias . 'id NOT IN (';
 				foreach ($filter->getNotEntryIds() as $entry_id) {
 					$sub_search .= '?,';
@@ -767,56 +793,56 @@ SQL;
 				$sub_search .= ') ';
 			}
 
-			if ($filter->getMinDate()) {
+			if ($filter->getMinDate() !== null) {
 				$sub_search .= 'AND ' . $alias . 'id >= ? ';
 				$values[] = "{$filter->getMinDate()}000000";
 			}
-			if ($filter->getMaxDate()) {
+			if ($filter->getMaxDate() !== null) {
 				$sub_search .= 'AND ' . $alias . 'id <= ? ';
 				$values[] = "{$filter->getMaxDate()}000000";
 			}
-			if ($filter->getMinPubdate()) {
+			if ($filter->getMinPubdate() !== null) {
 				$sub_search .= 'AND ' . $alias . 'date >= ? ';
 				$values[] = $filter->getMinPubdate();
 			}
-			if ($filter->getMaxPubdate()) {
+			if ($filter->getMaxPubdate() !== null) {
 				$sub_search .= 'AND ' . $alias . 'date <= ? ';
 				$values[] = $filter->getMaxPubdate();
 			}
 
 			//Negation of date intervals must be combined by OR
-			if ($filter->getNotMinDate() || $filter->getNotMaxDate()) {
+			if ($filter->getNotMinDate() !== null || $filter->getNotMaxDate() !== null) {
 				$sub_search .= 'AND (';
-				if ($filter->getNotMinDate()) {
+				if ($filter->getNotMinDate() !== null) {
 					$sub_search .= $alias . 'id < ?';
 					$values[] = "{$filter->getNotMinDate()}000000";
 					if ($filter->getNotMaxDate()) {
 						$sub_search .= ' OR ';
 					}
 				}
-				if ($filter->getNotMaxDate()) {
+				if ($filter->getNotMaxDate() !== null) {
 					$sub_search .= $alias . 'id > ?';
 					$values[] = "{$filter->getNotMaxDate()}000000";
 				}
 				$sub_search .= ') ';
 			}
-			if ($filter->getNotMinPubdate() || $filter->getNotMaxPubdate()) {
+			if ($filter->getNotMinPubdate() !== null || $filter->getNotMaxPubdate() !== null) {
 				$sub_search .= 'AND (';
-				if ($filter->getNotMinPubdate()) {
+				if ($filter->getNotMinPubdate() !== null) {
 					$sub_search .= $alias . 'date < ?';
 					$values[] = $filter->getNotMinPubdate();
 					if ($filter->getNotMaxPubdate()) {
 						$sub_search .= ' OR ';
 					}
 				}
-				if ($filter->getNotMaxPubdate()) {
+				if ($filter->getNotMaxPubdate() !== null) {
 					$sub_search .= $alias . 'date > ?';
 					$values[] = $filter->getNotMaxPubdate();
 				}
 				$sub_search .= ') ';
 			}
 
-			if ($filter->getFeedIds()) {
+			if ($filter->getFeedIds() !== null) {
 				$sub_search .= 'AND ' . $alias . 'id_feed IN (';
 				foreach ($filter->getFeedIds() as $feed_id) {
 					$sub_search .= '?,';
@@ -825,7 +851,7 @@ SQL;
 				$sub_search = rtrim($sub_search, ',');
 				$sub_search .= ') ';
 			}
-			if ($filter->getNotFeedIds()) {
+			if ($filter->getNotFeedIds() !== null) {
 				$sub_search .= 'AND ' . $alias . 'id_feed NOT IN (';
 				foreach ($filter->getNotFeedIds() as $feed_id) {
 					$sub_search .= '?,';
@@ -835,7 +861,7 @@ SQL;
 				$sub_search .= ') ';
 			}
 
-			if ($filter->getLabelIds()) {
+			if ($filter->getLabelIds() !== null) {
 				if ($filter->getLabelIds() === '*') {
 					$sub_search .= 'AND EXISTS (SELECT et.id_tag FROM `_entrytag` et WHERE et.id_entry = ' . $alias . 'id) ';
 				} else {
@@ -848,7 +874,7 @@ SQL;
 					$sub_search .= ')) ';
 				}
 			}
-			if ($filter->getNotLabelIds()) {
+			if ($filter->getNotLabelIds() !== null) {
 				if ($filter->getNotLabelIds() === '*') {
 					$sub_search .= 'AND NOT EXISTS (SELECT et.id_tag FROM `_entrytag` et WHERE et.id_entry = ' . $alias . 'id) ';
 				} else {
@@ -862,7 +888,7 @@ SQL;
 				}
 			}
 
-			if ($filter->getLabelNames()) {
+			if ($filter->getLabelNames() !== null) {
 				$sub_search .= 'AND ' . $alias . 'id IN (SELECT et.id_entry FROM `_entrytag` et, `_tag` t WHERE et.id_tag = t.id AND t.name IN (';
 				foreach ($filter->getLabelNames() as $label_name) {
 					$sub_search .= '?,';
@@ -871,7 +897,7 @@ SQL;
 				$sub_search = rtrim($sub_search, ',');
 				$sub_search .= ')) ';
 			}
-			if ($filter->getNotLabelNames()) {
+			if ($filter->getNotLabelNames() !== null) {
 				$sub_search .= 'AND ' . $alias . 'id NOT IN (SELECT et.id_entry FROM `_entrytag` et, `_tag` t WHERE et.id_tag = t.id AND t.name IN (';
 				foreach ($filter->getNotLabelNames() as $label_name) {
 					$sub_search .= '?,';
@@ -881,57 +907,57 @@ SQL;
 				$sub_search .= ')) ';
 			}
 
-			if ($filter->getAuthor()) {
+			if ($filter->getAuthor() !== null) {
 				foreach ($filter->getAuthor() as $author) {
 					$sub_search .= 'AND ' . $alias . 'author LIKE ? ';
 					$values[] = "%{$author}%";
 				}
 			}
-			if ($filter->getIntitle()) {
+			if ($filter->getIntitle() !== null) {
 				foreach ($filter->getIntitle() as $title) {
 					$sub_search .= 'AND ' . $alias . 'title LIKE ? ';
 					$values[] = "%{$title}%";
 				}
 			}
-			if ($filter->getTags()) {
+			if ($filter->getTags() !== null) {
 				foreach ($filter->getTags() as $tag) {
 					$sub_search .= 'AND ' . static::sqlConcat('TRIM(' . $alias . 'tags) ', " ' #'") . ' LIKE ? ';
 					$values[] = "%{$tag} #%";
 				}
 			}
-			if ($filter->getInurl()) {
+			if ($filter->getInurl() !== null) {
 				foreach ($filter->getInurl() as $url) {
 					$sub_search .= 'AND ' . $alias . 'link LIKE ? ';
 					$values[] = "%{$url}%";
 				}
 			}
 
-			if ($filter->getNotAuthor()) {
+			if ($filter->getNotAuthor() !== null) {
 				foreach ($filter->getNotAuthor() as $author) {
 					$sub_search .= 'AND ' . $alias . 'author NOT LIKE ? ';
 					$values[] = "%{$author}%";
 				}
 			}
-			if ($filter->getNotIntitle()) {
+			if ($filter->getNotIntitle() !== null) {
 				foreach ($filter->getNotIntitle() as $title) {
 					$sub_search .= 'AND ' . $alias . 'title NOT LIKE ? ';
 					$values[] = "%{$title}%";
 				}
 			}
-			if ($filter->getNotTags()) {
+			if ($filter->getNotTags() !== null) {
 				foreach ($filter->getNotTags() as $tag) {
 					$sub_search .= 'AND ' . static::sqlConcat('TRIM(' . $alias . 'tags) ', " ' #'") . ' NOT LIKE ? ';
 					$values[] = "%{$tag} #%";
 				}
 			}
-			if ($filter->getNotInurl()) {
+			if ($filter->getNotInurl() !== null) {
 				foreach ($filter->getNotInurl() as $url) {
 					$sub_search .= 'AND ' . $alias . 'link NOT LIKE ? ';
 					$values[] = "%{$url}%";
 				}
 			}
 
-			if ($filter->getSearch()) {
+			if ($filter->getSearch() !== null) {
 				foreach ($filter->getSearch() as $search_value) {
 					if (static::isCompressed()) {	// MySQL-only
 						$sub_search .= 'AND CONCAT(' . $alias . 'title, UNCOMPRESS(' . $alias . 'content_bin)) LIKE ? ';
@@ -943,7 +969,7 @@ SQL;
 					}
 				}
 			}
-			if ($filter->getNotSearch()) {
+			if ($filter->getNotSearch() !== null) {
 				foreach ($filter->getNotSearch() as $search_value) {
 					if (static::isCompressed()) {	// MySQL-only
 						$sub_search .= 'AND CONCAT(' . $alias . 'title, UNCOMPRESS(' . $alias . 'content_bin)) NOT LIKE ? ';
@@ -973,10 +999,11 @@ SQL;
 	/**
 	 * @param 'ASC'|'DESC' $order
 	 * @return array{0:array<int|string>,1:string}
+	 * @throws FreshRSS_EntriesGetter_Exception
 	 */
 	protected function sqlListEntriesWhere(string $alias = '', ?FreshRSS_BooleanSearch $filters = null,
 			int $state = FreshRSS_Entry::STATE_ALL,
-			string $order = 'DESC', string $firstId = '', int $date_min = 0) {
+			string $order = 'DESC', string $firstId = '', int $date_min = 0): array {
 		$search = ' ';
 		$values = [];
 		if ($state & FreshRSS_Entry::STATE_NOT_READ) {
@@ -1021,54 +1048,58 @@ SQL;
 	}
 
 	/**
-	 * @phpstan-param 'a'|'A'|'s'|'S'|'c'|'f'|'t'|'T'|'ST' $type
+	 * @phpstan-param 'a'|'A'|'i'|'s'|'S'|'c'|'f'|'t'|'T'|'ST' $type
 	 * @param int $id category/feed/tag ID
 	 * @param 'ASC'|'DESC' $order
 	 * @return array{0:array<int|string>,1:string}
+	 * @throws FreshRSS_EntriesGetter_Exception
 	 */
 	private function sqlListWhere(string $type = 'a', int $id = 0, int $state = FreshRSS_Entry::STATE_ALL,
-			string $order = 'DESC', int $limit = 1, string $firstId = '', ?FreshRSS_BooleanSearch $filters = null,
-			int $date_min = 0) {
+			string $order = 'DESC', int $limit = 1, int $offset = 0, string $firstId = '', ?FreshRSS_BooleanSearch $filters = null,
+			int $date_min = 0): array {
 		if (!$state) {
 			$state = FreshRSS_Entry::STATE_ALL;
 		}
 		$where = '';
 		$values = [];
 		switch ($type) {
-		case 'a':	//All PRIORITY_MAIN_STREAM
-			$where .= 'f.priority > ' . FreshRSS_Feed::PRIORITY_NORMAL . ' ';
-			break;
-		case 'A':	//All except PRIORITY_ARCHIVED
-			$where .= 'f.priority >= ' . FreshRSS_Feed::PRIORITY_NORMAL . ' ';
-			break;
-		case 's':	//Starred. Deprecated: use $state instead
-			$where .= 'f.priority >= ' . FreshRSS_Feed::PRIORITY_NORMAL . ' ';
-			$where .= 'AND e.is_favorite=1 ';
-			break;
-		case 'S':	//Starred
-			$where .= 'e.is_favorite=1 ';
-			break;
-		case 'c':	//Category
-			$where .= 'f.priority >= ' . FreshRSS_Feed::PRIORITY_NORMAL . ' ';
-			$where .= 'AND f.category=? ';
-			$values[] = $id;
-			break;
-		case 'f':	//Feed
-			$where .= 'e.id_feed=? ';
-			$values[] = $id;
-			break;
-		case 't':	//Tag (label)
-			$where .= 'et.id_tag=? ';
-			$values[] = $id;
-			break;
-		case 'T':	//Any tag (label)
-			$where .= '1=1 ';
-			break;
-		case 'ST':	//Starred or tagged (label)
-			$where .= 'e.is_favorite=1 OR EXISTS (SELECT et2.id_tag FROM `_entrytag` et2 WHERE et2.id_entry = e.id) ';
-			break;
-		default:
-			throw new FreshRSS_EntriesGetter_Exception('Bad type in Entry->listByType: [' . $type . ']!');
+			case 'a':	//All PRIORITY_MAIN_STREAM
+				$where .= 'f.priority >= ' . FreshRSS_Feed::PRIORITY_MAIN_STREAM . ' ';
+				break;
+			case 'A':	//All except PRIORITY_ARCHIVED
+				$where .= 'f.priority > ' . FreshRSS_Feed::PRIORITY_ARCHIVED . ' ';
+				break;
+			case 'i':	//Priority important feeds
+				$where .= 'f.priority >= ' . FreshRSS_Feed::PRIORITY_IMPORTANT . ' ';
+				break;
+			case 's':	//Starred. Deprecated: use $state instead
+				$where .= 'f.priority > ' . FreshRSS_Feed::PRIORITY_ARCHIVED . ' ';
+				$where .= 'AND e.is_favorite=1 ';
+				break;
+			case 'S':	//Starred
+				$where .= 'e.is_favorite=1 ';
+				break;
+			case 'c':	//Category
+				$where .= 'f.priority >= ' . FreshRSS_Feed::PRIORITY_CATEGORY . ' ';
+				$where .= 'AND f.category=? ';
+				$values[] = $id;
+				break;
+			case 'f':	//Feed
+				$where .= 'e.id_feed=? ';
+				$values[] = $id;
+				break;
+			case 't':	//Tag (label)
+				$where .= 'et.id_tag=? ';
+				$values[] = $id;
+				break;
+			case 'T':	//Any tag (label)
+				$where .= '1=1 ';
+				break;
+			case 'ST':	//Starred or tagged (label)
+				$where .= 'e.is_favorite=1 OR EXISTS (SELECT et2.id_tag FROM `_entrytag` et2 WHERE et2.id_entry = e.id) ';
+				break;
+			default:
+				throw new FreshRSS_EntriesGetter_Exception('Bad type in Entry->listByType: [' . $type . ']!');
 		}
 
 		[$searchValues, $search] = $this->sqlListEntriesWhere('e.', $filters, $state, $order, $firstId, $date_min);
@@ -1081,19 +1112,22 @@ SQL;
 			. 'WHERE ' . $where
 			. $search
 			. 'ORDER BY e.id ' . $order
-			. ($limit > 0 ? ' LIMIT ' . intval($limit) : '')];	//TODO: See http://explainextended.com/2009/10/23/mysql-order-by-limit-performance-late-row-lookups/
+			. ($limit > 0 ? ' LIMIT ' . $limit : '')	// http://explainextended.com/2009/10/23/mysql-order-by-limit-performance-late-row-lookups/
+			. ($offset > 0 ? ' OFFSET ' . $offset : '')
+		];
 	}
 
 	/**
-	 * @phpstan-param 'a'|'A'|'s'|'S'|'c'|'f'|'t'|'T'|'ST' $type
+	 * @phpstan-param 'a'|'A'|'s'|'S'|'i'|'c'|'f'|'t'|'T'|'ST' $type
 	 * @param 'ASC'|'DESC' $order
 	 * @param int $id category/feed/tag ID
 	 * @return PDOStatement|false
+	 * @throws FreshRSS_EntriesGetter_Exception
 	 */
 	private function listWhereRaw(string $type = 'a', int $id = 0, int $state = FreshRSS_Entry::STATE_ALL,
-			string $order = 'DESC', int $limit = 1, string $firstId = '', ?FreshRSS_BooleanSearch $filters = null,
+			string $order = 'DESC', int $limit = 1, int $offset = 0, string $firstId = '', ?FreshRSS_BooleanSearch $filters = null,
 			int $date_min = 0) {
-		[$values, $sql] = $this->sqlListWhere($type, $id, $state, $order, $limit, $firstId, $filters, $date_min);
+		[$values, $sql] = $this->sqlListWhere($type, $id, $state, $order, $limit, $offset, $firstId, $filters, $date_min);
 
 		if ($order !== 'DESC' && $order !== 'ASC') {
 			$order = 'DESC';
@@ -1112,7 +1146,7 @@ SQL;
 		} else {
 			$info = $stm == null ? $this->pdo->errorInfo() : $stm->errorInfo();
 			if ($this->autoUpdateDb($info)) {
-				return $this->listWhereRaw($type, $id, $state, $order, $limit, $firstId, $filters, $date_min);
+				return $this->listWhereRaw($type, $id, $state, $order, $limit, $offset, $firstId, $filters, $date_min);
 			}
 			Minz_Log::error('SQL error ' . __METHOD__ . json_encode($info));
 			return false;
@@ -1120,26 +1154,29 @@ SQL;
 	}
 
 	/**
-	 * @phpstan-param 'a'|'A'|'s'|'S'|'c'|'f'|'t'|'T'|'ST' $type
+	 * @phpstan-param 'a'|'A'|'s'|'S'|'i'|'c'|'f'|'t'|'T'|'ST' $type
 	 * @param int $id category/feed/tag ID
 	 * @param 'ASC'|'DESC' $order
 	 * @return Traversable<FreshRSS_Entry>
+	 * @throws FreshRSS_EntriesGetter_Exception
 	 */
 	public function listWhere(string $type = 'a', int $id = 0, int $state = FreshRSS_Entry::STATE_ALL,
-			string $order = 'DESC', int $limit = 1, string $firstId = '',
+			string $order = 'DESC', int $limit = 1, int $offset = 0, string $firstId = '',
 			?FreshRSS_BooleanSearch $filters = null, int $date_min = 0): Traversable {
-		$stm = $this->listWhereRaw($type, $id, $state, $order, $limit, $firstId, $filters, $date_min);
+		$stm = $this->listWhereRaw($type, $id, $state, $order, $limit, $offset, $firstId, $filters, $date_min);
 		if ($stm) {
 			while ($row = $stm->fetch(PDO::FETCH_ASSOC)) {
-				/** @var array{'id':string,'id_feed':int,'guid':string,'title':string,'author':string,'content':string,'link':string,'date':int,
-				 *		'hash':string,'is_read':int,'is_favorite':int,'tags':string,'attributes'?:string} $row */
-				yield FreshRSS_Entry::fromArray($row);
+				if (is_array($row)) {
+					/** @var array{'id':string,'id_feed':int,'guid':string,'title':string,'author':string,'content':string,'link':string,'date':int,
+					 *		'hash':string,'is_read':int,'is_favorite':int,'tags':string,'attributes'?:?string} $row */
+					yield FreshRSS_Entry::fromArray($row);
+				}
 			}
 		}
 	}
 
 	/**
-	 * @param array<string> $ids
+	 * @param array<numeric-string> $ids
 	 * @param 'ASC'|'DESC' $order
 	 * @return Traversable<FreshRSS_Entry>
 	 */
@@ -1174,9 +1211,11 @@ SQL;
 			return;
 		}
 		while ($row = $stm->fetch(PDO::FETCH_ASSOC)) {
-			/** @var array{'id':string,'id_feed':int,'guid':string,'title':string,'author':string,'content':string,'link':string,'date':int,
-			 *		'hash':string,'is_read':int,'is_favorite':int,'tags':string,'attributes'?:string} $row */
-			yield FreshRSS_Entry::fromArray($row);
+			if (is_array($row)) {
+				/** @var array{'id':string,'id_feed':int,'guid':string,'title':string,'author':string,'content':string,'link':string,'date':int,
+				 *		'hash':string,'is_read':int,'is_favorite':int,'tags':string,'attributes':?string} $row */
+				yield FreshRSS_Entry::fromArray($row);
+			}
 		}
 	}
 
@@ -1185,11 +1224,12 @@ SQL;
 	 * @param int $id category/feed/tag ID
 	 * @param 'ASC'|'DESC' $order
 	 * @return array<numeric-string>|null
+	 * @throws FreshRSS_EntriesGetter_Exception
 	 */
 	public function listIdsWhere(string $type = 'a', int $id = 0, int $state = FreshRSS_Entry::STATE_ALL,
-		string $order = 'DESC', int $limit = 1, string $firstId = '', ?FreshRSS_BooleanSearch $filters = null): ?array {
+		string $order = 'DESC', int $limit = 1, int $offset = 0, string $firstId = '', ?FreshRSS_BooleanSearch $filters = null): ?array {
 
-		[$values, $sql] = $this->sqlListWhere($type, $id, $state, $order, $limit, $firstId, $filters);
+		[$values, $sql] = $this->sqlListWhere($type, $id, $state, $order, $limit, $offset, $firstId, $filters);
 		$stm = $this->pdo->prepare($sql);
 		if ($stm !== false && $stm->execute($values) && ($res = $stm->fetchAll(PDO::FETCH_COLUMN, 0)) !== false) {
 			/** @var array<numeric-string> $res */
@@ -1218,7 +1258,7 @@ SQL;
 		}
 		$guids = array_unique($guids);
 		$sql = 'SELECT guid, ' . static::sqlHexEncode('hash') .
-			' AS hex_hash FROM `_entry` WHERE id_feed=? AND guid IN (' . str_repeat('?,', count($guids) - 1). '?)';
+			' AS hex_hash FROM `_entry` WHERE id_feed=? AND guid IN (' . str_repeat('?,', count($guids) - 1) . '?)';
 		$stm = $this->pdo->prepare($sql);
 		$values = [$id_feed];
 		$values = array_merge($values, $guids);
@@ -1251,11 +1291,11 @@ SQL;
 			$affected = 0;
 			$guidsChunks = array_chunk($guids, FreshRSS_DatabaseDAO::MAX_VARIABLE_NUMBER);
 			foreach ($guidsChunks as $guidsChunk) {
-				$affected += $this->updateLastSeen($id_feed, $guidsChunk, $mtime);
+				$affected += ($this->updateLastSeen($id_feed, $guidsChunk, $mtime) ?: 0);
 			}
 			return $affected;
 		}
-		$sql = 'UPDATE `_entry` SET `lastSeen`=? WHERE id_feed=? AND guid IN (' . str_repeat('?,', count($guids) - 1). '?)';
+		$sql = 'UPDATE `_entry` SET `lastSeen`=? WHERE id_feed=? AND guid IN (' . str_repeat('?,', count($guids) - 1) . '?)';
 		$stm = $this->pdo->prepare($sql);
 		if ($mtime <= 0) {
 			$mtime = time();
@@ -1362,20 +1402,20 @@ SELECT c FROM (
 		FROM `_entry` AS e1
 		JOIN `_feed` AS f1 ON e1.id_feed = f1.id
 		WHERE e1.is_favorite = 1
-		AND f1.priority >= :priority_normal1
+		AND f1.priority >= :priority1
 	UNION
 	SELECT COUNT(e2.id) AS c, 2 AS o
 		FROM `_entry` AS e2
 		JOIN `_feed` AS f2 ON e2.id_feed = f2.id
 		WHERE e2.is_favorite = 1
-		AND e2.is_read = 0 AND f2.priority >= :priority_normal2
+		AND e2.is_read = 0 AND f2.priority >= :priority2
 	) u
 ORDER BY o
 SQL;
 		//Binding a value more than once is not standard and does not work with native prepared statements (e.g. MySQL) https://bugs.php.net/bug.php?id=40417
 		$res = $this->fetchColumn($sql, 0, [
-			':priority_normal1' => FreshRSS_Feed::PRIORITY_NORMAL,
-			':priority_normal2' => FreshRSS_Feed::PRIORITY_NORMAL,
+			':priority1' => FreshRSS_Feed::PRIORITY_CATEGORY,
+			':priority2' => FreshRSS_Feed::PRIORITY_CATEGORY,
 		]);
 		if ($res === null) {
 			return ['all' => -1, 'unread' => -1, 'read' => -1];
