@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 
 class FreshRSS_Factory {
 
@@ -13,7 +14,7 @@ class FreshRSS_Factory {
 	 * @throws Minz_ConfigurationNamespaceException|Minz_PDOConnectionException
 	 */
 	public static function createCategoryDao(?string $username = null): FreshRSS_CategoryDAO {
-		switch (FreshRSS_Context::$system_conf->db['type'] ?? '') {
+		switch (FreshRSS_Context::systemConf()->db['type'] ?? '') {
 			case 'sqlite':
 				return new FreshRSS_CategoryDAOSQLite($username);
 			default:
@@ -25,7 +26,7 @@ class FreshRSS_Factory {
 	 * @throws Minz_ConfigurationNamespaceException|Minz_PDOConnectionException
 	 */
 	public static function createFeedDao(?string $username = null): FreshRSS_FeedDAO {
-		switch (FreshRSS_Context::$system_conf->db['type'] ?? '') {
+		switch (FreshRSS_Context::systemConf()->db['type'] ?? '') {
 			case 'sqlite':
 				return new FreshRSS_FeedDAOSQLite($username);
 			default:
@@ -37,7 +38,7 @@ class FreshRSS_Factory {
 	 * @throws Minz_ConfigurationNamespaceException|Minz_PDOConnectionException
 	 */
 	public static function createEntryDao(?string $username = null): FreshRSS_EntryDAO {
-		switch (FreshRSS_Context::$system_conf->db['type'] ?? '') {
+		switch (FreshRSS_Context::systemConf()->db['type'] ?? '') {
 			case 'sqlite':
 				return new FreshRSS_EntryDAOSQLite($username);
 			case 'pgsql':
@@ -51,7 +52,7 @@ class FreshRSS_Factory {
 	 * @throws Minz_ConfigurationNamespaceException|Minz_PDOConnectionException
 	 */
 	public static function createTagDao(?string $username = null): FreshRSS_TagDAO {
-		switch (FreshRSS_Context::$system_conf->db['type'] ?? '') {
+		switch (FreshRSS_Context::systemConf()->db['type'] ?? '') {
 			case 'sqlite':
 				return new FreshRSS_TagDAOSQLite($username);
 			case 'pgsql':
@@ -65,7 +66,7 @@ class FreshRSS_Factory {
 	 * @throws Minz_ConfigurationNamespaceException|Minz_PDOConnectionException
 	 */
 	public static function createStatsDAO(?string $username = null): FreshRSS_StatsDAO {
-		switch (FreshRSS_Context::$system_conf->db['type'] ?? '') {
+		switch (FreshRSS_Context::systemConf()->db['type'] ?? '') {
 			case 'sqlite':
 				return new FreshRSS_StatsDAOSQLite($username);
 			case 'pgsql':
@@ -79,7 +80,7 @@ class FreshRSS_Factory {
 	 * @throws Minz_ConfigurationNamespaceException|Minz_PDOConnectionException
 	 */
 	public static function createDatabaseDAO(?string $username = null): FreshRSS_DatabaseDAO {
-		switch (FreshRSS_Context::$system_conf->db['type'] ?? '') {
+		switch (FreshRSS_Context::systemConf()->db['type'] ?? '') {
 			case 'sqlite':
 				return new FreshRSS_DatabaseDAOSQLite($username);
 			case 'pgsql':
@@ -88,5 +89,4 @@ class FreshRSS_Factory {
 				return new FreshRSS_DatabaseDAO($username);
 		}
 	}
-
 }
