@@ -1,8 +1,10 @@
 <?php
+declare(strict_types=1);
 
 class FreshRSS_FeedDAOSQLite extends FreshRSS_FeedDAO {
 
-	/** @param array<string> $errorInfo */
+	/** @param array<int|string> $errorInfo */
+	#[\Override]
 	protected function autoUpdateDb(array $errorInfo): bool {
 		if ($tableInfo = $this->pdo->query("PRAGMA table_info('feed')")) {
 			$columns = $tableInfo->fetchAll(PDO::FETCH_COLUMN, 1);
