@@ -1,12 +1,11 @@
 <?php
+declare(strict_types=1);
 
 class FreshRSS_Themes extends Minz_Model {
-	/** @var string */
-	private static $themesUrl = '/themes/';
-	/** @var string */
-	private static $defaultIconsUrl = '/themes/icons/';
-	/** @var string */
-	public static $defaultTheme = 'Origine';
+
+	private static string $themesUrl = '/themes/';
+	private static string $defaultIconsUrl = '/themes/icons/';
+	public static string $defaultTheme = 'Origine';
 
 	/** @return array<string> */
 	public static function getList(): array {
@@ -39,11 +38,12 @@ class FreshRSS_Themes extends Minz_Model {
 			if (file_exists($json_filename)) {
 				$content = file_get_contents($json_filename) ?: '';
 				$res = json_decode($content, true);
-				if ($res &&
+				if (is_array($res) &&
 						!empty($res['name']) &&
 						isset($res['files']) &&
 						is_array($res['files'])) {
 					$res['id'] = $theme_id;
+					/** @var array{'id':string,'name':string,'author':string,'description':string,'version':float|string,'files':array<string>,'theme-color'?:string|array{'dark'?:string,'light'?:string,'default'?:string}} */
 					return $res;
 				}
 			}
@@ -51,10 +51,9 @@ class FreshRSS_Themes extends Minz_Model {
 		return false;
 	}
 
-	/** @var string */
-	private static $themeIconsUrl;
+	private static string $themeIconsUrl;
 	/** @var array<string,int> */
-	private static $themeIcons;
+	private static array $themeIcons;
 
 	/**
 	 * @return false|array{'id':string,'name':string,'author':string,'description':string,'version':float|string,'files':array<string>,'theme-color'?:string|array{'dark'?:string,'light'?:string,'default'?:string}}
@@ -104,6 +103,7 @@ class FreshRSS_Themes extends Minz_Model {
 			'FreshRSS-logo' => '⊚',
 			'help' => 'ℹ️',	//ⓘ
 			'icon' => '⊚',
+			'important' => '📌',
 			'key' => '🔑',	//⚿
 			'label' => '🏷️',
 			'link' => '↗️',	//↗
@@ -156,9 +156,9 @@ class FreshRSS_Themes extends Minz_Model {
 		}
 
 		if ($type == self::ICON_DEFAULT) {
-			if ((FreshRSS_Context::$user_conf && FreshRSS_Context::$user_conf->icons_as_emojis)
+			if ((FreshRSS_Context::hasUserConf() && FreshRSS_Context::userConf()->icons_as_emojis)
 				// default to emoji alternate for some icons
-				) {
+			) {
 				$type = self::ICON_EMOJI;
 			} else {
 				$type = self::ICON_IMG;
