@@ -19,14 +19,13 @@ return array(
 		'credits_content' => 'Some design elements come from <a href="http://twitter.github.io/bootstrap/">Bootstrap</a> although FreshRSS doesn’t use this framework. <a href="https://gitlab.gnome.org/Archive/gnome-icon-theme-symbolic">Icons</a> come from the <a href="https://www.gnome.org/">GNOME project</a>. <em>Open Sans</em> font police has been created by <a href="https://fonts.google.com/specimen/Open+Sans">Steve Matteson</a>. FreshRSS is based on <a href="https://framagit.org/marienfressinaud/MINZ">Minz</a>, a PHP framework.',	// IGNORE
 		'documentation' => 'Documentation',	// IGNORE
 		'freshrss_description' => 'FreshRSS is a self-hostable RSS aggregator and reader. It allows you to read and follow several news websites at a glance without the need to browse from one website to another. FreshRSS is lightweight, configurable, and easy to use.',	// IGNORE
-		'github' => '<a href="https://github.com/FreshRSS/FreshRSS/issues">on Github</a>',	// IGNORE
+		'github' => '<a href="https://github.com/FreshRSS/FreshRSS/issues">on GitHub</a>',	// IGNORE
 		'license' => 'License',	// IGNORE
 		'project_website' => 'Project website',	// IGNORE
 		'title' => 'About',	// IGNORE
 		'version' => 'Version',	// IGNORE
 	),
 	'feed' => array(
-		'add' => 'Please add some feeds.',	// IGNORE
 		'empty' => 'There are no articles to show.',	// IGNORE
 		'rss_of' => 'RSS feed of %s',	// IGNORE
 		'title' => 'Main stream',	// IGNORE
@@ -46,6 +45,7 @@ return array(
 		'bookmark_query' => 'Bookmark current query',	// IGNORE
 		'favorites' => 'Favorites (%s)',
 		'global_view' => 'Global view',	// IGNORE
+		'important' => 'Important feeds',	// IGNORE
 		'main_stream' => 'Main stream',	// IGNORE
 		'mark_all_read' => 'Mark all as read',	// IGNORE
 		'mark_cat_read' => 'Mark category as read',	// IGNORE
