@@ -33,8 +33,9 @@ return array(
 	'display' => array(
 		'_' => 'Visualización',
 		'darkMode' => array(
-			'_' => 'Modo oscuro automatico (beta)',
-			'auto' => 'Automatico',
+			'_' => 'Modo oscuro automático',
+			'auto' => 'Automático',
+			'help' => 'Solo para temas compatibles',
 			'no' => 'No',	// IGNORE
 		),
 		'icon' => array(
@@ -56,8 +57,8 @@ return array(
 		'theme' => array(
 			'_' => 'Tema',
 			'deprecated' => array(
-				'_' => 'Deprecated',	// TODO
-				'description' => 'Este tema no tiene soporte y no volvera a estar disponible en <a href="https://freshrss.github.io/FreshRSS/en/users/05_Configuration.html#theme" target="_blank">Futuros lanzamientos de FreshRSS</a>',
+				'_' => 'Obsoleto',
+				'description' => 'Este tema no tiene soporte y no volverá a estar disponible en <a href="https://freshrss.github.io/FreshRSS/en/users/05_Configuration.html#theme" target="_blank">Futuros lanzamientos de FreshRSS</a>',
 			),
 		),
 		'theme_not_available' => 'El tema “%s” ya no está disponible. Por favor, elija otro tema.',
@@ -114,26 +115,42 @@ return array(
 	'query' => array(
 		'_' => 'Consultas de usuario',
 		'deprecated' => 'Esta consulta ya no es válida. La categoría referenciada o fuente ha sido eliminada.',
+		'description' => 'Descripción',
 		'filter' => array(
 			'_' => 'Filtro aplicado:',
 			'categories' => 'Mostrar por categoría',
-			'feeds' => 'Mostrar por feed',
+			'feeds' => 'Mostrar por fuente',
 			'order' => 'Ordenar por fecha',
 			'search' => 'Expresión',
+			'shareOpml' => 'Permitir que OPML comparta las categorías y fuentes correspondientes',
+			'shareRss' => 'Permite compartir por HTML &amp; RSS',
 			'state' => 'Estado',
 			'tags' => 'Mostrar por etiqueta',
 			'type' => 'Tipo',
 		),
 		'get_all' => 'Mostrar todos los artículos',
+		'get_all_labels' => 'Mostrar artículos con cualquier etiqueta',
 		'get_category' => 'Mostrar la categoría “%s”',
 		'get_favorite' => 'Mostrar artículos favoritos',
 		'get_feed' => 'Mostrar fuente “%s”',
+		'get_important' => 'Mostrar artículos de fuentes importantes',
+		'get_label' => 'Mostrar artículos con la etiqueta “%s”',
+		'help' => 'Ver la <a href="https://freshrss.github.io/FreshRSS/en/users/user_queries.html" target="_blank">documentación para consultas de usuarios y compartir mediante HTML / RSS / OPML</a>.',
+		'image_url' => 'URL de la imagen',
 		'name' => 'Nombre',
 		'no_filter' => 'Sin filtro',
 		'number' => 'Consulta n° %d',
 		'order_asc' => 'Mostrar primero los artículos más antiguos',
 		'order_desc' => 'Mostrar primero los artículos más recientes',
 		'search' => 'Buscar “%s”',
+		'share' => array(
+			'_' => 'Comparte esta consulta por enlace',
+			'greader' => 'Shareable link to the GReader JSON',	// TODO
+			'help' => 'Dale este enlace si quieres compartir esta consulta con alguien',
+			'html' => 'Enlace para compartir a la página HTML',
+			'opml' => 'Enlace para compartir a la lista de fuentes de OPML',
+			'rss' => 'Enlace para compartir a la fuente RSS',
+		),
 		'state_0' => 'Mostrar todos los artículos',
 		'state_1' => 'Mostrar artículos leídos',
 		'state_2' => 'Mostrar artículos pendientes',
@@ -169,7 +186,12 @@ return array(
 				'none' => 'Ninguno',
 				'with_authors' => 'En la fila de autores y fecha',
 			),
-			'feed_title' => 'Título del Feed',
+			'feed_title' => 'Título de la fuente',
+			'icons' => array(
+				'_' => 'Posición de los iconos del artículo<br /><small>(Solo en vista de lectura)</small>',
+				'above_title' => 'Encima del título',
+				'with_authors' => 'En la fila de autores y fecha',
+			),
 			'tags' => array(
 				'_' => 'Etiquetas',
 				'both' => 'En el encabezado y pie de página',
@@ -189,7 +211,7 @@ return array(
 		'display_articles_unfolded' => 'Mostrar los artículos expandidos por defecto',
 		'display_categories_unfolded' => 'Categorías a desarrollar',
 		'headline' => array(
-			'articles' => 'Artículos: Abrir/Cerar',
+			'articles' => 'Artículos: Abrir/Cerrar',
 			'articles_header_footer' => 'Artículos: encabezado/pie de página',
 			'categories' => 'Navegación izquierda: Categorías',
 			'mark_as_read' => 'Marcar artículo como leído',
@@ -204,9 +226,10 @@ return array(
 		'read' => array(
 			'article_open_on_website' => 'cuando el artículo se abra en su web original',
 			'article_viewed' => 'cuando se muestre el artículo',
+			'focus' => 'cuando tiene el foco (excepto para fuentes importantes)',
 			'keep_max_n_unread' => 'Número máximo de artículos para mantener sin leer',
-			'scroll' => 'durante el desplazamiento',
-			'upon_gone' => 'cuando ya no está disponible en el feed de noticias previo',
+			'scroll' => 'durante el desplazamiento (excepto para fuentes importantes)',
+			'upon_gone' => 'cuando ya no está disponible en la fuente de noticias previa',
 			'upon_reception' => 'al recibir el artículo',
 			'when' => 'Marcar el artículo como leído…',
 			'when_same_title' => 'Si ya existe un título idéntico en la parte superior <i>n</i> artículos más recientes',
@@ -228,6 +251,9 @@ return array(
 			'newer_first' => 'Nuevos primero',
 			'older_first' => 'Antiguos primero',
 		),
+		'star' => array(
+			'when' => 'Mark an article as favourite…',	// TODO
+		),
 		'sticky_post' => 'Pegar el artículo a la parte superior al abrirlo',
 		'title' => 'Lectura',
 		'view' => array(
@@ -240,7 +266,6 @@ return array(
 	'sharing' => array(
 		'_' => 'Compartir',
 		'add' => 'Agregar un método de uso compartido',
-		'blogotext' => 'Blogotext',	// IGNORE
 		'deprecated' => 'Este servicio está obsoleto y será removido de FreshRSS en un<a href="https://freshrss.github.io/FreshRSS/en/users/08_sharing_services.html" title="Abrir la documentación para más información" target="_blank">futuro lanzamiento</a>.',
 		'diaspora' => 'Diaspora*',	// IGNORE
 		'email' => 'Correo electrónico',
@@ -251,7 +276,7 @@ return array(
 		'remove' => 'Quitar método de uso compartido',
 		'shaarli' => 'Shaarli',	// IGNORE
 		'share_name' => 'Compartir nombre a mostrar',
-		'share_url' => 'Compatir URL a usar',
+		'share_url' => 'Compartir URL a usar',
 		'title' => 'Compartir',
 		'twitter' => 'Twitter',	// IGNORE
 		'wallabag' => 'wallabag',	// IGNORE
@@ -290,7 +315,7 @@ return array(
 		'title' => 'Atajos de teclado',
 		'toggle_media' => 'Jugar/pausar medios',
 		'user_filter' => 'Acceso a filtros de usuario',
-		'user_filter_help' => 'Si solo hay un filtro de usuario, ese será el que se use. En caso contrario, los filtros están accesibles por su númeración.',
+		'user_filter_help' => 'Si solo hay un filtro de usuario, ese será el que se use. En caso contrario, los filtros están accesibles por su numeración.',
 		'views' => 'Vistas',
 	),
 	'user' => array(
