@@ -17,16 +17,15 @@ return array(
 		'bugs_reports' => 'Informe de fallos',
 		'credits' => 'Créditos',
 		'credits_content' => 'Aunque FreshRSS no usa ese entorno, algunos elementos del diseño están obtenidos de <a href="http://twitter.github.io/bootstrap/">Bootstrap</a>. Los <a href="https://gitlab.gnome.org/Archive/gnome-icon-theme-symbolic">Iconos</a> han sido obtenidos del <a href="https://www.gnome.org/">proyecto GNOME</a>. La fuente <em>Open Sans</em> es una creación de <a href="https://fonts.google.com/specimen/Open+Sans">Steve Matteson</a>. FreshRSS usa el entorno PHP <a href="https://framagit.org/marienfressinaud/MINZ">Minz</a>.',
-		'documentation' => 'Documentacion',
+		'documentation' => 'Documentación',
 		'freshrss_description' => 'FreshRSS es un agregador de fuentes RSS de alojamiento privado. Es una herramienta potente, pero ligera y fácil de usar y configurar.',
-		'github' => '<a href="https://github.com/FreshRSS/FreshRSS/issues">en Github</a>',
+		'github' => '<a href="https://github.com/FreshRSS/FreshRSS/issues">en GitHub</a>',
 		'license' => 'Licencia',
 		'project_website' => 'Web del proyecto',
 		'title' => 'Acerca de',
 		'version' => 'Versión',
 	),
 	'feed' => array(
-		'add' => 'Puedes añadir fuentes.',
 		'empty' => 'No hay artículos a mostrar.',
 		'rss_of' => 'Fuente RSS de %s',
 		'title' => 'Salida Principal',
@@ -46,6 +45,7 @@ return array(
 		'bookmark_query' => 'Marcar consulta actual',
 		'favorites' => 'Favoritos (%s)',
 		'global_view' => 'Vista Global',
+		'important' => 'Fuentes importantes',
 		'main_stream' => 'Salida Principal',
 		'mark_all_read' => 'Marcar todo como leído',
 		'mark_cat_read' => 'Marcar categoría como leída',
@@ -64,7 +64,7 @@ return array(
 		'stats' => 'Estadísticas',
 		'subscription' => 'Administración de suscripciones',
 		'tags' => 'Mis etiquetas',
-		'unread' => 'Mostar solo no leídos',
+		'unread' => 'Mostrar solo no leídos',
 	),
 	'share' => 'Compartir',
 	'tag' => array(
