@@ -19,8 +19,8 @@ return array(
 		'http' => 'HTTP (pour utilisateurs avancés avec HTTPS)',
 		'none' => 'Aucune (dangereux)',
 		'title' => 'Authentification',
-		'token' => 'Jeton d’identification',
-		'token_help' => 'Permet d’accéder à la sortie RSS de l’utilisateur par défaut sans besoin de s’authentifier :',
+		'token' => 'Jeton d’identification maître',
+		'token_help' => 'Permet d’accéder à toutes les sorties RSS de l’utilisateur et au rafraîchissement des flux sans besoin de s’authentifier :',
 		'type' => 'Méthode d’authentification',
 		'unsafe_autologin' => 'Autoriser les connexions automatiques non-sûres au format : ',
 	),
@@ -161,7 +161,7 @@ return array(
 		'auto-update-url' => 'URL du service de mise à jour',
 		'base-url' => array(
 			'_' => 'URL de la racine',
-			'recommendation' => 'Recommandation automatique: <kbd>%s</kbd>',
+			'recommendation' => 'Recommandation automatique : <kbd>%s</kbd>',
 		),
 		'cookie-duration' => array(
 			'help' => 'en secondes',
@@ -187,12 +187,15 @@ return array(
 			),
 			'title' => 'Formulaire d’inscription utilisateur',
 		),
-		'sensitive-parameter' => 'Paramètre sensible. Éditez manuallement <kbd>./data/config.php</kbd>',
+		'sensitive-parameter' => 'Paramètre sensible. Éditez manuellement <kbd>./data/config.php</kbd>',
 		'tos' => array(
 			'disabled' => 'non renseigné',
 			'enabled' => '<a href="./?a=tos">activées</a>',
 			'help' => 'Comment <a href="https://freshrss.github.io/FreshRSS/en/admins/12_User_management.html#enable-terms-of-service-tos" target="_blank">activer les conditions d’utilisation</a>',
 		),
+		'websub' => array(
+			'help' => 'À propos de <a href="https://freshrss.github.io/FreshRSS/fr/users/08_PubSubHubbub.html" target="_blank">WebSub</a>',
+		),
 	),
 	'update' => array(
 		'_' => 'Système de mise à jour',
@@ -210,7 +213,7 @@ return array(
 			'latest' => 'Publication stable (“latest”)',
 		),
 		'title' => 'Système de mise à jour',
-		'viaGit' => 'Mise à jour via git et Github.com démarrée',
+		'viaGit' => 'Mise à jour via git et GitHub.com démarrée',
 	),
 	'user' => array(
 		'admin' => 'Administrateur',
