@@ -26,7 +26,6 @@ return array(
 		'version' => 'גרסה',
 	),
 	'feed' => array(
-		'add' => 'ניתן להוסיף הזנות חדשות.',
 		'empty' => 'אין מאמר להצגה.',
 		'rss_of' => 'הזנת RSS של %s',
 		'title' => 'הזנה ראשית',
@@ -46,6 +45,7 @@ return array(
 		'bookmark_query' => 'Bookmark current query',	// TODO
 		'favorites' => 'מועדפים (%s)',
 		'global_view' => 'תצוגה גלובלית',
+		'important' => 'Important feeds',	// TODO
 		'main_stream' => 'הזנה ראשית',
 		'mark_all_read' => 'סימון הכל כנקרא',
 		'mark_cat_read' => 'סימון קטגוריה כנקראה',
