@@ -17,9 +17,9 @@ return array(
 		'help' => '個々のフィード設定内で、より多くの設定をしていただけます。',
 		'keep_favourites' => 'お気に入りを消去しない',
 		'keep_labels' => 'ラベルを消去しない',
-		'keep_max' => '記事を保存する最大数',	// DIRTY
-		'keep_min_by_feed' => '記事をフィードに残す最小数',
-		'keep_period' => '記事を保存する最大時間',
+		'keep_max' => '各フィードに残す記事の最大数',
+		'keep_min_by_feed' => '各フィードに残す記事の最小数',
+		'keep_period' => '記事を残す最大時間',
 		'keep_unreads' => '未読の記事を消去しない',
 		'maintenance' => 'メンテナンス',
 		'optimize' => 'データベースを整理する',
@@ -33,9 +33,10 @@ return array(
 	'display' => array(
 		'_' => '表示',
 		'darkMode' => array(
-			'_' => 'Automatic dark mode (beta)',	// TODO
-			'auto' => 'Auto',	// TODO
-			'no' => 'No',	// TODO
+			'_' => '自動ダークモード',
+			'auto' => '自動',
+			'help' => '対応するテーマのみ',
+			'no' => '無効',
 		),
 		'icon' => array(
 			'bottom_line' => '行の下部',
@@ -56,11 +57,11 @@ return array(
 		'theme' => array(
 			'_' => 'テーマ',
 			'deprecated' => array(
-				'_' => 'Deprecated',	// TODO
-				'description' => 'This theme is no longer supported and will be not available anymore in a <a href="https://freshrss.github.io/FreshRSS/en/users/05_Configuration.html#theme" target="_blank">future release of FreshRSS</a>',	// TODO
+				'_' => '非推奨',
+				'description' => 'このテーマのサポートは終了しており、<a href="https://freshrss.github.io/FreshRSS/en/users/05_Configuration.html#theme" target="_blank">FreshRSSの将来のリリース</a>では利用できなくなります。',
 			),
 		),
-		'theme_not_available' => '“%s”テーマはご利用いただけません。他のテーマをお選びください。',
+		'theme_not_available' => 'テーマ“%s”はご利用いただけません。他のテーマをお選びください。',
 		'thumbnail' => array(
 			'label' => 'サムネイル',
 			'landscape' => 'ランドスケープ',
@@ -68,14 +69,14 @@ return array(
 			'portrait' => 'ポートレート',
 			'square' => '四角',
 		),
-		'timezone' => 'Time zone',	// TODO
+		'timezone' => 'タイムゾーン',
 		'title' => 'ディスプレイ',
 		'website' => array(
-			'full' => 'Icon and name',	// TODO
-			'icon' => 'Icon only',	// TODO
-			'label' => 'Website',	// TODO
-			'name' => 'Name only',	// TODO
-			'none' => 'None',	// TODO
+			'full' => 'アイコンと名前',
+			'icon' => 'アイコンのみ',
+			'label' => 'Webサイト',
+			'name' => '名前のみ',
+			'none' => 'なし',
 		),
 		'width' => array(
 			'content' => 'コンテンツ幅',
@@ -94,7 +95,7 @@ return array(
 		'pagination' => array(
 			'first' => '先頭',
 			'last' => '最後',
-			'next' => 'つぎへ',
+			'next' => '次へ',
 			'previous' => '前へ',
 		),
 	),
@@ -113,27 +114,43 @@ return array(
 	),
 	'query' => array(
 		'_' => 'ユーザークエリ',
-		'deprecated' => 'このクエリは有効ではありません。参照されているカテゴリあるいはフィードはすでに消去されました。',
+		'deprecated' => 'このクエリは有効ではありません。参照されているカテゴリやフィードはすでに消去されました。',
+		'description' => '説明',
 		'filter' => array(
 			'_' => 'フィルターを適用:',
 			'categories' => 'カテゴリごとに表示する',
 			'feeds' => 'フィードごとに表示する',
 			'order' => '日付ごとにソートする',
 			'search' => '式',
+			'shareOpml' => 'カテゴリとフィードのOPMLによる共有を有効にする',
+			'shareRss' => 'HTMLとRSSによる共有を有効にする',
 			'state' => '状態',
 			'tags' => 'タグごとに表示する',
 			'type' => 'タイプ',
 		),
-		'get_all' => 'すべての著者を表示する',
-		'get_category' => '“%s”カテゴリを表示する',
-		'get_favorite' => 'お気に入りの著者を表示する',
-		'get_feed' => '“%s”フィードを表示する',
+		'get_all' => 'すべての記事を表示する',
+		'get_all_labels' => '任意のラベルで記事を表示する',
+		'get_category' => 'カテゴリ“%s”を表示する',
+		'get_favorite' => 'お気に入りの記事を表示する',
+		'get_feed' => 'フィード“%s”を表示する',
+		'get_important' => '重要なフィードからの記事を表示する',
+		'get_label' => 'ラベル“%s”の記事を表示する',
+		'help' => 'HTML/RSS/OPMLによるユーザークエリと再共有については <a href="https://freshrss.github.io/FreshRSS/en/users/user_queries.html" target="_blank">こちら</a>をご覧ください',
+		'image_url' => '画像のURL',
 		'name' => '名前',
 		'no_filter' => 'フィルターはありません',
 		'number' => 'クエリ n°%d',
-		'order_asc' => '古い著者を最初に表示する',
-		'order_desc' => '新しい著者を最初に表示する',
+		'order_asc' => '古い記事を最初に表示する',
+		'order_desc' => '新しい記事を最初に表示する',
 		'search' => '“%s”で検索する',
+		'share' => array(
+			'_' => 'このクエリをリンクで共有する',
+			'greader' => 'Shareable link to the GReader JSON',	// TODO
+			'help' => 'このクエリを誰かと共有したい場合は、このリンクを提供してください',
+			'html' => 'HTMLページへの共有リンク',
+			'opml' => 'フィードのOPMLリストへの共有リンク',
+			'rss' => 'RSSフィードへの共有リンク',
+		),
 		'state_0' => 'すべての記事を表示する',
 		'state_1' => '既読の記事を表示する',
 		'state_2' => '未読の記事を表示する',
@@ -154,7 +171,7 @@ return array(
 	),
 	'reading' => array(
 		'_' => 'リーディング',
-		'after_onread' => 'あとで “すべてに既読を付ける”,',
+		'after_onread' => '“すべてに既読を付ける”を押した後,',
 		'always_show_favorites' => 'デフォルトですべてのお気に入りの記事を表示する',
 		'article' => array(
 			'authors_date' => array(
@@ -170,6 +187,11 @@ return array(
 				'with_authors' => '著者と日付の行',
 			),
 			'feed_title' => 'フィードのタイトル',
+			'icons' => array(
+				'_' => '記事アイコンの位置<br /><small>(リーディングビューのみ)</small>',
+				'above_title' => 'タイトルの上',
+				'with_authors' => '著者と日付の行',
+			),
 			'tags' => array(
 				'_' => 'タグ',
 				'both' => 'ヘッダーとフッター',
@@ -179,15 +201,15 @@ return array(
 			),
 			'tags_max' => array(
 				'_' => '表示されるタグの数の上限',
-				'help' => '0は:すべてのタグを表示し、折り畳めまれないことを意味します。',
+				'help' => '0に設定すると、折りたたまずにすべてのタグを表示します。',
 			),
 		),
 		'articles_per_page' => '1ページ当たりの記事の数',
 		'auto_load_more' => 'ページの下にもっと記事を読み込む',
 		'auto_remove_article' => '記事を読んだら非表示にする',
 		'confirm_enabled' => '“すべてに既読を付ける” を押したとき確認ダイアログを表示する',
-		'display_articles_unfolded' => 'デフォルトでフォルダーに入れてない記事を表示する',
-		'display_categories_unfolded' => '展開されていない記事',
+		'display_articles_unfolded' => 'デフォルトで未分類の記事を表示する',
+		'display_categories_unfolded' => '展開するカテゴリ',
 		'headline' => array(
 			'articles' => '記事: 開く/閉じる',
 			'articles_header_footer' => '記事: ヘッダー/フッター',
@@ -196,20 +218,21 @@ return array(
 			'misc' => 'その他',
 			'view' => 'ビュー',
 		),
-		'hide_read_feeds' => 'カテゴリーを非表示 & 未読の記事がないフィード ("すべてに既読を付ける”では適用しません)',
+		'hide_read_feeds' => 'カテゴリを非表示 & 未読の記事がないフィード ("すべてに既読を付ける”では適用しません)',
 		'img_with_lazyload' => '<em>lazy load</em>を写真の読み込み時に使う',
-		'jump_next' => '次の未読の姉妹記事へ移る (フィードあるいはカテゴリー)',
+		'jump_next' => '次の未読の姉妹記事へ移る (フィードやカテゴリ)',
 		'mark_updated_article_unread' => '更新された記事を未読とする',
-		'number_divided_when_reader' => 'reading viewを二分割する',
+		'number_divided_when_reader' => 'リーディングビューを2分割する',
 		'read' => array(
-			'article_open_on_website' => '記事を元のwebサイトで開いたとき',
+			'article_open_on_website' => '記事を元のWebサイトで開いたとき',
 			'article_viewed' => '記事を読んだとき',
+			'focus' => 'フォーカスしたとき (重要なフィードを除く)',
 			'keep_max_n_unread' => '未読の記事として残す最大数',
-			'scroll' => 'スクロールしているとき',
+			'scroll' => 'スクロールしているとき (重要なフィードを除く)',
 			'upon_gone' => 'ニュースフィードの提供元がなくなったとき',
 			'upon_reception' => '記事を受け取ったとき',
 			'when' => '記事を既読にする…',
-			'when_same_title' => '同一タイトルの新しい記事があるときには、上部へ表示する',
+			'when_same_title' => 'すでに同一タイトルが上位n件の最新記事に存在するとき',
 		),
 		'show' => array(
 			'_' => '記事を表示する',
@@ -217,8 +240,8 @@ return array(
 			'adaptive' => '表示を調整する',
 			'all_articles' => 'すべての記事を表示する',
 			'all_categories' => 'すべてのカテゴリ',
-			'no_category' => 'カテゴリがありません',
-			'remember_categories' => '開いたカテゴリを保存する',
+			'no_category' => '未分類',
+			'remember_categories' => '前回開いたカテゴリ',
 			'unread' => '未読のみ表示する',
 		),
 		'show_fav_unread_help' => 'ラベルも適用する',
@@ -228,20 +251,22 @@ return array(
 			'newer_first' => '最新のものを先頭にする',
 			'older_first' => '最古のものを先頭にする',
 		),
+		'star' => array(
+			'when' => 'Mark an article as favourite…',	// TODO
+		),
 		'sticky_post' => '開いたときにトップを記事にする',
 		'title' => 'リーディング',
 		'view' => array(
 			'default' => 'デフォルトビュー',
 			'global' => 'グローバルビュー',
-			'normal' => '標準ビュー',
+			'normal' => 'ノーマルビュー',
 			'reader' => 'リーディングビュー',
 		),
 	),
 	'sharing' => array(
 		'_' => '共有',
 		'add' => '共有方法を追加する',
-		'blogotext' => 'Blogotext',	// IGNORE
-		'deprecated' => 'このサービスは非推奨でFreshRSSから削除される予定です<a href="https://freshrss.github.io/FreshRSS/en/users/08_sharing_services.html" title="Open documentation for more information" target="_blank">future release</a>.',
+		'deprecated' => 'このサービスは非推奨でFreshRSSの<a href="https://freshrss.github.io/FreshRSS/en/users/08_sharing_services.html" title="Open documentation for more information" target="_blank">将来のリリース</a>から削除される予定です。',
 		'diaspora' => 'Diaspora*',	// IGNORE
 		'email' => 'Eメール',
 		'facebook' => 'Facebook',	// IGNORE
@@ -264,33 +289,33 @@ return array(
 		'close_dropdown' => 'メニューを閉じる',
 		'collapse_article' => '折りたたむ',
 		'first_article' => '初めの記事を開く',
-		'focus_search' => '共有ボックスにアクセスする',
+		'focus_search' => '検索ボックスにアクセスする',
 		'global_view' => 'グローバルビューに変更する',
 		'help' => 'ドキュメントを表示する',
 		'javascript' => 'JavaScriptはショートカットを使うときに必要です',
 		'last_article' => '最近の記事を表示する',
 		'load_more' => 'もっと記事を読み込む',
 		'mark_favorite' => 'お気に入りを切り替える',
-		'mark_read' => '読みを切り替える',
+		'mark_read' => '既読/未読を切り替える',
 		'navigation' => 'ナビゲーション',
-		'navigation_help' => '<kbd>⇧ Shift</kbd>キーを使うと, フィードにショートカットナビが表示されます。<br/><kbd>Alt ⎇</kbd> キーを使うと、カテゴリにショートカットナビが表示されます。',
-		'navigation_no_mod_help' => '次のショートカットナビは、キーボードショートカットには対応していません。',
+		'navigation_help' => '<kbd>⇧ Shift</kbd>キーとの組み合わせで、フィードをナビゲーションします。<br/><kbd>Alt ⎇</kbd> キーとの組み合わせで、カテゴリをナビゲーションします。',
+		'navigation_no_mod_help' => '以下のナビゲーションショートカットは、修飾キーをサポートしません。',
 		'next_article' => '次の記事を開く',
-		'next_unread_article' => '次に未読の記事を開く',
+		'next_unread_article' => '次の未読の記事を開く',
 		'non_standard' => '(<kbd>%s</kbd>)のキーはショートカットにはなりません。',
 		'normal_view' => 'ノーマルビューに切り替える',
 		'other_action' => 'ほかのアクション',
 		'previous_article' => '前の記事を表示する',
 		'reading_view' => 'リーディングビューに切り替える',
 		'rss_view' => 'RSSフィードとして開く',
-		'see_on_website' => '元のwebサイトを開く',
+		'see_on_website' => '元のWebサイトを開く',
 		'shift_for_all_read' => '+ <kbd>Alt ⎇</kbd>で前の記事を既読にし、<br />+ <kbd>⇧ Shift</kbd>ですべての記事を既読にします。',
-		'skip_next_article' => '次を開かないで飛ばす',
-		'skip_previous_article' => '前の記事を開かないで飛ばす',
+		'skip_next_article' => '次の記事を開かずにフォーカスする',
+		'skip_previous_article' => '前の記事を開かずにフォーカスする',
 		'title' => 'ショートカット',
 		'toggle_media' => 'メディアの 再生/停止',
-		'user_filter' => 'ユーザーのクエリにアクセスする',
-		'user_filter_help' => '一つのユーザークエリしかないとき、それが使われます。そうではなければ、番号によってクエリにアクセスできます。',
+		'user_filter' => 'ユーザークエリにアクセスする',
+		'user_filter_help' => 'ユーザークエリが一つしかなければ、それを使う。そうではなければ、番号でクエリを選択する。',
 		'views' => 'ビュー',
 	),
 	'user' => array(
