@@ -16,9 +16,9 @@ return array(
 		'agpl3' => '<a href="https://www.gnu.org/licenses/agpl-3.0.html">AGPL 3</a>',	// IGNORE
 		'bugs_reports' => 'バグレポート',
 		'credits' => 'クレジット',
-		'credits_content' => 'いくつかのデザイン要素は <a href="http://twitter.github.io/bootstrap/">Bootstrap</a>から来ています。しかしFreshRSSはこのフレームワークを使用していません。 <a href="https://gitlab.gnome.org/Archive/gnome-icon-theme-symbolic">アイコン</a> は <a href="https://www.gnome.org/">GNOME プロジェクトから作られています</a>。 <em>Open Sans</em> フォントは <a href="https://fonts.google.com/specimen/Open+Sans">Steve Matteson によって作成されました</a>。 FreshRSS は<a href="https://framagit.org/marienfressinaud/MINZ">Minz</a>,PHP フレームワークをもとにしています。',
-		'documentation' => 'Documentation',	// TODO
-		'freshrss_description' => 'FreshRSSは なセルフホストできるRSSフィード収集ツールです。強力なツールになっており、軽量で簡単に使え、豊富な設定が特徴です。',
+		'credits_content' => 'いくつかのデザイン要素は<a href="http://twitter.github.io/bootstrap/">Bootstrap</a>に由来しますが、FreshRSSはこのフレームワークを使用していません。<a href="https://gitlab.gnome.org/Archive/gnome-icon-theme-symbolic">アイコン</a>は<a href="https://www.gnome.org/">GNOMEプロジェクト</a>に由来します。<em>Open Sans</em>フォントは<a href="https://fonts.google.com/specimen/Open+Sans">Steve Matteson</a>によって作成されました。FreshRSSはPHPフレームワークの<a href="https://framagit.org/marienfressinaud/MINZ">Minz</a>を採用しています。',
+		'documentation' => 'ドキュメント',
+		'freshrss_description' => 'FreshRSSはセルフホストできるRSSフィード収集ツールです。強力なツールで、軽量で簡単に使え、豊富な設定が特徴です。',
 		'github' => '<a href="https://github.com/FreshRSS/FreshRSS/issues">Githubへお願いします</a>',
 		'license' => 'ライセンス',
 		'project_website' => 'プロジェクトのwebサイト',
@@ -26,7 +26,6 @@ return array(
 		'version' => 'バージョン',
 	),
 	'feed' => array(
-		'add' => 'フィードを追加してください。',
 		'empty' => '表示できる記事がありません',
 		'rss_of' => '%s のRSSフィード',
 		'title' => 'メイン',
@@ -46,25 +45,26 @@ return array(
 		'bookmark_query' => '現在のブックマーククエリ',
 		'favorites' => 'お気に入り (%s)',
 		'global_view' => 'グローバルビュー',
+		'important' => '重要なフィード',
 		'main_stream' => 'メイン',
-		'mark_all_read' => 'すべての記事に既読をつける',
-		'mark_cat_read' => 'カテゴリーに既読をつける',
-		'mark_feed_read' => 'フィードに既読をつける',
-		'mark_selection_unread' => '選択したものに未読をつける',
-		'newer_first' => '最新のものを先にする',
-		'non-starred' => 'お気に入りに登録されてないものを表示する',
+		'mark_all_read' => 'すべての記事を既読にする',
+		'mark_cat_read' => 'カテゴリを既読にする',
+		'mark_feed_read' => 'フィードを既読にする',
+		'mark_selection_unread' => '選択した記事を未読にする',
+		'newer_first' => '最新の記事を先頭にする',
+		'non-starred' => 'お気に入りに登録されてない記事を表示する',
 		'normal_view' => 'ノーマルビュー',
-		'older_first' => '最古のものを先にする',
+		'older_first' => '最古の記事を先頭にする',
 		'queries' => 'ユーザークエリ',
-		'read' => '読み取りを表示する',
+		'read' => '既読の記事を表示する',
 		'reader_view' => 'リーディングビュー',
 		'rss_view' => 'RSSフィード',
 		'search_short' => '検索',
 		'starred' => 'お気に入りを表示する',
 		'stats' => '統計',
-		'subscription' => '購読されたものの管理',
+		'subscription' => '購読フィードの管理',
 		'tags' => 'ラベル',
-		'unread' => '未読のものを表示する',
+		'unread' => '未読の記事を表示する',
 	),
 	'share' => '共有',
 	'tag' => array(
