@@ -29,7 +29,9 @@ return array(
 			'help' => '<a href="http://opml.org/" target="_blank">から提供されたOPMLファイル</a>をこのカテゴリに動的に追加します。',
 		),
 		'empty' => 'からのカテゴリ',
+		'expand' => 'Expand category',	// TODO
 		'information' => 'インフォメーション',
+		'open' => 'Open category',	// TODO
 		'opml_url' => 'OPMLのURL',
 		'position' => '表示位置',
 		'position_help' => 'カテゴリの表示順を操作する',
@@ -57,18 +59,23 @@ return array(
 		),
 		'css_cookie' => '記事のコンテンツを読み出したとき、クッキーを使用する',
 		'css_cookie_help' => '例: <kbd>foo=bar; gdpr_consent=true; cookie=value</kbd>',
-		'css_help' => '失敗したRSSフィードを再取得します (ただし、多くの時間が必要になります!)',
-		'css_path' => '元のwebサイトのCSS',
+		'css_help' => '省略されたRSSフィードを復元します (ただし、時間がかかります)',
+		'css_path' => '元のWebサイトから記事を抽出するCSSセレクタ',
 		'css_path_filter' => array(
-			'_' => '削除される要素をCSSで選ぶ',
-			'help' => 'CSSセレクタは: <kbd> フッターやアサイド要素をリストにできます</kbd>',
+			'_' => '要素を削除するCSSセレクタ',
+			'help' => 'CSSセレクタは次のようなリストです: <kbd>.footer, .aside</kbd>',
 		),
 		'description' => '説明',
 		'empty' => 'このフィードは空です。サイトが運営されているかどうかを確認してみてください。',
 		'error' => 'このフィードに問題が発生しました。ここでアクセスできるかどうかを確認して更新してみてください。',
+		'export-as-opml' => array(
+			'download' => 'ダウンロード',
+			'help' => 'XMLファイル (データのサブセット。<a href="https://freshrss.github.io/FreshRSS/en/developers/OPML.html" target="_blank">ドキュメントを参照してください</a>。)',
+			'label' => 'OPMLとしてエクスポート',
+		),
 		'filteractions' => array(
 			'_' => 'フィルターアクション',
-			'help' => '1行に1つの検索フィルターを設定してください Operators <a href="https://freshrss.github.io/FreshRSS/en/users/10_filter.html#with-the-search-field" target="_blank">see documentation</a>.',	// DIRTY
+			'help' => '1行に1つの検索フィルターを設定してください。演算子は<a href="https://freshrss.github.io/FreshRSS/en/users/10_filter.html#with-the-search-field" target="_blank">ドキュメントを参照してください</a>。',
 		),
 		'information' => 'インフォメーション',
 		'keep_min' => '最小数の記事は保持されます',
@@ -78,15 +85,15 @@ return array(
 				'_' => 'HTML + XPath (ウェブスクレイピング)',
 				'feed_title' => array(
 					'_' => 'フィードタイトル',
-					'help' => '例: <code>//タイトル</code>あるいは文字列定数: <code>"カスタムフィード"</code>',
+					'help' => '例: <code>//title</code> または文字列定数: <code>"カスタムフィード"</code>',
 				),
 				'help' => '<dfn><a href="https://www.w3.org/TR/xpath-10/" target="_blank">XPath 1.0</a></dfn> は上級者向けのクエリ型言語で、FreshRSSでスクレイピングをサポートしている言語です。',
 				'item' => array(
-					'_' => 'ニュース<strong>の項目を探す</strong><br /><small>(最も重要)</small>',
+					'_' => 'ニュース<strong>項目</strong>を探す<br /><small>(最も重要)</small>',
 					'help' => '例: <code>//div[@class="news-item"]</code>',
 				),
 				'item_author' => array(
-					'_' => '著者',
+					'_' => '項目の著者',
 					'help' => 'これもまた、文字定数が使えます。例: <code>"匿名"</code>',
 				),
 				'item_categories' => '項目のタグ',
@@ -99,16 +106,16 @@ return array(
 					'help' => '例: <code>descendant::img/@src</code>',
 				),
 				'item_timeFormat' => array(
-					'_' => 'Custom date/time format',	// TODO
-					'help' => 'Optional. A format supported by <a href="https://php.net/datetime.createfromformat" target="_blank"><code>DateTime::createFromFormat()</code></a> such as <code>d-m-Y H:i:s</code>',	// TODO
+					'_' => 'カスタム日時フォーマット',
+					'help' => 'オプションです。<a href="https://php.net/datetime.createfromformat" target="_blank"><code>DateTime::createFromFormat()</code></a>でサポートされている書式で、<code>d-m-Y H:i:s</code>のように指定します',
 				),
 				'item_timestamp' => array(
 					'_' => '項目の日付',
-					'help' => '結果は<a href="https://php.net/strtotime" target="_blank"><code>strtotime()</code></a>によってパースされます',
+					'help' => '結果は<a href="https://php.net/strtotime" target="_blank"><code>strtotime()</code></a>で解析されます',
 				),
 				'item_title' => array(
 					'_' => '項目のタイトル',
-					'help' => '特に<a href="https://developer.mozilla.org/docs/Web/XPath/Axes" target="_blank">XPath アクシスを</a> <code>descendant::</code> ように使います <code>descendant::h2</code>',
+					'help' => '特に<a href="https://developer.mozilla.org/docs/Web/XPath/Axes" target="_blank">XPath Axis</a>の <code>descendant::</code> を <code>descendant::h2</code> のように使います',
 				),
 				'item_uid' => array(
 					'_' => '項目のユニークID',
@@ -118,33 +125,82 @@ return array(
 					'_' => '項目のリンク(URL)',
 					'help' => '例: <code>descendant::a/@href</code>',
 				),
-				'relative' => 'XPath (関連する項目):',
-				'xpath' => 'XPathは:',
+				'relative' => 'XPath (項目からの相対パス):',
+				'xpath' => 'XPath:',
 			),
+			'json_dotnotation' => array(
+				'_' => 'JSON（ドット記法）',
+				'feed_title' => array(
+					'_' => 'フィード名',
+					'help' => '例: <code>meta.title</code> または静的文字列: <code>"My custom feed"</code>',
+				),
+				'help' => 'JSONのドット記法は、オブジェクトの間にドットを使用し、配列には括弧を使用します。例: <code>data.items[0].title</code>',
+				'item' => array(
+					'_' => 'ニュース<strong>項目</strong>を探す<br /><small>(最重要)</small>',
+					'help' => '項目を含む配列へのJSONパス。 例: <code>newsItems</code>',
+				),
+				'item_author' => '項目の著者',
+				'item_categories' => '項目のタグ',
+				'item_content' => array(
+					'_' => '項目のコンテンツ',
+					'help' => 'コンテンツが存在するキー。例: <code>content</code>',
+				),
+				'item_thumbnail' => array(
+					'_' => '項目のサムネイル',
+					'help' => '例: <code>image</code>',
+				),
+				'item_timeFormat' => array(
+					'_' => 'カスタム日時フォーマット',
+					'help' => 'オプションです。<a href="https://php.net/datetime.createfromformat" target="_blank"><code>DateTime::createFromFormat()</code></a>でサポートされている書式で、<code>d-m-Y H:i:s</code>のように指定します',
+				),
+				'item_timestamp' => array(
+					'_' => '項目の日付',
+					'help' => '結果は<a href="https://php.net/strtotime" target="_blank"><code>strtotime()</code></a>で解析されます',
+				),
+				'item_title' => '項目のタイトル',
+				'item_uid' => '項目のユニークID',
+				'item_uri' => array(
+					'_' => '項目のリンク（URL）',
+					'help' => '例: <code>permalink</code>',
+				),
+				'json' => 'ドット記法:',
+				'relative' => 'ドット記法（項目からの相対パス）:',
+			),
+			'jsonfeed' => 'JSONフィード',
 			'rss' => 'RSS / Atom (標準)',
-			'xml_xpath' => 'XML + XPath',	// TODO
+			'xml_xpath' => 'XML + XPath',	// IGNORE
 		),
 		'maintenance' => array(
 			'clear_cache' => 'キャッシュのクリア',
 			'clear_cache_help' => 'このフィードのキャッシュをクリアします。',
 			'reload_articles' => '記事を再読み込みする',
-			'reload_articles_help' => '記事を再読み込みして、セレクターが定義したコンテンツを完全に取得します。',	// DIRTY
+			'reload_articles_help' => '指定した数の記事を再読み込みし、セレクターが定義されていればコンテンツを完全に取得します。',
 			'title' => 'メンテナンス',
 		),
 		'max_http_redir' => 'HTTPのリダイレクトの上限',
 		'max_http_redir_help' => '0を設定するか、空白のままにすると無効になり、-1を設定するとリダイレクト数が無制限になります。',
+		'method' => array(
+			'_' => 'HTTPメソッド',
+		),
+		'method_help' => 'POSTペイロードは <code>application/x-www-form-urlencoded</code> と <code>application/json</code> を自動的にサポートしています',
+		'method_postparams' => 'POST用ペイロード',
 		'moved_category_deleted' => 'カテゴリを削除したとき、フィードは自動的に<em>%s</em>下に分類されます。',
-		'mute' => 'ミュート',
+		'mute' => array(
+			'_' => 'ミュート',
+			'state_is_muted' => 'This feed is muted',	// TODO
+		),
 		'no_selected' => 'どのフィードも選択されていません',
 		'number_entries' => '%d 記事数',
+		'open_feed' => 'Open feed %s',	// TODO
 		'priority' => array(
 			'_' => '表示する場所',
 			'archived' => '非表示にする(アーカイブ)',
+			'category' => 'カテゴリで表示する',
+			'important' => '重要なフィードに表示する',
 			'main_stream' => 'メインストリームで表示する',
-			'normal' => 'カテゴリで表示する',
 		),
 		'proxy' => 'フィードを読み込み時にproxyを設定してください',
-		'proxy_help' => 'プロトコルを選択し (例: SOCKS5) proxyアドレスを入力してください (例: <kbd>127.0.0.1:1080</kbd>)',
+		'proxy_help' => 'プロトコルを選択し (例: SOCKS5) プロキシアドレスを入力してください (例: <kbd>127.0.0.1:1080</kbd> や <kbd>username:password@127.0.0.1:1080</kbd>)',
 		'selector_preview' => array(
 			'show_raw' => 'ソースコードを表示する',
 			'show_rendered' => 'コンテンツを表示する',
@@ -176,14 +232,14 @@ return array(
 		'export_opml' => 'フィードリストをエクスポートする (OPML)',
 		'export_starred' => 'お気に入りをエクスポートする',
 		'feed_list' => '%s 記事のリスト',
-		'file_to_import' => 'インポートするファイル<br />(OPML, JSON あるいは ZIP)',
-		'file_to_import_no_zip' => 'インポートするファイル<br />(OPML あるいは JSON)',
+		'file_to_import' => 'インポートするファイル<br />(OPML, JSON または ZIP)',
+		'file_to_import_no_zip' => 'インポートするファイル<br />(OPML または JSON)',
 		'import' => 'インポート',
 		'starred_list' => 'お気に入りの記事',
 		'title' => 'インポート / エクスポート',
 	),
 	'menu' => array(
-		'add' => 'フィード化カテゴリを追加します',
+		'add' => 'フィードやカテゴリを追加',
 		'import_export' => 'インポート / エクスポート',
 		'label_management' => 'ラベル管理',
 		'stats' => array(
@@ -191,17 +247,18 @@ return array(
 			'main' => '主な統計',
 			'repartition' => '記事の仕切り',
 		),
-		'subscription_management' => '購読されたものの管理',
+		'subscription_management' => '購読フィードの管理',
 		'subscription_tools' => '購読ツール',
 	),
 	'tag' => array(
+		'auto_label' => 'このラベルを新しい記事に追加する',
 		'name' => '名前',
 		'new_name' => '新しい名前',
 		'old_name' => '古い名前',
 	),
 	'title' => array(
-		'_' => '購読されたものの管理',
-		'add' => 'フィードあるいはカテゴリを追加します',
+		'_' => '購読フィードの管理',
+		'add' => 'フィードやカテゴリを追加',
 		'add_category' => 'カテゴリの追加',
 		'add_dynamic_opml' => '動的なOPMLを追加する',
 		'add_feed' => 'フィードの追加',
