@@ -17,16 +17,15 @@ return array(
 		'bugs_reports' => '버그 제보하기',
 		'credits' => '크레딧',
 		'credits_content' => 'FreshRSS는 <a href="http://twitter.github.io/bootstrap/">Bootstrap</a> 프레임워크를 사용하진 않지만, 일부 디자인 요소를 가져왔습니다. <a href="https://gitlab.gnome.org/Archive/gnome-icon-theme-symbolic">아이콘들</a>은 <a href="https://www.gnome.org/">GNOME 프로젝트</a>에서 가져왔습니다. <em>Open Sans</em> 글꼴은 <a href="https://fonts.google.com/specimen/Open+Sans">Steve Matteson</a>가 제작하였습니다. FreshRSS는 PHP 프레임워크인 <a href="https://framagit.org/marienfressinaud/MINZ">Minz</a>에 기반하고 있습니다.',
-		'documentation' => 'Documentation',	// TODO
+		'documentation' => '문서',
 		'freshrss_description' => 'FreshRSS는 같은 셀프 호스팅 기반의 RSS 피드 수집기입니다. FreshRSS는 강력하고 다양한 설정을 할 수 있으면서도 가볍고 사용하기 쉽습니다.',
-		'github' => '<a href="https://github.com/FreshRSS/FreshRSS/issues">Github 저장소에 제보</a>',
+		'github' => '<a href="https://github.com/FreshRSS/FreshRSS/issues">GitHub 저장소에 제보</a>',
 		'license' => '라이센스',
 		'project_website' => '프로젝트 웹사이트',
 		'title' => '정보',
 		'version' => '버전',
 	),
 	'feed' => array(
-		'add' => '피드를 추가하세요.',
 		'empty' => '글이 없습니다.',
 		'rss_of' => '%s의 피드',
 		'title' => '메인 스트림',
@@ -46,6 +45,7 @@ return array(
 		'bookmark_query' => '현재 쿼리 북마크',
 		'favorites' => '즐겨찾기 (%s)',
 		'global_view' => '전체 모드',
+		'important' => '중요 피드',
 		'main_stream' => '메인 스트림',
 		'mark_all_read' => '모두 읽음으로 표시',
 		'mark_cat_read' => '카테고리를 읽음으로 표시',
