@@ -16,9 +16,9 @@ return array(
 		'exception' => 'Regras de exceção da limpeza',
 		'help' => 'Mais opções estão disponíveis nas configurações individuais do Feed',
 		'keep_favourites' => 'Nunca deletar os favoritos',
-		'keep_labels' => 'Nunca deletar etiquetas',
+		'keep_labels' => 'Nunca deletar tags',
 		'keep_max' => 'Número máximo de artigos para manter no feed',
-		'keep_min_by_feed' => 'Número mínimo de artigos para deixar no feed',
+		'keep_min_by_feed' => 'Número mínimo de artigos para manter no feed',
 		'keep_period' => 'Idade máxima dos artigos a serem mantidos',
 		'keep_unreads' => 'Nunca apagar os não lidos',
 		'maintenance' => 'Manutenção',
@@ -33,9 +33,10 @@ return array(
 	'display' => array(
 		'_' => 'Exibição',
 		'darkMode' => array(
-			'_' => 'Automatic dark mode (beta)',	// TODO
-			'auto' => 'Auto',	// TODO
-			'no' => 'No',	// TODO
+			'_' => 'Modo noturno automático',
+			'auto' => 'Automático',
+			'help' => 'For compatible themes only',	// TODO
+			'no' => 'Não',
 		),
 		'icon' => array(
 			'bottom_line' => 'Linha inferior',
@@ -56,8 +57,8 @@ return array(
 		'theme' => array(
 			'_' => 'Tema',
 			'deprecated' => array(
-				'_' => 'Deprecated',	// TODO
-				'description' => 'This theme is no longer supported and will be not available anymore in a <a href="https://freshrss.github.io/FreshRSS/en/users/05_Configuration.html#theme" target="_blank">future release of FreshRSS</a>',	// TODO
+				'_' => 'Depreciado',
+				'description' => 'Este tema não é mais suportado e não estará mais disponível em <a href="https://freshrss.github.io/FreshRSS/en/users/05_Configuration.html#theme" target="_blank">uma versão futura do FreshRSS</a>',
 			),
 		),
 		'theme_not_available' => 'O tema “%s” não está mais disponível. Por favor escolha outro tema.',
@@ -68,14 +69,14 @@ return array(
 			'portrait' => 'Modo retrato',
 			'square' => 'Modo quadrado',
 		),
-		'timezone' => 'Time zone',	// TODO
+		'timezone' => 'Fuso horário',
 		'title' => 'Exibição',
 		'website' => array(
-			'full' => 'Icon and name',	// TODO
-			'icon' => 'Icon only',	// TODO
-			'label' => 'Website',	// TODO
-			'name' => 'Name only',	// TODO
-			'none' => 'None',	// TODO
+			'full' => 'Ícone e nome',
+			'icon' => 'Apenas ícone',
+			'label' => 'Site',
+			'name' => 'Apenas nome',
+			'none' => 'Nenhum',
 		),
 		'width' => array(
 			'content' => 'Largura do conteúdo',
@@ -112,28 +113,44 @@ return array(
 		'title' => 'Perfil',
 	),
 	'query' => array(
-		'_' => 'Queries do usuário',
+		'_' => 'Consultas do usuário',
 		'deprecated' => 'Esta não é mais válida. A categoria ou feed relacionado foi deletado.',
+		'description' => 'Description',	// TODO
 		'filter' => array(
 			'_' => 'Filtro aplicado:',
 			'categories' => 'Exibir por categoria',
 			'feeds' => 'Exibir por feed',
 			'order' => 'Ordenar por data',
 			'search' => 'Expressão',
+			'shareOpml' => 'Habilita o compartilhamento por OPML de categorias e feeds correspondentes',
+			'shareRss' => 'Habilita o compartilhamento por HTML &amp; RSS',
 			'state' => 'Estado',
-			'tags' => 'Exibir por tag',	// DIRTY
+			'tags' => 'Exibir por tag',
 			'type' => 'Tipo',
 		),
 		'get_all' => 'Mostrar todos os artigos',
+		'get_all_labels' => 'Exibir artigos com qualquer rótulo',
 		'get_category' => 'Visualizar “%s” categoria',
 		'get_favorite' => 'Visualizar artigos favoritos',
 		'get_feed' => 'Visualizar “%s” feed',
+		'get_important' => 'Exibir artigos de feeds importantes',
+		'get_label' => 'Exibir artigos com rótulo “%s”',
+		'help' => 'Veja a <a href="https://freshrss.github.io/FreshRSS/en/users/user_queries.html" target="_blank">documentação para consultas de usuários e recompartilhamentos por HTML / RSS / OPML</a>.',
+		'image_url' => 'Image URL',	// TODO
 		'name' => 'Nome',
 		'no_filter' => 'Sem filtro',
-		'number' => 'Query n°%d',	// IGNORE
+		'number' => 'Consulta n°%d',
 		'order_asc' => 'Exibir artigos mais antigos primeiro',
 		'order_desc' => 'Exibir artigos mais novos primeiro',
 		'search' => 'Busca por “%s”',
+		'share' => array(
+			'_' => 'Compartilhar esta consulta por link',
+			'greader' => 'Shareable link to the GReader JSON',	// TODO
+			'help' => 'Forneça este link se quiser compartilhar esta consulta com alguém',
+			'html' => 'Link compartilhável para a página HTML',
+			'opml' => 'Link compartilhável para a lista de feeds OPML',
+			'rss' => 'Link compartilhável para o feed RSS',
+		),
 		'state_0' => 'Exibir todos os artigos',
 		'state_1' => 'Exibir artigos lidos',
 		'state_2' => 'Exibir artigos não lidos',
@@ -150,7 +167,7 @@ return array(
 		'state_13' => 'Exibir artigos lidos',
 		'state_14' => 'Exibir artigos não lidos',
 		'state_15' => 'Exibir todos os artigos',
-		'title' => 'Queries de usuários',
+		'title' => 'Consultas de usuários',
 	),
 	'reading' => array(
 		'_' => 'Leitura',
@@ -165,21 +182,26 @@ return array(
 				'none' => 'Nenhum',
 			),
 			'feed_name' => array(
-				'above_title' => 'Acima do titulo/etiqueta',
+				'above_title' => 'Acima do título/etiqueta',
 				'none' => 'Nenhum',
 				'with_authors' => 'Com autores e data',
 			),
-			'feed_title' => 'Titulo do Feed',
+			'feed_title' => 'Título do Feed',
+			'icons' => array(
+				'_' => 'Article icons position<br /><small>(Reading view only)</small>',	// TODO
+				'above_title' => 'Above title',	// TODO
+				'with_authors' => 'In authors and date row',	// TODO
+			),
 			'tags' => array(
-				'_' => 'Etiqueta',
+				'_' => 'Tag',
 				'both' => 'No cabeçalho e rodapé',
 				'footer' => 'No rodapé',
 				'header' => 'No cabeçalho',
 				'none' => 'Nenhum',
 			),
 			'tags_max' => array(
-				'_' => 'Número máximo de etiquetas exibidas',
-				'help' => '0 significa: mostrar todas as etiquetas e não recolhê-las',
+				'_' => 'Número máximo de tags exibidas',
+				'help' => '0 significa: mostrar todas as tags e não recolhê-las',
 			),
 		),
 		'articles_per_page' => 'Número de artigos por página',
@@ -204,12 +226,13 @@ return array(
 		'read' => array(
 			'article_open_on_website' => 'quando o artigo é aberto no site original',
 			'article_viewed' => 'Quando o artigo é visualizado',
+			'focus' => 'quando focado (exceto por feeds importantes)',
 			'keep_max_n_unread' => 'Número máximo de artigos para manter como não lido',
-			'scroll' => 'enquanto scrolling',
-			'upon_gone' => 'QUuando não estiver mais no feed de noticiais principais',
+			'scroll' => 'enquanto faz a rolagem (exceto por feeds importantes)',
+			'upon_gone' => 'Quando não estiver mais no feed de notícias principais',
 			'upon_reception' => 'ao receber um artigo',
 			'when' => 'Marcar artigo como lido…',
-			'when_same_title' => 'Se um título idêntico já existir nos últimos<i>n</i> artigos mais novos',
+			'when_same_title' => 'Se um título idêntico já existir nos últimos <i>n</i> artigos mais novos',
 		),
 		'show' => array(
 			'_' => 'Artigos para exibir',
@@ -221,13 +244,16 @@ return array(
 			'remember_categories' => 'lembrar de abrir as categorias',
 			'unread' => 'Exibir apenas não lido',
 		),
-		'show_fav_unread_help' => 'Aplicar também nas etiquetas',
+		'show_fav_unread_help' => 'Aplicar também nas tags',
 		'sides_close_article' => 'Clicando fora da área do texto do artigo fecha o mesmo',
 		'sort' => array(
 			'_' => 'Ordem de visualização',
 			'newer_first' => 'Novos primeiro',
 			'older_first' => 'Antigos primeiro',
 		),
+		'star' => array(
+			'when' => 'Mark an article as favourite…',	// TODO
+		),
 		'sticky_post' => 'Coloque o artigo no topo quando aberto',
 		'title' => 'Lendo',
 		'view' => array(
@@ -240,13 +266,12 @@ return array(
 	'sharing' => array(
 		'_' => 'Compartilhando',
 		'add' => 'Adicionar um método de compartilhamento',
-		'blogotext' => 'Blogotext',	// IGNORE
 		'deprecated' => 'Este serviço está obceloeto e será removido do FreshRSS <a href="https://freshrss.github.io/FreshRSS/en/users/08_sharing_services.html" title="Abra este documento para mais informações" target="_blank">em versões futuras</a>.',
 		'diaspora' => 'Diaspora*',	// IGNORE
 		'email' => 'E-mail',
 		'facebook' => 'Facebook',	// IGNORE
 		'more_information' => 'Mais informação',
-		'print' => 'Imprimir',	// IGNORE
+		'print' => 'Imprimir',
 		'raindrop' => 'Raindrop.io',	// IGNORE
 		'remove' => 'Remover método de compartilhamento',
 		'shaarli' => 'Shaarli',	// IGNORE
