@@ -29,7 +29,9 @@ return array(
 			'help' => 'Forneça uma URL para <a href="http://opml.org/" target="_blank">o arquivo OPML </a> para preencher dinamicamente esta categoria com feeds',
 		),
 		'empty' => 'Categoria vazia',
+		'expand' => 'Expand category',	// TODO
 		'information' => 'Informações',
+		'open' => 'Open category',	// TODO
 		'opml_url' => 'URL de OPML',
 		'position' => 'Posição de exibição',
 		'position_help' => 'Para controlar a ordem de exibição',
@@ -66,6 +68,11 @@ return array(
 		'description' => 'Descrição',
 		'empty' => 'Este feed está vazio. Por favor verifique ele ainda é mantido.',
 		'error' => 'Este feed encontra-se com problema. Por favor verifique se ele ainda está disponível e atualize-o.',
+		'export-as-opml' => array(
+			'download' => 'Download',	// IGNORE
+			'help' => 'Arquivo XML (data subset. <a href="https://freshrss.github.io/FreshRSS/en/developers/OPML.html" target="_blank">See documentation</a>)',	// DIRTY
+			'label' => 'Exportar como OPML',
+		),
 		'filteractions' => array(
 			'_' => 'Ações do filtro',
 			'help' => 'Escreva um filtro de pesquisa por linha. Operators <a href="https://freshrss.github.io/FreshRSS/en/users/10_filter.html#with-the-search-field" target="_blank">see documentation</a>.',	// DIRTY
@@ -121,30 +128,79 @@ return array(
 				'relative' => 'XPath (relativo do item) para:',
 				'xpath' => 'XPath para:',
 			),
+			'json_dotnotation' => array(
+				'_' => 'JSON (notação de ponto)',
+				'feed_title' => array(
+					'_' => 'título do feed',
+					'help' => 'Exemplo: <code>meta.title</code> ou uma string estática: <code>"Meu feed customizado"</code>',
+				),
+				'help' => 'Um JSON na notação de ponto usa pontos entre os objetos e colchetes para arrays (e.g. <code>data.items[0].title</code>)',
+				'item' => array(
+					'_' => 'encontrando novidades <strong>itens</strong><br /><small>(mais importante)</small>',
+					'help' => 'Caminho do JSON para o array contendo os itens, e.g. <code>newsItems</code>',
+				),
+				'item_author' => 'autor do item',
+				'item_categories' => 'tags dos itens',
+				'item_content' => array(
+					'_' => 'conteúdo do item',
+					'help' => 'Chave sob na qual o conteúdo é encontrado, e.g. <code>content</code>',
+				),
+				'item_thumbnail' => array(
+					'_' => 'miniatura do item',
+					'help' => 'Exemplo: <code>image</code>',
+				),
+				'item_timeFormat' => array(
+					'_' => 'Formato de data/hora customizado',
+					'help' => 'Opcional. Um formato suportado por <a href="https://php.net/datetime.createfromformat" target="_blank"><code>DateTime::createFromFormat()</code></a> assim como <code>d-m-Y H:i:s</code>',
+				),
+				'item_timestamp' => array(
+					'_' => 'data do item',
+					'help' => 'The result will be parsed by <a href="https://php.net/strtotime" target="_blank"><code>strtotime()</code></a>',	// TODO
+				),
+				'item_title' => 'título do item',
+				'item_uid' => 'ID único do item',
+				'item_uri' => array(
+					'_' => 'Link do item (URL)',
+					'help' => 'Exemplo: <code>permalink</code>',
+				),
+				'json' => 'notação de ponto para:',
+				'relative' => 'notação de ponto (relativa ao item) para:',
+			),
+			'jsonfeed' => 'JSON Feed',	// IGNORE
 			'rss' => 'RSS / Atom (padrão)',
-			'xml_xpath' => 'XML + XPath',	// TODO
+			'xml_xpath' => 'XML + XPath',	// IGNORE
 		),
 		'maintenance' => array(
 			'clear_cache' => 'Limpar o cache',
 			'clear_cache_help' => 'Limpar o cache em disco deste feed',
 			'reload_articles' => 'Recarregar artigos',
-			'reload_articles_help' => 'Recarregar artigos e buscar conteúdo completo',	// DIRTY
+			'reload_articles_help' => 'Recarregar artigos e buscar conteúdo completo',
 			'title' => 'Manutenção',
 		),
 		'max_http_redir' => 'Quantidade máxima de redirecionamentos HTTP',
 		'max_http_redir_help' => 'Defina como 0 ou deixe em branco para desabilitar, -1 para redirecionamentos ilimitados',
+		'method' => array(
+			'_' => 'Método HTTP',
+		),
+		'method_help' => 'O conteúdo do POST tem suporte automático para <code>application/x-www-form-urlencoded</code> e <code>application/json</code>',
+		'method_postparams' => 'Conteúdo do POST',
 		'moved_category_deleted' => 'Quando você deleta uma categoria, seus feeds são automaticamente classificados como <em>%s</em>.',
-		'mute' => 'silenciar',
+		'mute' => array(
+			'_' => 'silenciar',
+			'state_is_muted' => 'This feed is muted',	// TODO
+		),
 		'no_selected' => 'Nenhum feed selecionado.',
 		'number_entries' => '%d artigos',
+		'open_feed' => 'Open feed %s',	// TODO
 		'priority' => array(
 			'_' => 'Visibilidade',
 			'archived' => 'Não exibir (arquivado)',
+			'category' => 'Mostrar na sua categoria',
+			'important' => 'Mostrar feeds importantes',
 			'main_stream' => 'Mostrar na tela principal',
-			'normal' => 'Mostrar na sua categoria',
 		),
 		'proxy' => 'Defina um proxy para buscar esse feed',
-		'proxy_help' => 'Selecione um protocolo (e.g: SOCKS5) e digite o endereço do proxy (e.g: <kbd>127.0.0.1:1080</kbd>)',
+		'proxy_help' => 'Selecione um protocolo (e.g: SOCKS5) e digite o endereço do proxy (e.g: <kbd>127.0.0.1:1080</kbd> or <kbd>username:password@127.0.0.1:1080</kbd>)',
 		'selector_preview' => array(
 			'show_raw' => 'Mostrar fonte',
 			'show_rendered' => 'Mostrar conteúdo',
@@ -195,6 +251,7 @@ return array(
 		'subscription_tools' => 'Ferramentas de inscrição',
 	),
 	'tag' => array(
+		'auto_label' => 'Adicione esta etiqueta para novos artigos',
 		'name' => 'Nome',
 		'new_name' => 'Nome novo',
 		'old_name' => 'Nome antigo',
