@@ -16,7 +16,7 @@ return array(
 		'title' => 'API',	// IGNORE
 	),
 	'bookmarklet' => array(
-		'documentation' => 'Перетяните эту кнопку на вашу панель закладок, или нажмите правой кнопкой мыши и выберите "Добавить ссылку в закладки". Нажимайте кнопку "Подписаться" на любой странице, на которую вы хотите подписаться.<br>',
+		'documentation' => 'Перетяните эту кнопку на вашу панель закладок, или нажмите правой кнопкой мыши и выберите "Добавить ссылку в закладки". Нажимайте кнопку "Подписаться" на любой странице, на которую вы хотите подписаться.<br />',
 		'label' => 'Подписаться',
 		'title' => 'Букмарклет',
 	),
@@ -29,7 +29,9 @@ return array(
 			'help' => 'Предоставьте ссылку на <a href="http://opml.org/" target="_blank">OPML файл</a> чтобы динамично заполнять эту категорию лентами',
 		),
 		'empty' => 'Пустая категория',
+		'expand' => 'Expand category',	// TODO
 		'information' => 'Информация',
+		'open' => 'Open category',	// TODO
 		'opml_url' => 'OPML ссылка',
 		'position' => 'Положение отображения',
 		'position_help' => 'Влияет на порядок отображения категорий',
@@ -66,9 +68,14 @@ return array(
 		'description' => 'Описание',
 		'empty' => 'Лента пустая. Пожалуйста, убедитесь, что её до сих пор обслуживают.',
 		'error' => 'С этой лентой возникла проблема. Пожалуйста, убедитесь, что она всегда досягаема. Затем снова обновите её.',
+		'export-as-opml' => array(
+			'download' => 'Скачать',
+			'help' => 'XML файл (data subset. <a href="https://freshrss.github.io/FreshRSS/en/developers/OPML.html" target="_blank">See documentation</a>)',	// DIRTY
+			'label' => 'Экспортировать как OPML',
+		),
 		'filteractions' => array(
 			'_' => 'Действия фильтрации',
-			'help' => 'Введите по одному поисковому фильтру в строке. Operators <a href="https://freshrss.github.io/FreshRSS/en/users/10_filter.html#with-the-search-field" target="_blank">see documentation</a>.',	// DIRTY
+			'help' => 'Введите по одному поисковому фильтру в строке. См. <a href="https://freshrss.github.io/FreshRSS/en/users/10_filter.html#with-the-search-field" target="_blank">документацию</a>.',
 		),
 		'information' => 'Информация',
 		'keep_min' => 'Оставлять статей не менее',
@@ -121,8 +128,47 @@ return array(
 				'relative' => 'XPath (относительно элемента) для:',
 				'xpath' => 'XPath для:',
 			),
+			'json_dotnotation' => array(
+				'_' => 'JSON (точечная нотация)',
+				'feed_title' => array(
+					'_' => 'название ленты',
+					'help' => 'Пример: <code>meta.title</code> или статический текст: <code>"Моя пользовательская лента"</code>',
+				),
+				'help' => 'JSON с точечной нотацией использует точки между объектами и квадратные скобки для массивов (например: <code>data.items[0].title</code>)',
+				'item' => array(
+					'_' => 'Найти новые <strong>элементы</strong><br /><small>(самое важное)</small>',
+					'help' => 'JSON-путь к массиву, содержащему элементы, например: <code>newsItems</code>',
+				),
+				'item_author' => 'автор элемента',
+				'item_categories' => 'теги элемента',
+				'item_content' => array(
+					'_' => 'содержимое элемента',
+					'help' => 'Ключ, по которому найден контент, например: <code>content</code>',
+				),
+				'item_thumbnail' => array(
+					'_' => 'эскиз элемента',
+					'help' => 'Пример: <code>image</code>',
+				),
+				'item_timeFormat' => array(
+					'_' => 'Пользовательский формат даты/времени',
+					'help' => 'Выборочно. Формат, поддерживаемый <a href="https://php.net/datetime.createfromformat" target="_blank"><code>DateTime::createFromFormat()</code></a>, например <code>d-m-Y H:i:s</code>',
+				),
+				'item_timestamp' => array(
+					'_' => 'дата элемента',
+					'help' => 'Результат будет распарсен используя <a href="https://php.net/strtotime" target="_blank"><code>strtotime()</code></a>',
+				),
+				'item_title' => 'название элемента',
+				'item_uid' => 'уникальный ID элемента',
+				'item_uri' => array(
+					'_' => 'ссылка на элемент (URL)',
+					'help' => 'Пример: <code>permalink</code>',
+				),
+				'json' => 'точечная нотация для:',
+				'relative' => 'JSON-путь (относительный до элемента) для:',
+			),
+			'jsonfeed' => 'JSON Лента',
 			'rss' => 'RSS / Atom (по умолчанию)',
-			'xml_xpath' => 'XML + XPath',	// TODO
+			'xml_xpath' => 'XML + XPath',	// IGNORE
 		),
 		'maintenance' => array(
 			'clear_cache' => 'Очистить кэш',
@@ -133,18 +179,28 @@ return array(
 		),
 		'max_http_redir' => 'Максимум HTTP переводов',
 		'max_http_redir_help' => 'Установите 0 или оставьте пустым, чтобы отключить, -1 для бесконечных переводов',
+		'method' => array(
+			'_' => 'HTTP метод',
+		),
+		'method_help' => 'Полезная нагрузка POST автоматически поддерживает <code>application/x-www-form-urlencoded</code> и <code>application/json</code>',
+		'method_postparams' => 'Полезная нагрузка POST',
 		'moved_category_deleted' => 'Когда вы удаляете категорию, ленты категории автоматически попадают в категорию <em>%s</em>.',
-		'mute' => 'заглушить',
+		'mute' => array(
+			'_' => 'заглушить',
+			'state_is_muted' => 'This feed is muted',	// TODO
+		),
 		'no_selected' => 'Ленты не выбраны.',
 		'number_entries' => '%d статей',
+		'open_feed' => 'Open feed %s',	// TODO
 		'priority' => array(
 			'_' => 'Видимость',
 			'archived' => 'Не показывать (архивировано)',
+			'category' => 'Показывать в категории ленты',
+			'important' => 'Показывать в важных лентах',
 			'main_stream' => 'Показывать в основном потоке',
-			'normal' => 'Показывать в категории ленты',
 		),
 		'proxy' => 'Указать прокси для извлечения этой ленты',
-		'proxy_help' => 'Выберите протокол (например, SOCKS5) и введите адрес прокси (например, <kbd>127.0.0.1:1080</kbd>)',
+		'proxy_help' => 'Выберите протокол (например, SOCKS5) и введите адрес прокси (например, <kbd>127.0.0.1:1080</kbd> или <kbd>username:password@127.0.0.1:1080</kbd>)',	// DIRTY
 		'selector_preview' => array(
 			'show_raw' => 'Показать исходный код',
 			'show_rendered' => 'Показать содержимое',
@@ -195,6 +251,7 @@ return array(
 		'subscription_tools' => 'Инструменты подписки',
 	),
 	'tag' => array(
+		'auto_label' => 'Добавьте это название к новым статьям',
 		'name' => 'Название',
 		'new_name' => 'Новое название',
 		'old_name' => 'Старое название',
