@@ -17,16 +17,15 @@ return array(
 		'bugs_reports' => 'Nahlásiť chybu',
 		'credits' => 'Poďakovanie',
 		'credits_content' => 'Niektoré časti vzhľadu pochádzajú z <a href="http://twitter.github.io/bootstrap/">Bootstrap</a>u, aj keď FreshRSS tento framework nepoužíva. <a href="https://gitlab.gnome.org/Archive/gnome-icon-theme-symbolic">Ikony</a> sú z <a href="https://www.gnome.org/">GNOME project</a>. Font <em>Open Sans</em> zabezpečil <a href="https://fonts.google.com/specimen/Open+Sans">Steve Matteson</a>. FreshRSS je založený na PHP frameworku <a href="https://framagit.org/marienfressinaud/MINZ">Minz</a>.',
-		'documentation' => 'Documentation',	// TODO
+		'documentation' => 'Dokumentácia',
 		'freshrss_description' => 'FreshRSS je čítačka RSS kanálov, ktorú môžete nasadiť na vlastný server. Ide o jednoduchý a zároveň dobre nastaviteľný nástroj.',
-		'github' => '<a href="https://github.com/FreshRSS/FreshRSS/issues">na Github</a>e',
+		'github' => '<a href="https://github.com/FreshRSS/FreshRSS/issues">na GitHub</a>e',
 		'license' => 'Licencia',
 		'project_website' => 'Webová stránka projektu',
 		'title' => 'O FreshRSS',
 		'version' => 'Verzia',
 	),
 	'feed' => array(
-		'add' => 'Môžete pridať kanály.',
 		'empty' => 'Žiadne články.',
 		'rss_of' => 'RSS kanál pre %s',
 		'title' => 'Všetky kanály',
@@ -46,6 +45,7 @@ return array(
 		'bookmark_query' => 'Pridať aktuálny dopyt do obľúbených',
 		'favorites' => 'Obľúbené (%s)',
 		'global_view' => 'Prehľad',
+		'important' => 'Dôležité kanály',
 		'main_stream' => 'Všetky kanály',
 		'mark_all_read' => 'Označiť všetko ako prečítané',
 		'mark_cat_read' => 'Označiť kategóriu ako prečítanú',
