@@ -17,16 +17,15 @@ return array(
 		'bugs_reports' => 'Hata raporu',
 		'credits' => 'Tanıtım',
 		'credits_content' => 'Bu frameworkü kullanmamasına rağmen FreshRSS bazı tasarım ögelerini <a href="http://twitter.github.io/bootstrap/">Bootstrap</a> dan almıştır. <a href="https://gitlab.gnome.org/Archive/gnome-icon-theme-symbolic">İkonlar</a> <a href="https://www.gnome.org/">GNOME projesinden</a> alınmıştır. <em>Open Sans</em> yazı tipi <a href="https://fonts.google.com/specimen/Open+Sans">Steve Matteson</a> tarafından oluşturulmuştur. FreshRSS bir PHP framework olan <a href="https://framagit.org/marienfressinaud/MINZ">Minz</a> i temel alır.',
-		'documentation' => 'Documentation',	// TODO
+		'documentation' => 'Dökümantasyon',
 		'freshrss_description' => 'FreshRSS kendi hostunuzda çalışan bir RSS akış toplayıcısıdır. Güçlü ve yapılandırılabilir araçlarıyla basit ve kullanımı kolay bir uygulamadır.',
-		'github' => '<a href="https://github.com/FreshRSS/FreshRSS/issues">Github sayfası</a>',
+		'github' => '<a href="https://github.com/FreshRSS/FreshRSS/issues">GitHub sayfası</a>',
 		'license' => 'Lisans',
 		'project_website' => 'Proje sayfası',
 		'title' => 'Hakkında',
 		'version' => 'Sürüm',
 	),
 	'feed' => array(
-		'add' => 'Akış ekleyebilirsin.',
 		'empty' => 'Gösterilecek makale yok.',
 		'rss_of' => '%s kaynağına ait RSS akışı',
 		'title' => 'Ana akış',
@@ -46,6 +45,7 @@ return array(
 		'bookmark_query' => 'Şuana ait yer imi sorgusu',
 		'favorites' => 'Favoriler (%s)',
 		'global_view' => 'Evrensel görünüm',
+		'important' => 'Önemli akışlar',
 		'main_stream' => 'Ana akış',
 		'mark_all_read' => 'Hepsini okundu olarak işaretle',
 		'mark_cat_read' => 'Kategoriyi okundu olarak işaretle',
