@@ -29,7 +29,9 @@ return array(
 			'help' => '使用 URL 上的 <a href="http://opml.org/" target="_blank">OPML 文件</a> 中的订阅源填充这一分类',
 		),
 		'empty' => '空分类',
+		'expand' => 'Expand category',	// TODO
 		'information' => '信息',
+		'open' => 'Open category',	// TODO
 		'opml_url' => 'OPML URL',	// IGNORE
 		'position' => '显示位置',
 		'position_help' => '控制分类排列顺序',
@@ -66,9 +68,14 @@ return array(
 		'description' => '描述',
 		'empty' => '此源为空。请确认它是否正常更新。',
 		'error' => '此源遇到一些问题。请在确认是否能正常访问后重试。',
+		'export-as-opml' => array(
+			'download' => '下载',
+			'help' => 'XML 文件 (data subset. <a href="https://freshrss.github.io/FreshRSS/en/developers/OPML.html" target="_blank">See documentation</a>)',	// DIRTY
+			'label' => '导出为 OPML',
+		),
 		'filteractions' => array(
 			'_' => '过滤动作',
-			'help' => '每行写一条过滤搜索 Operators <a href="https://freshrss.github.io/FreshRSS/en/users/10_filter.html#with-the-search-field" target="_blank">see documentation</a>.',	// DIRTY
+			'help' => '每行写一条过滤规则，过滤规则可见 <a href="https://freshrss.github.io/FreshRSS/en/users/10_filter.html#with-the-search-field" target="_blank">文档</a>。',
 		),
 		'information' => '信息',
 		'keep_min' => '至少保存的文章数',
@@ -121,8 +128,47 @@ return array(
 				'relative' => 'XPath（文章）：',
 				'xpath' => 'XPath 定位：',
 			),
+			'json_dotnotation' => array(
+				'_' => 'JSON (点表达式)',
+				'feed_title' => array(
+					'_' => '订阅源标题',
+					'help' => '例如: <code>meta.title</code> 或一个静态的字符串: <code>"My custom feed"</code>',
+				),
+				'help' => 'JSON 点表达式（JSON 路径）在对象之间使用点，在数组中使用中括号 (例如 <code>data.items[0].title</code>)',
+				'item' => array(
+					'_' => '寻找新的 <strong>文章</strong><br /><small>(最重要的参数)</small>',
+					'help' => '包含文章数组的 JSON 路径， 例如 <code>newsItems</code>',
+				),
+				'item_author' => '文章作者',
+				'item_categories' => '文章标签',
+				'item_content' => array(
+					'_' => '文章内容',
+					'help' => '用于找到文章内容的键, 例如 <code>content</code>',
+				),
+				'item_thumbnail' => array(
+					'_' => '文章缩略图',
+					'help' => '例如: <code>image</code>',
+				),
+				'item_timeFormat' => array(
+					'_' => '自定义时间格式',
+					'help' => '可选项. 被 <a href="https://php.net/datetime.createfromformat" target="_blank"><code>DateTime::createFromFormat()</code></a> 支持的日期格式。例如 <code>d-m-Y H:i:s</code>',
+				),
+				'item_timestamp' => array(
+					'_' => '文章时间',
+					'help' => '结果会被 <a href="https://php.net/strtotime" target="_blank"><code>strtotime()</code></a> 解析',
+				),
+				'item_title' => '文章标题',
+				'item_uid' => '文章唯一ID',
+				'item_uri' => array(
+					'_' => '文章链接 (URL)',
+					'help' => '例如: <code>permalink</code>',
+				),
+				'json' => 'JSON 路径：',
+				'relative' => 'JSON 路径（相对于文章）：',
+			),
+			'jsonfeed' => 'JSON 订阅源',
 			'rss' => 'RSS / Atom (默认)',
-			'xml_xpath' => 'XML + XPath',	// TODO
+			'xml_xpath' => 'XML + XPath',	// IGNORE
 		),
 		'maintenance' => array(
 			'clear_cache' => '清理缓存',
@@ -133,18 +179,28 @@ return array(
 		),
 		'max_http_redir' => '最大 HTTP 重定向',
 		'max_http_redir_help' => '设置为 0 或留空以禁用，-1 表示无限重定向',
+		'method' => array(
+			'_' => 'HTTP 方式',
+		),
+		'method_help' => '如果荷载非空且是合法的 JSON，HTTP 请求标头将被自动设为 <code>application/json</code>，否则使用 <code>application/x-www-form-urlencoded</code>',
+		'method_postparams' => 'POST 荷载',
 		'moved_category_deleted' => '删除分类时，其中的订阅源会自动归类到 <em>%s</em>',
-		'mute' => '暂停',
+		'mute' => array(
+			'_' => '暂停',
+			'state_is_muted' => 'This feed is muted',	// TODO
+		),
 		'no_selected' => '未选择订阅源',
 		'number_entries' => '%d 篇文章',
+		'open_feed' => 'Open feed %s',	// TODO
 		'priority' => array(
 			'_' => '可见性',
 			'archived' => '不显示（归档）',
+			'category' => '在分类中显示',
+			'important' => '在“重要的订阅”中显示',
 			'main_stream' => '在首页中显示',
-			'normal' => '在分类中显示',
 		),
 		'proxy' => '获取订阅源时的代理',
-		'proxy_help' => '选择协议（例：SOCKS5）和代理地址（例：<kbd>127.0.0.1:1080</kbd>）',
+		'proxy_help' => '选择协议（例：SOCKS5）和代理地址（例：<kbd>127.0.0.1:1080</kbd> 或者 <kbd>username:password@127.0.0.1:1080</kbd>）',
 		'selector_preview' => array(
 			'show_raw' => '显示源码',
 			'show_rendered' => '显示内容',
@@ -195,6 +251,7 @@ return array(
 		'subscription_tools' => '订阅工具',
 	),
 	'tag' => array(
+		'auto_label' => '给新文章打标签',
 		'name' => '名称',
 		'new_name' => '新名称',
 		'old_name' => '旧名称',
@@ -205,7 +262,7 @@ return array(
 		'add_category' => '添加分类',
 		'add_dynamic_opml' => '添加订阅源动态列表',
 		'add_feed' => '添加订阅源',
-		'add_label' => '添加标签',
+		'add_label' => '打标签',
 		'delete_label' => '删除标签',
 		'feed_management' => '订阅源管理',
 		'rename_label' => '重命名标签',
