@@ -16,11 +16,11 @@ return array(
 		'allow_anonymous_refresh' => '允許匿名刷新文章',
 		'api_enabled' => '允許 <abbr>API</abbr> 訪問 <small>（用於手機應用）</small>',
 		'form' => '網頁表單（傳統方式, 需要 JavaScript)',
-		'http' => 'HTTP（面向啟用 HTTPS 的高級用戶)',
+		'http' => 'HTTP (對於HTTPS的進階使用者)',
 		'none' => '無認證（危險）',
 		'title' => '認證',
-		'token' => '認證口令',
-		'token_help' => '用於不經認證訪問預設使用者的 RSS 輸出：',
+		'token' => '主要驗證權杖',
+		'token_help' => '允許存取使用者的所有 RSS 輸出以及重整源而無需身份驗證:',
 		'type' => '認證方式',
 		'unsafe_autologin' => '允許不安全的自動登入方式：',
 	),
@@ -160,8 +160,8 @@ return array(
 		'_' => '系統配置',
 		'auto-update-url' => '自動升級伺服器地址',
 		'base-url' => array(
-			'_' => 'Base URL',	// TODO
-			'recommendation' => 'Automatic recommendation: <kbd>%s</kbd>',	// TODO
+			'_' => '基本URL',
+			'recommendation' => '自動推薦: <kbd>%s</kbd>',
 		),
 		'cookie-duration' => array(
 			'help' => '單位（秒）',
@@ -178,7 +178,7 @@ return array(
 				'option' => array(
 					'noform' => '禁用，無註冊表單',
 					'nolimit' => '啟用，且無帳號限制',
-					'setaccountsnumber' => '設置用戶數的最大值',
+					'setaccountsnumber' => '設置使用者數的最大值',
 				),
 			),
 			'status' => array(
@@ -187,35 +187,38 @@ return array(
 			),
 			'title' => '使用者註冊表單',
 		),
-		'sensitive-parameter' => 'Sensitive parameter. Edit manually in <kbd>./data/config.php</kbd>',	// TODO
+		'sensitive-parameter' => '敏感參數。手動編輯於 <kbd>./data/config.php</kbd>',
 		'tos' => array(
-			'disabled' => 'is not given',	// TODO
-			'enabled' => '<a href="./?a=tos">is enabled</a>',	// TODO
-			'help' => 'How to <a href="https://freshrss.github.io/FreshRSS/en/admins/12_User_management.html#enable-terms-of-service-tos" target="_blank">enable the Terms of Service</a>',	// TODO
+			'disabled' => '未被給予',
+			'enabled' => '<a href="./?a=tos">為啟用的</a>',
+			'help' => '如何 <a href="https://freshrss.github.io/FreshRSS/en/admins/12_User_management.html#enable-terms-of-service-tos" target="_blank">啟用服務條款</a>',
+		),
+		'websub' => array(
+			'help' => '關於 <a href="https://freshrss.github.io/FreshRSS/en/users/WebSub.html" target="_blank">WebSub</a>',
 		),
 	),
 	'update' => array(
 		'_' => '更新系統',
 		'apply' => '應用',
-		'changelog' => 'Changelog',	// TODO
+		'changelog' => '更新紀錄',
 		'check' => '檢查更新',
-		'copiedFromURL' => 'update.php copied from %s to ./data',	// TODO
+		'copiedFromURL' => 'update.php 複製從 %s 至 ./data',
 		'current_version' => '當前 版本為',
 		'last' => '上次檢查',
-		'loading' => 'Updating…',	// TODO
+		'loading' => '更新中…',
 		'none' => '沒有可用更新',
 		'releaseChannel' => array(
-			'_' => 'Release channel',	// TODO
-			'edge' => 'Rolling release (“edge”)',	// TODO
-			'latest' => 'Stable release (“latest”)',	// TODO
+			'_' => '發佈通道',
+			'edge' => '滾動式發佈(“edge”)',
+			'latest' => '穩定式發佈(“latest”)',
 		),
 		'title' => '系統更新',
-		'viaGit' => 'Update via git and Github.com started',	// TODO
+		'viaGit' => '從git並由GitHub.com開始',
 	),
 	'user' => array(
 		'admin' => '管理員',
 		'article_count' => '文章數',
-		'back_to_manage' => '← 返回用戶列表',
+		'back_to_manage' => '← 返回使用者列表',
 		'create' => '新增使用者',
 		'database_size' => '資料庫大小',
 		'email' => '郵箱地址',
