@@ -29,7 +29,9 @@ return array(
 			'help' => '使用地址上的 <a href="http://opml.org/" target="_blank">OPML 文件</a> 中的訂閱源填充這一分類',
 		),
 		'empty' => '空分類',
-		'information' => '信息',
+		'expand' => '展開分類',
+		'information' => '資訊',
+		'open' => '打開分類',
 		'opml_url' => 'OPML 地址',
 		'position' => '顯示位置',
 		'position_help' => '控制分類排列順序',
@@ -66,6 +68,11 @@ return array(
 		'description' => '描述',
 		'empty' => '此源為空。請確認它是否正常更新。',
 		'error' => '此源遇到一些問題。請在確認是否能正常訪問後重試。',
+		'export-as-opml' => array(
+			'download' => '下載',
+			'help' => 'XML file (data subset. <a href="https://freshrss.github.io/FreshRSS/en/developers/OPML.html" target="_blank">See documentation</a>)',	// TODO
+			'label' => '匯出為OPML',
+		),
 		'filteractions' => array(
 			'_' => '過濾動作',
 			'help' => '每行寫一條過濾搜尋 Operators <a href="https://freshrss.github.io/FreshRSS/en/users/10_filter.html#with-the-search-field" target="_blank">see documentation</a>.',	// DIRTY
@@ -89,7 +96,7 @@ return array(
 					'_' => '文章作者',
 					'help' => '可以是靜態字元串，例如 <code>"Anonymous"</code>',
 				),
-				'item_categories' => '文章標簽',
+				'item_categories' => '文章標籤',
 				'item_content' => array(
 					'_' => '文章內容',
 					'help' => '例如使用 <code>.</code> 將整個對象作為文章內容',
@@ -99,8 +106,8 @@ return array(
 					'help' => '例如 <code>descendant::img/@src</code>',
 				),
 				'item_timeFormat' => array(
-					'_' => 'Custom date/time format',	// TODO
-					'help' => 'Optional. A format supported by <a href="https://php.net/datetime.createfromformat" target="_blank"><code>DateTime::createFromFormat()</code></a> such as <code>d-m-Y H:i:s</code>',	// TODO
+					'_' => '自訂日期/時間格式',
+					'help' => '可選的。支援的格式<a href="https://php.net/datetime.createfromformat" target="_blank"><code>DateTime::createFromFormat()</code></a> 例如 <code>d-m-Y H:i:s</code>',
 				),
 				'item_timestamp' => array(
 					'_' => '文章日期：',
@@ -121,7 +128,46 @@ return array(
 				'relative' => 'XPath（文章）：',
 				'xpath' => 'XPath 定位：',
 			),
-			'rss' => 'RSS / Atom (默認)',
+			'json_dotnotation' => array(
+				'_' => 'JSON (點「.」符號)',
+				'feed_title' => array(
+					'_' => '源標題',
+					'help' => '範例: <code>meta.title</code> 或固定的字串: <code>"My custom feed"</code>',
+				),
+				'help' => 'A JSON dot notated uses dots between objects and brackets for arrays (e.g. <code>data.items[0].title</code>)',	// TODO
+				'item' => array(
+					'_' => '找尋新聞 <strong>項目</strong><br /><small>(最重要的)</small>',
+					'help' => 'JSON path to the array containing the items, e.g. <code>newsItems</code>',	// TODO
+				),
+				'item_author' => '項目作者',
+				'item_categories' => '項目標籤',
+				'item_content' => array(
+					'_' => '項目內容',
+					'help' => '可以在其下方找到內容的關鍵字, e.g. <code>content</code>',
+				),
+				'item_thumbnail' => array(
+					'_' => '項目縮圖',
+					'help' => '範例: <code>image</code>',
+				),
+				'item_timeFormat' => array(
+					'_' => '自訂 日期/時間 格式',
+					'help' => '選用項目。 支援以<a href="https://php.net/datetime.createfromformat" target="_blank"><code>DateTime::createFromFormat()</code></a> 表達的格式，例如 <code>d-m-Y H:i:s</code>',
+				),
+				'item_timestamp' => array(
+					'_' => '項目日期',
+					'help' => 'The result will be parsed by <a href="https://php.net/strtotime" target="_blank"><code>strtotime()</code></a>',	// TODO
+				),
+				'item_title' => '項目標題',
+				'item_uid' => '項目專用ID',
+				'item_uri' => array(
+					'_' => '項目連結(URL)',
+					'help' => '範例: <code>永久連結</code>',
+				),
+				'json' => 'dot notation for:',	// TODO
+				'relative' => 'dot notated path (relative to item) for:',	// TODO
+			),
+			'jsonfeed' => 'JSON Feed',	// TODO
+			'rss' => 'RSS / Atom (預設)',
 			'xml_xpath' => 'XML + XPath',	// TODO
 		),
 		'maintenance' => array(
@@ -133,18 +179,28 @@ return array(
 		),
 		'max_http_redir' => '最大 HTTP 重定向',
 		'max_http_redir_help' => '設置為 0 或留空以禁用，-1 表示無限重定向',
+		'method' => array(
+			'_' => 'HTTP 方法',
+		),
+		'method_help' => 'The POST payload has automatic support for <code>application/x-www-form-urlencoded</code> and <code>application/json</code>',	// TODO
+		'method_postparams' => 'Payload for POST',	// TODO
 		'moved_category_deleted' => '刪除分類時，其中的訂閱源會自動歸類到 <em>%s</em>',
-		'mute' => '暫停',
+		'mute' => array(
+			'_' => '暫停',
+			'state_is_muted' => 'This feed is muted',	// TODO
+		),
 		'no_selected' => '未選擇訂閱源',
 		'number_entries' => '%d 篇文章',
+		'open_feed' => 'Open feed %s',	// TODO
 		'priority' => array(
 			'_' => '可見性',
 			'archived' => '不顯示（歸檔）',
+			'category' => '在分類中顯示',
+			'important' => '顯示在重要的源',
 			'main_stream' => '在首頁中顯示',
-			'normal' => '在分類中顯示',
 		),
 		'proxy' => '獲取訂閱源時的代理',
-		'proxy_help' => '選擇協議（例：SOCKS5）和代理地址（例：<kbd>127.0.0.1:1080</kbd>）',
+		'proxy_help' => '選擇協議（例：SOCKS5）和代理地址（例：<kbd>127.0.0.1:1080</kbd> or <kbd>username:password@127.0.0.1:1080</kbd>）',	// DIRTY
 		'selector_preview' => array(
 			'show_raw' => '顯示源碼',
 			'show_rendered' => '顯示內容',
@@ -172,7 +228,7 @@ return array(
 	),
 	'import_export' => array(
 		'export' => '導出',
-		'export_labelled' => '導出有標簽的文章',
+		'export_labelled' => '導出有標籤的文章',
 		'export_opml' => '導出訂閱源列表（OPML）',
 		'export_starred' => '導出你的收藏',
 		'feed_list' => '%s 文章列表',
@@ -185,7 +241,7 @@ return array(
 	'menu' => array(
 		'add' => '添加訂閱源或分類',
 		'import_export' => '導入/導出',
-		'label_management' => '標簽管理',
+		'label_management' => '標籤管理',
 		'stats' => array(
 			'idle' => '長期無更新訂閱源',
 			'main' => '主要統計',
@@ -195,6 +251,7 @@ return array(
 		'subscription_tools' => '訂閱工具',
 	),
 	'tag' => array(
+		'auto_label' => '新增標籤給新文章',
 		'name' => '名稱',
 		'new_name' => '新名稱',
 		'old_name' => '舊名稱',
@@ -205,10 +262,10 @@ return array(
 		'add_category' => '添加分類',
 		'add_dynamic_opml' => '添加訂閱源動態列表',
 		'add_feed' => '添加訂閱源',
-		'add_label' => '添加標簽',
-		'delete_label' => '刪除標簽',
+		'add_label' => '添加標籤',
+		'delete_label' => '刪除標籤',
 		'feed_management' => '訂閱源管理',
-		'rename_label' => '重命名標簽',
+		'rename_label' => '重命名標籤',
 		'subscription_tools' => '訂閱工具',
 	),
 );
