@@ -1,4 +1,6 @@
 <?php
+declare(strict_types=1);
+
 if (function_exists('opcache_reset')) {
 	opcache_reset();
 }
@@ -27,15 +29,15 @@ function initTranslate(): void {
 	Minz_Translate::init();
 	$available_languages = Minz_Translate::availableLanguages();
 
-	if (Minz_Session::param('language') == '') {
+	if (Minz_Session::paramString('language') == '') {
 		Minz_Session::_param('language', get_best_language());
 	}
 
-	if (!in_array(Minz_Session::param('language'), $available_languages, true)) {
+	if (!in_array(Minz_Session::paramString('language'), $available_languages, true)) {
 		Minz_Session::_param('language', 'en');
 	}
 
-	Minz_Translate::reset(Minz_Session::param('language'));
+	Minz_Translate::reset(Minz_Session::paramString('language'));
 }
 
 function get_best_language(): string {
@@ -68,20 +70,20 @@ function saveStep1(): void {
 
 		// First, we try to get previous configurations
 		FreshRSS_Context::initSystem();
-		FreshRSS_Context::initUser(FreshRSS_Context::$system_conf->default_user, false);
+		FreshRSS_Context::initUser(FreshRSS_Context::systemConf()->default_user, false);
 
 		// Then, we set $_SESSION vars
 		Minz_Session::_params([
-				'title' => FreshRSS_Context::$system_conf->title,
-				'auth_type' => FreshRSS_Context::$system_conf->auth_type,
-				'default_user' => Minz_User::name(),
-				'passwordHash' => FreshRSS_Context::$user_conf->passwordHash,
-				'bd_type' => FreshRSS_Context::$system_conf->db['type'] ?? '',
-				'bd_host' => FreshRSS_Context::$system_conf->db['host'] ?? '',
-				'bd_user' => FreshRSS_Context::$system_conf->db['user'] ?? '',
-				'bd_password' => FreshRSS_Context::$system_conf->db['password'] ?? '',
-				'bd_base' => FreshRSS_Context::$system_conf->db['base'] ?? '',
-				'bd_prefix' => FreshRSS_Context::$system_conf->db['prefix'] ?? '',
+				'title' => FreshRSS_Context::systemConf()->title,
+				'auth_type' => FreshRSS_Context::systemConf()->auth_type,
+				'default_user' => Minz_User::name() ?? '',
+				'passwordHash' => FreshRSS_Context::userConf()->passwordHash,
+				'bd_type' => FreshRSS_Context::systemConf()->db['type'] ?? '',
+				'bd_host' => FreshRSS_Context::systemConf()->db['host'] ?? '',
+				'bd_user' => FreshRSS_Context::systemConf()->db['user'] ?? '',
+				'bd_password' => FreshRSS_Context::systemConf()->db['password'] ?? '',
+				'bd_base' => FreshRSS_Context::systemConf()->db['base'] ?? '',
+				'bd_prefix' => FreshRSS_Context::systemConf()->db['prefix'] ?? '',
 				'bd_error' => false,
 			]);
 
@@ -91,7 +93,7 @@ function saveStep1(): void {
 
 function saveStep2(): void {
 	if (!empty($_POST)) {
-		if (Minz_Session::param('bd_type') === 'sqlite') {
+		if (Minz_Session::paramString('bd_type') === 'sqlite') {
 			Minz_Session::_params([
 					'bd_base' => false,
 					'bd_host' => false,
@@ -114,9 +116,6 @@ function saveStep2(): void {
 					'bd_prefix' => substr($_POST['prefix'], 0, 16),
 				]);
 		}
-		if (Minz_Session::param('bd_type') === 'pgsql') {
-			Minz_Session::_param('bd_base', strtolower(Minz_Session::param('bd_base')));
-		}
 
 		// We use dirname to remove the /i part
 		$base_url = dirname(Minz_Request::guessBaseUrl());
@@ -125,18 +124,18 @@ function saveStep2(): void {
 			'base_url' => $base_url,
 			'default_user' => '_',
 			'db' => [
-				'type' => Minz_Session::param('bd_type'),
-				'host' => Minz_Session::param('bd_host'),
-				'user' => Minz_Session::param('bd_user'),
-				'password' => Minz_Session::param('bd_password'),
-				'base' => Minz_Session::param('bd_base'),
-				'prefix' => Minz_Session::param('bd_prefix'),
+				'type' => Minz_Session::paramString('bd_type'),
+				'host' => Minz_Session::paramString('bd_host'),
+				'user' => Minz_Session::paramString('bd_user'),
+				'password' => Minz_Session::paramString('bd_password'),
+				'base' => Minz_Session::paramString('bd_base'),
+				'prefix' => Minz_Session::paramString('bd_prefix'),
 				'pdo_options' => [],
 			],
 			'pubsubhubbub_enabled' => Minz_Request::serverIsPublic($base_url),
 		];
-		if (Minz_Session::param('title') != '') {
-			$config_array['title'] = Minz_Session::param('title');
+		if (Minz_Session::paramString('title') != '') {
+			$config_array['title'] = Minz_Session::paramString('title');
 		}
 
 		$customConfigPath = DATA_PATH . '/config.custom.php';
@@ -177,7 +176,7 @@ function saveStep2(): void {
 		if ($ok) {
 			Minz_Session::_param('bd_error');
 			header('Location: index.php?step=3');
-		} elseif (Minz_Session::param('bd_error') == '') {
+		} elseif (Minz_Session::paramString('bd_error') == '') {
 			Minz_Session::_param('bd_error', 'Unknown error!');
 		}
 	}
@@ -186,50 +185,51 @@ function saveStep2(): void {
 
 function saveStep3(): bool {
 	FreshRSS_Context::initSystem();
-	Minz_Translate::init(Minz_Session::param('language'));
+	Minz_Translate::init(Minz_Session::paramString('language'));
 
 	if (!empty($_POST)) {
-		if (param('auth_type', 'form') != '') {
-			FreshRSS_Context::$system_conf->auth_type = param('auth_type', 'form');
-			Minz_Session::_param('auth_type', FreshRSS_Context::$system_conf->auth_type);
+		$auth_type = param('auth_type', 'form');
+		if (in_array($auth_type, ['form', 'http_auth', 'none'], true)) {
+			FreshRSS_Context::systemConf()->auth_type = $auth_type;
+			Minz_Session::_param('auth_type', FreshRSS_Context::systemConf()->auth_type);
 		} else {
 			return false;
 		}
 
 		$password_plain = param('passwordPlain', '');
-		if (FreshRSS_Context::$system_conf->auth_type === 'form' && $password_plain == '') {
+		if (FreshRSS_Context::systemConf()->auth_type === 'form' && $password_plain == '') {
 			return false;
 		}
 
 		if (FreshRSS_user_Controller::checkUsername(param('default_user', ''))) {
-			FreshRSS_Context::$system_conf->default_user = param('default_user', '');
-			Minz_Session::_param('default_user', FreshRSS_Context::$system_conf->default_user);
+			FreshRSS_Context::systemConf()->default_user = param('default_user', '');
+			Minz_Session::_param('default_user', FreshRSS_Context::systemConf()->default_user);
 		} else {
 			return false;
 		}
 
-		if (FreshRSS_Context::$system_conf->auth_type === 'http_auth' &&
+		if (FreshRSS_Context::systemConf()->auth_type === 'http_auth' &&
 			connectionRemoteAddress() !== '' &&
 			empty($_SERVER['REMOTE_USER']) && empty($_SERVER['REDIRECT_REMOTE_USER']) &&	// No safe authentication HTTP headers
 			(!empty($_SERVER['HTTP_REMOTE_USER']) || !empty($_SERVER['HTTP_X_WEBAUTH_USER']))	// but has unsafe authentication HTTP headers
 		) {
 			// Trust by default the remote IP address (e.g. last proxy) used during install to provide remote user name via unsafe HTTP header
-			FreshRSS_Context::$system_conf->trusted_sources[] = connectionRemoteAddress();
-			FreshRSS_Context::$system_conf->trusted_sources = array_unique(FreshRSS_Context::$system_conf->trusted_sources);
+			FreshRSS_Context::systemConf()->trusted_sources[] = connectionRemoteAddress();
+			FreshRSS_Context::systemConf()->trusted_sources = array_unique(FreshRSS_Context::systemConf()->trusted_sources);
 		}
 
 		// Create default user files but first, we delete previous data to
 		// avoid access right problems.
-		recursive_unlink(USERS_PATH . '/' . Minz_Session::param('default_user'));
+		recursive_unlink(USERS_PATH . '/' . Minz_Session::paramString('default_user'));
 
 		$ok = false;
 		try {
 			$ok = FreshRSS_user_Controller::createUser(
-				Minz_Session::param('default_user'),
+				Minz_Session::paramString('default_user'),
 				'',	//TODO: Add e-mail
 				$password_plain,
 				[
-					'language' => Minz_Session::param('language'),
+					'language' => Minz_Session::paramString('language'),
 					'is_admin' => true,
 					'enabled' => true,
 				]
@@ -242,7 +242,7 @@ function saveStep3(): bool {
 			return false;
 		}
 
-		FreshRSS_Context::$system_conf->save();
+		FreshRSS_Context::systemConf()->save();
 
 		header('Location: index.php?step=4');
 	}
@@ -270,8 +270,8 @@ function checkStep(): void {
 /** @return array<string,string> */
 function checkStep0(): array {
 	$languages = Minz_Translate::availableLanguages();
-	$language = Minz_Session::param('language') != '' && in_array(Minz_Session::param('language'), $languages, true);
-	$sessionWorking = Minz_Session::param('sessionWorking') === 'ok';
+	$language = Minz_Session::paramString('language') != '' && in_array(Minz_Session::paramString('language'), $languages, true);
+	$sessionWorking = Minz_Session::paramString('sessionWorking') === 'ok';
 
 	return [
 		'language' => $language ? 'ok' : 'ko',
@@ -310,8 +310,8 @@ function freshrss_already_installed(): bool {
 function checkStep2(): array {
 	$conf = is_writable(join_path(DATA_PATH, 'config.php'));
 
-	$bd = Minz_Session::param('bd_type') != '';
-	$conn = Minz_Session::param('bd_error') == '';
+	$bd = Minz_Session::paramString('bd_type') != '';
+	$conn = Minz_Session::paramString('bd_error') == '';
 
 	return [
 		'bd' => $bd ? 'ok' : 'ko',
@@ -323,13 +323,13 @@ function checkStep2(): array {
 
 /** @return array<string,string> */
 function checkStep3(): array {
-	$conf = Minz_Session::param('default_user') != '';
+	$conf = Minz_Session::paramString('default_user') != '';
 
-	$form = Minz_Session::param('auth_type') != '';
+	$form = Minz_Session::paramString('auth_type') != '';
 
 	$defaultUser = empty($_POST['default_user']) ? null : $_POST['default_user'];
 	if ($defaultUser === null) {
-		$defaultUser = Minz_Session::param('default_user') == '' ? '' : Minz_Session::param('default_user');
+		$defaultUser = Minz_Session::paramString('default_user') == '' ? '' : Minz_Session::paramString('default_user');
 	}
 	$data = is_writable(join_path(USERS_PATH, $defaultUser, 'config.php'));
 
@@ -382,8 +382,8 @@ function printStep0(): void {
 		</div>
 	</div>
 
+	<h2><?= _t('install.language.choose') ?></h2>
 	<form action="index.php?step=0" method="post">
-		<legend><?= _t('install.language.choose') ?></legend>
 		<div class="form-group">
 			<label class="group-name" for="language"><?= _t('install.language') ?></label>
 			<div class="group-controls">
@@ -505,7 +505,10 @@ function printStep1(): void {
 <?php
 }
 
-/* Select database & configuration */
+/**
+ * Select database & configuration
+ * @throws Minz_ConfigurationNamespaceException
+ */
 function printStep2(): void {
 	$system_default_config = FreshRSS_SystemConfiguration::get('default_system');
 	$s2 = checkStep2();
@@ -516,8 +519,8 @@ function printStep2(): void {
 		(empty($_SESSION['bd_error']) ? '' : ' : ' . $_SESSION['bd_error']) ?></p>
 	<?php } ?>
 
+	<h2><?= _t('install.bdd.conf') ?></h2>
 	<form action="index.php?step=2" method="post" autocomplete="off">
-		<legend><?= _t('install.bdd.conf') ?></legend>
 		<div class="form-group">
 			<label class="group-name" for="type"><?= _t('install.bdd.type') ?></label>
 			<div class="group-controls">
@@ -531,7 +534,7 @@ function printStep2(): void {
 				<?php if (extension_loaded('pdo_mysql')) {?>
 				<option value="mysql"
 					<?= isset($_SESSION['bd_type']) && $_SESSION['bd_type'] === 'mysql' ? 'selected="selected"' : '' ?>>
-					MySQL
+					MySQL / MariaDB
 				</option>
 				<?php }?>
 				<?php if (extension_loaded('pdo_pgsql')) {?>
@@ -548,7 +551,7 @@ function printStep2(): void {
 		<div class="form-group">
 			<label class="group-name" for="host"><?= _t('install.bdd.host') ?></label>
 			<div class="group-controls">
-				<input type="text" id="host" name="host" pattern="[0-9A-Z/a-z_.-]{1,64}(:[0-9]{2,5})?" value="<?=
+				<input type="text" id="host" name="host" pattern="[0-9A-Z/a-z_.\-]{1,64}(:[0-9]{2,5})?" value="<?=
 					$_SESSION['bd_host'] ?? $system_default_config->db['host'] ?? '' ?>" tabindex="2" />
 			</div>
 		</div>
@@ -556,7 +559,7 @@ function printStep2(): void {
 		<div class="form-group">
 			<label class="group-name" for="user"><?= _t('install.bdd.username') ?></label>
 			<div class="group-controls">
-				<input type="text" id="user" name="user" maxlength="64" pattern="[0-9A-Za-z@_.-]{1,64}" value="<?=
+				<input type="text" id="user" name="user" maxlength="64" pattern="[0-9A-Za-z@_.\-]{1,64}" value="<?=
 					$_SESSION['bd_user'] ?? '' ?>" tabindex="3" />
 			</div>
 		</div>
@@ -575,7 +578,7 @@ function printStep2(): void {
 		<div class="form-group">
 			<label class="group-name" for="base"><?= _t('install.bdd') ?></label>
 			<div class="group-controls">
-				<input type="text" id="base" name="base" maxlength="64" pattern="[0-9A-Za-z_-]{1,64}" value="<?=
+				<input type="text" id="base" name="base" maxlength="64" pattern="[0-9A-Za-z_\-]{1,64}" value="<?=
 					$_SESSION['bd_base'] ?? '' ?>" tabindex="6" />
 			</div>
 		</div>
@@ -616,9 +619,8 @@ function printStep3(): void {
 	<p class="alert alert-error"><?= _t('install.fix_errors_before') ?></p>
 	<?php } ?>
 
+	<h2><?= _t('install.conf') ?></h2>
 	<form action="index.php?step=3" method="post">
-		<legend><?= _t('install.conf') ?></legend>
-
 		<div class="form-group">
 			<label class="group-name" for="default_user"><?= _t('install.default_user') ?></label>
 			<div class="group-controls">
