@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 
 /*
  * This is a configuration file. You shouldn’t modify it unless you know what
@@ -35,6 +36,13 @@ return [
 		'form' => 'simple',
 		'method' => 'GET',
 	],
+	'archiveIS' => [
+		'url' => 'https://archive.is/submit/?url=~LINK~',
+		'transform' => [],
+		'help' => 'https://archive.is/',
+		'form' => 'simple',
+		'method' => 'GET',
+	],
 	'archivePH' => [
 		'url' => 'https://archive.ph/submit/?url=~LINK~',
 		'transform' => [],
@@ -42,14 +50,6 @@ return [
 		'form' => 'simple',
 		'method' => 'GET',
 	],
-	'blogotext' => [
-		'deprecated' => true,
-		'url' => '~URL~/admin/links.php?url=~LINK~',
-		'transform' => [],
-		'help' => 'http://lehollandaisvolant.net/blogotext/fr/',
-		'form' => 'advanced',
-		'method' => 'GET',
-	],
 	'buffer' => [
 		'url' => 'https://publish.buffer.com/compose?url=~LINK~&text=~TITLE~',
 		'transform' => ['rawurlencode'],
