@@ -1,28 +1,46 @@
 #!/usr/bin/env php
 <?php
-
+declare(strict_types=1);
+require_once __DIR__ . '/_cli.php';
 require_once __DIR__ . '/i18n/I18nCompletionValidator.php';
 require_once __DIR__ . '/i18n/I18nData.php';
 require_once __DIR__ . '/i18n/I18nFile.php';
 require_once __DIR__ . '/i18n/I18nUsageValidator.php';
+require_once __DIR__ . '/../constants.php';
+
+$cliOptions = new class extends CliOptionsParser {
+	/** @var array<int,string> $language */
+	public array $language;
+	public string $displayResult;
+	public string $help;
+	public string $displayReport;
+
+	public function __construct() {
+		$this->addOption('language', (new CliOption('language', 'l'))->typeOfArrayOfString());
+		$this->addOption('displayResult', (new CliOption('display-result', 'd'))->withValueNone());
+		$this->addOption('help', (new CliOption('help', 'h'))->withValueNone());
+		$this->addOption('displayReport', (new CliOption('display-report', 'r'))->withValueNone());
+		parent::__construct();
+	}
+};
+
+if (!empty($cliOptions->errors)) {
+	fail('FreshRSS error: ' . array_shift($cliOptions->errors) . "\n" . $cliOptions->usage);
+}
+if (isset($cliOptions->help)) {
+	checkHelp();
+}
 
 $i18nFile = new I18nFile();
 $i18nData = new I18nData($i18nFile->load());
 
-/** @var array<string,string>|false $options */
-$options = getopt('dhl:r');
-
-if (!is_array($options) || array_key_exists('h', $options)) {
-	checkHelp();
-}
-
-if (array_key_exists('l', $options)) {
-	$languages = array($options['l']);
+if (isset($cliOptions->language)) {
+	$languages = $cliOptions->language;
 } else {
 	$languages = $i18nData->getAvailableLanguages();
 }
-$displayResults = array_key_exists('d', $options);
-$displayReport = array_key_exists('r', $options);
+$displayResults = isset($cliOptions->displayResult);
+$displayReport = isset($cliOptions->displayReport);
 
 $isValidated = true;
 $result = [];
@@ -99,11 +117,11 @@ SYNOPSIS
 DESCRIPTION
 	Check if translation files have missing keys or missing translations.
 
-	-d	display results.
-	-h	display this help and exit.
-	-l=LANG	filter by LANG.
-	-r	display completion report.
+	-d, --display-result	display results.
+	-h, --help		display this help and exit.
+	-l, --language=LANG	filter by LANG.
+	-r, --display-report	display completion report.
 
 HELP;
-	exit;
+	exit();
 }
