@@ -1,19 +1,17 @@
 <?php
+declare(strict_types=1);
 
 require_once __DIR__ . '/I18nValidatorInterface.php';
 
 class I18nCompletionValidator implements I18nValidatorInterface {
 
 	/** @var array<string,array<string,I18nValue>> */
-	private $reference;
+	private array $reference;
 	/** @var array<string,array<string,I18nValue>> */
-	private $language;
-	/** @var int */
-	private $totalEntries = 0;
-	/** @var int */
-	private $passEntries = 0;
-	/** @var string */
-	private $result = '';
+	private array $language;
+	private int $totalEntries = 0;
+	private int $passEntries = 0;
+	private string $result = '';
 
 	/**
 	 * @param array<string,array<string,I18nValue>> $reference
@@ -24,6 +22,7 @@ class I18nCompletionValidator implements I18nValidatorInterface {
 		$this->language = $language;
 	}
 
+	#[\Override]
 	public function displayReport(): string {
 		if ($this->passEntries > $this->totalEntries) {
 			throw new \RuntimeException('The number of translated strings cannot be higher than the number of strings');
@@ -34,10 +33,12 @@ class I18nCompletionValidator implements I18nValidatorInterface {
 		return sprintf('Translation is %5.1f%% complete.', $this->passEntries / $this->totalEntries * 100) . PHP_EOL;
 	}
 
+	#[\Override]
 	public function displayResult(): string {
 		return $this->result;
 	}
 
+	#[\Override]
 	public function validate(): bool {
 		foreach ($this->reference as $file => $data) {
 			foreach ($data as $refKey => $refValue) {
