@@ -1,11 +1,12 @@
 <?php
+declare(strict_types=1);
 
 class I18nData {
 
 	public const REFERENCE_LANGUAGE = 'en';
 
 	/** @var array<string,array<string,array<string,I18nValue>>> */
-	private $data;
+	private array $data;
 
 	/** @param array<string,array<string,array<string,I18nValue>>> $data */
 	public function __construct(array $data) {
@@ -92,16 +93,15 @@ class I18nData {
 	 * @return array<string>
 	 */
 	private function getNonReferenceLanguages(): array {
-		return array_filter(array_keys($this->data), static function (string $value) {
-			return static::REFERENCE_LANGUAGE !== $value;
-		});
+		return array_filter(array_keys($this->data),
+			static fn(string $value) => static::REFERENCE_LANGUAGE !== $value);
 	}
 
 	/**
 	 * Add a new language. It’s a copy of the reference language.
 	 * @throws Exception
 	 */
-	public function addLanguage(string $language, string $reference = null): void {
+	public function addLanguage(string $language, ?string $reference = null): void {
 		if (array_key_exists($language, $this->data)) {
 			throw new Exception('The selected language already exist.');
 		}
@@ -144,9 +144,7 @@ class I18nData {
 		$keys = array_keys($this->data[static::REFERENCE_LANGUAGE][$this->getFilenamePrefix($key)]);
 		$parent = $this->getParentKey($key);
 
-		return array_values(array_filter($keys, static function (string $element) use ($parent) {
-			return false !== strpos($element, $parent);
-		}));
+		return array_values(array_filter($keys, static fn(string $element) => false !== strpos($element, $parent)));
 	}
 
 	/**
@@ -287,27 +285,27 @@ class I18nData {
 	}
 
 	/**
-	 * Ignore a key from a language, or reverse it.
+	 * Ignore a key from a language, or revert an existing ignore on a key.
 	 */
-	public function ignore(string $key, string $language, bool $reverse = false): void {
+	public function ignore(string $key, string $language, bool $revert = false): void {
 		$value = $this->data[$language][$this->getFilenamePrefix($key)][$key];
-		if ($reverse) {
-			$value->markAsIgnore();
-		} else {
+		if ($revert) {
 			$value->unmarkAsIgnore();
+		} else {
+			$value->markAsIgnore();
 		}
 	}
 
 	/**
-	 * Ignore all unmodified keys from a language, or reverse it.
+	 * Ignore all unmodified keys from a language, or revert all existing ignores on unmodified keys.
 	 */
-	public function ignore_unmodified(string $language, bool $reverse = false): void {
+	public function ignore_unmodified(string $language, bool $revert = false): void {
 		$my_language = $this->getLanguage($language);
 		foreach ($this->getReferenceLanguage() as $file => $ref_language) {
 			foreach ($ref_language as $key => $ref_value) {
 				if (array_key_exists($key, $my_language[$file])) {
 					if ($ref_value->equal($my_language[$file][$key])) {
-						$this->ignore($key, $language, $reverse);
+						$this->ignore($key, $language, $revert);
 					}
 				}
 			}
@@ -329,7 +327,7 @@ class I18nData {
 	}
 
 	private function getFilenamePrefix(string $key): string {
-		return preg_replace('/\..*/', '.php', $key);
+		return preg_replace('/\..*/', '.php', $key) ?? '';
 	}
 
 }
