@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 
 require_once __DIR__ . '/I18nValue.php';
 
@@ -7,7 +8,7 @@ class I18nFile {
 	 * @return array<string,array<string,array<string,I18nValue>>>
 	 */
 	public function load(): array {
-		$i18n = array();
+		$i18n = [];
 		$dirs = new DirectoryIterator(I18N_PATH);
 		foreach ($dirs as $dir) {
 			if ($dir->isDot()) {
@@ -27,7 +28,7 @@ class I18nFile {
 	}
 
 	/**
-	 * @param array<string,array<array<string>>> $i18n
+	 * @param array<string,array<string,array<string,I18nValue>>> $i18n
 	 */
 	public function dump(array $i18n): void {
 		foreach ($i18n as $language => $file) {
@@ -65,7 +66,7 @@ class I18nFile {
 		} catch (ParseError $ex) {
 			if (defined('STDERR')) {
 				fwrite(STDERR, "Error while processing: $filename\n");
-				fwrite(STDERR, $ex);
+				fwrite(STDERR, $ex->getMessage());
 			}
 			die(1);
 		}
@@ -85,7 +86,7 @@ class I18nFile {
 	 * @return array<string,I18nValue>
 	 */
 	private function flatten(array $translation, string $prefix = ''): array {
-		$a = array();
+		$a = [];
 
 		if ('' !== $prefix) {
 			$prefix .= '.';
@@ -108,17 +109,17 @@ class I18nFile {
 	 * The first key is dropped since it represents the filename and we have
 	 * no use of it.
 	 *
-	 * @param array<string> $translation
+	 * @param array<string,I18nValue> $translation
 	 * @return array<string,array<string,I18nValue>>
 	 */
 	private function unflatten(array $translation): array {
-		$a = array();
+		$a = [];
 
 		ksort($translation, SORT_NATURAL);
 		foreach ($translation as $compoundKey => $value) {
 			$keys = explode('.', $compoundKey);
 			array_shift($keys);
-			eval("\$a['" . implode("']['", $keys) . "'] = '" . addcslashes($value, "'") . "';");
+			eval("\$a['" . implode("']['", $keys) . "'] = '" . addcslashes($value->__toString(), "'") . "';");
 		}
 
 		return $a;
@@ -131,11 +132,11 @@ class I18nFile {
 	 * translation file. The array is first converted to a string then some
 	 * formatting regexes are applied to match the original content.
 	 *
-	 * @param array<string> $translation
+	 * @param array<string,I18nValue> $translation
 	 */
 	private function format(array $translation): string {
 		$translation = var_export($this->unflatten($translation), true);
-		$patterns = array(
+		$patterns = [
 			'/ -> todo\',/',
 			'/ -> dirty\',/',
 			'/ -> ignore\',/',
@@ -143,8 +144,8 @@ class I18nFile {
 			'/=>\s*array/',
 			'/(\w) {2}/',
 			'/ {2}/',
-		);
-		$replacements = array(
+		];
+		$replacements = [
 			"',\t// TODO", // Double quoting is mandatory to have a tab instead of the \t string
 			"',\t// DIRTY", // Double quoting is mandatory to have a tab instead of the \t string
 			"',\t// IGNORE", // Double quoting is mandatory to have a tab instead of the \t string
@@ -152,7 +153,7 @@ class I18nFile {
 			'=> array',
 			'$1 ',
 			"\t", // Double quoting is mandatory to have a tab instead of the \t string
-		);
+		];
 		$translation = preg_replace($patterns, $replacements, $translation);
 
 		return <<<OUTPUT
