@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 
 class I18nValue {
 	private const STATE_DIRTY = 'dirty';
@@ -10,15 +11,17 @@ class I18nValue {
 		self::STATE_TODO,
 	];
 
-	/** @var string */
-	private $value;
-	/**	@var string|null */
-	private $state;
+	private string $value;
+	private ?string $state = null;
 
-	public function __construct(string $data) {
+	/** @param I18nValue|string $data */
+	public function __construct($data) {
+		if ($data instanceof I18nValue) {
+			$data = $data->__toString();
+		}
 		$data = explode(' -> ', $data);
 
-		$this->value = array_shift($data);
+		$this->value = (string)(array_shift($data) ?? '');
 		if (count($data) === 0) {
 			return;
 		}
@@ -63,6 +66,7 @@ class I18nValue {
 		}
 	}
 
+	#[\Override]
 	public function __toString(): string {
 		if ($this->state === null) {
 			return $this->value;
