@@ -1,38 +1,42 @@
 #!/usr/bin/env php
 <?php
+declare(strict_types=1);
 require(__DIR__ . '/_cli.php');
 
 const DATA_FORMAT = "%-7s | %-20s | %-5s | %-7s | %-25s | %-15s | %-10s | %-10s | %-10s | %-10s | %-10s | %-10s | %-5s | %-10s\n";
 
-$params = array(
-	'user:',
-	'header',
-	'json',
-);
-$options = getopt('h', $params);
+$cliOptions = new class extends CliOptionsParser {
+	/** @var array<int,string> $user */
+	public array $user;
+	public string $header;
+	public string $json;
+	public string $humanReadable;
 
-if (!validateOptions($argv, $params)) {
-	fail('Usage: ' . basename(__FILE__) . ' (-h --header --json --user username --user username …)');
+	public function __construct() {
+		$this->addOption('user', (new CliOption('user'))->typeOfArrayOfString());
+		$this->addOption('header', (new CliOption('header'))->withValueNone());
+		$this->addOption('json', (new CliOption('json'))->withValueNone());
+		$this->addOption('humanReadable', (new CliOption('human-readable', 'h'))->withValueNone());
+		parent::__construct();
+	}
+};
+
+if (!empty($cliOptions->errors)) {
+	fail('FreshRSS error: ' . array_shift($cliOptions->errors) . "\n" . $cliOptions->usage);
 }
 
-if (empty($options['user'])) {
-	$users = listUsers();
-} elseif (is_array($options['user'])) {
-	$users = $options['user'];
-} else {
-	$users = array($options['user']);
-}
+$users = $cliOptions->user ?? listUsers();
 
 sort($users);
 
-$formatJson = isset($options['json']);
+$formatJson = isset($cliOptions->json);
 $jsonOutput = [];
 if ($formatJson) {
-	unset($options['header']);
-	unset($options['h']);
+	unset($cliOptions->header);
+	unset($cliOptions->humanReadable);
 }
 
-if (array_key_exists('header', $options)) {
+if (isset($cliOptions->header)) {
 	printf(
 		DATA_FORMAT,
 		'default',
@@ -66,10 +70,10 @@ foreach ($users as $username) {
 	$feedList = $feedDAO->listFeedsIds();
 
 	$data = array(
-		'default' => $username === FreshRSS_Context::$system_conf->default_user ? '*' : '',
+		'default' => $username === FreshRSS_Context::systemConf()->default_user ? '*' : '',
 		'user' => $username,
-		'admin' => FreshRSS_Context::$user_conf->is_admin ? '*' : '',
-		'enabled' => FreshRSS_Context::$user_conf->enabled ? '*' : '',
+		'admin' => FreshRSS_Context::userConf()->is_admin ? '*' : '',
+		'enabled' => FreshRSS_Context::userConf()->enabled ? '*' : '',
 		'last_user_activity' => FreshRSS_UserDAO::mtime($username),
 		'database_size' => $databaseDAO->size(),
 		'categories' => $catDAO->count(),
@@ -78,10 +82,10 @@ foreach ($users as $username) {
 		'unreads' => (int)$nbEntries['unread'],
 		'favourites' => (int)$nbFavorites['all'],
 		'tags' => $tagDAO->count(),
-		'lang' => FreshRSS_Context::$user_conf->language,
-		'mail_login' => FreshRSS_Context::$user_conf->mail_login,
+		'lang' => FreshRSS_Context::userConf()->language,
+		'mail_login' => FreshRSS_Context::userConf()->mail_login,
 	);
-	if (isset($options['h'])) {	//Human format
+	if (isset($cliOptions->humanReadable)) {	//Human format
 		$data['last_user_activity'] = date('c', $data['last_user_activity']);
 		$data['database_size'] = format_bytes($data['database_size']);
 	}
