@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 
 /**
  * An extension manager to load extensions present in CORE_EXTENSIONS_PATH and THIRDPARTY_EXTENSIONS_PATH.
@@ -6,22 +7,21 @@
  * @todo see coding style for methods!!
  */
 final class Minz_ExtensionManager {
-	/** @var string */
-	private static $ext_metaname = 'metadata.json';
-	/** @var string */
-	private static $ext_entry_point = 'extension.php';
+
+	private static string $ext_metaname = 'metadata.json';
+	private static string $ext_entry_point = 'extension.php';
 	/** @var array<string,Minz_Extension> */
-	private static $ext_list = array();
+	private static array $ext_list = [];
 	/** @var array<string,Minz_Extension> */
-	private static $ext_list_enabled = array();
+	private static array $ext_list_enabled = [];
 	/** @var array<string,bool> */
-	private static $ext_auto_enabled = array();
+	private static array $ext_auto_enabled = [];
 
 	/**
 	 * List of available hooks. Please keep this list sorted.
 	 * @var array<string,array{'list':array<callable>,'signature':'NoneToNone'|'NoneToString'|'OneToOne'|'PassArguments'}>
 	 */
-	private static $hook_list = array(
+	private static array $hook_list = [
 		'check_url_before_add' => array(	// function($url) -> Url | null
 			'list' => array(),
 			'signature' => 'OneToOne',
@@ -90,7 +90,7 @@ final class Minz_ExtensionManager {
 			'list' => array(),
 			'signature' => 'PassArguments',
 		),
-	);
+	];
 
 	/** Remove extensions and hooks from a previous initialisation */
 	private static function reset(): void {
@@ -118,6 +118,7 @@ final class Minz_ExtensionManager {
 	 * extension.php should contain at least a class named <name>Extension where
 	 * <name> must match with the entry point in metadata.json. This class must
 	 * inherit from Minz_Extension class.
+	 * @throws Minz_ConfigurationNamespaceException
 	 */
 	public static function init(): void {
 		self::reset();
@@ -147,7 +148,7 @@ final class Minz_ExtensionManager {
 			$meta_raw_content = file_get_contents($metadata_filename) ?: '';
 			/** @var array{'name':string,'entrypoint':string,'path':string,'author'?:string,'description'?:string,'version'?:string,'type'?:'system'|'user'}|null $meta_json */
 			$meta_json = json_decode($meta_raw_content, true);
-			if (!$meta_json || !self::isValidMetadata($meta_json)) {
+			if (!is_array($meta_json) || !self::isValidMetadata($meta_json)) {
 				// metadata.json is not a json file? Invalid!
 				// or metadata.json is invalid (no required information), invalid!
 				Minz_Log::warning('`' . $metadata_filename . '` is not a valid metadata file');
@@ -275,7 +276,7 @@ final class Minz_ExtensionManager {
 			return;
 		}
 		foreach ($ext_list as $ext_name => $ext_status) {
-			if ($ext_status) {
+			if ($ext_status && is_string($ext_name)) {
 				self::enable($ext_name, $onlyOfType);
 			}
 		}
@@ -347,9 +348,9 @@ final class Minz_ExtensionManager {
 				call_user_func($function, ...$args);
 			}
 		} elseif ($signature === 'NoneToString') {
-			return self::callNoneToString($hook_name);
+			return self::callHookString($hook_name);
 		} elseif ($signature === 'NoneToNone') {
-			self::callNoneToNone($hook_name);
+			self::callHookVoid($hook_name);
 		}
 		return;
 	}
@@ -391,9 +392,9 @@ final class Minz_ExtensionManager {
 	 * @param string $hook_name is the hook to call.
 	 * @return string concatenated result of the call to all the hooks.
 	 */
-	private static function callNoneToString(string $hook_name): string {
+	public static function callHookString(string $hook_name): string {
 		$result = '';
-		foreach (self::$hook_list[$hook_name]['list'] as $function) {
+		foreach (self::$hook_list[$hook_name]['list'] ?? [] as $function) {
 			$result = $result . call_user_func($function);
 		}
 		return $result;
@@ -407,8 +408,8 @@ final class Minz_ExtensionManager {
 	 *
 	 * @param string $hook_name is the hook to call.
 	 */
-	private static function callNoneToNone(string $hook_name): void {
-		foreach (self::$hook_list[$hook_name]['list'] as $function) {
+	public static function callHookVoid(string $hook_name): void {
+		foreach (self::$hook_list[$hook_name]['list'] ?? [] as $function) {
 			call_user_func($function);
 		}
 	}
