@@ -1,4 +1,6 @@
 <?php
+declare(strict_types=1);
+
 /**
  * MINZ - Copyright 2011 Marien Fressinaud
  * Sous licence AGPL3 <http://www.gnu.org/licenses/>
@@ -7,23 +9,25 @@
 /**
  * The Minz_Helper class contains some misc. help functions
  */
-class Minz_Helper {
+final class Minz_Helper {
 
 	/**
 	 * Wrapper for htmlspecialchars.
-	 * Force UTf-8 value and can be used on array too.
+	 * Force UTF-8 value and can be used on array too.
 	 *
-	 * @phpstan-template T of string|array<mixed>
+	 * @phpstan-template T of mixed
 	 * @phpstan-param T $var
 	 * @phpstan-return T
 	 *
-	 * @param string|array<string> $var
-	 * @return string|array<string>
+	 * @param mixed $var
+	 * @return mixed
 	 */
 	public static function htmlspecialchars_utf8($var) {
 		if (is_array($var)) {
-			return array_map(array('Minz_Helper', 'htmlspecialchars_utf8'), $var);
+			// @phpstan-ignore argument.type, return.type
+			return array_map([self::class, 'htmlspecialchars_utf8'], $var);
 		} elseif (is_string($var)) {
+			// @phpstan-ignore return.type
 			return htmlspecialchars($var, ENT_COMPAT, 'UTF-8');
 		} else {
 			return $var;
