@@ -1,4 +1,6 @@
 <?php
+declare(strict_types=1);
+
 /**
  * MINZ - Copyright 2011 Marien Fressinaud
  * Sous licence AGPL3 <http://www.gnu.org/licenses/>
@@ -7,6 +9,6 @@
 /**
  * The Minz_Model class represents a model in the MVC paradigm.
  */
-class Minz_Model {
+abstract class Minz_Model {
 
 }
