@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 
 /**
  * MINZ - Copyright 2011 Marien Fressinaud
@@ -12,29 +13,16 @@ class Minz_ModelPdo {
 
 	/**
 	 * Shares the connection to the database between all instances.
-	 * @var bool
 	 */
-	public static $usesSharedPdo = true;
+	public static bool $usesSharedPdo = true;
 
-	/**
-	 * @var Minz_Pdo|null
-	 */
-	private static $sharedPdo;
+	private static ?Minz_Pdo $sharedPdo = null;
 
-	/**
-	 * @var string|null
-	 */
-	private static $sharedCurrentUser;
+	private static string $sharedCurrentUser = '';
 
-	/**
-	 * @var Minz_Pdo
-	 */
-	protected $pdo;
+	protected Minz_Pdo $pdo;
 
-	/**
-	 * @var string|null
-	 */
-	protected $current_user;
+	protected ?string $current_user;
 
 	/**
 	 * @throws Minz_ConfigurationNamespaceException
@@ -70,7 +58,7 @@ class Minz_ModelPdo {
 				break;
 			case 'sqlite':
 				$dsn = 'sqlite:' . DATA_PATH . '/users/' . $this->current_user . '/db.sqlite';
-				$this->pdo = new Minz_PdoSqlite($dsn . $dsnParams, $db['user'], $db['password'], $driver_options);
+				$this->pdo = new Minz_PdoSqlite($dsn . $dsnParams, null, null, $driver_options);
 				$this->pdo->setPrefix('');
 				break;
 			case 'pgsql':
@@ -90,7 +78,9 @@ class Minz_ModelPdo {
 					$db['user'], Minz_Exception::ERROR
 				);
 		}
-		self::$sharedPdo = $this->pdo;
+		if (self::$usesSharedPdo) {
+			self::$sharedPdo = $this->pdo;
+		}
 	}
 
 	/**
@@ -98,7 +88,7 @@ class Minz_ModelPdo {
 	 * HOST, BASE, USER and PASS variables defined in the configuration file
 	 * @param string|null $currentUser
 	 * @param Minz_Pdo|null $currentPdo
-	 * @throws Minz_ConfigurationNamespaceException
+	 * @throws Minz_ConfigurationException
 	 * @throws Minz_PDOConnectionException
 	 */
 	public function __construct(?string $currentUser = null, ?Minz_Pdo $currentPdo = null) {
@@ -109,7 +99,7 @@ class Minz_ModelPdo {
 			$this->pdo = $currentPdo;
 			return;
 		}
-		if ($currentUser == '') {
+		if ($currentUser == null) {
 			throw new Minz_PDOConnectionException('Current user must not be empty!', '', Minz_Exception::ERROR);
 		}
 		if (self::$usesSharedPdo && self::$sharedPdo !== null && $currentUser === self::$sharedCurrentUser) {
@@ -118,7 +108,9 @@ class Minz_ModelPdo {
 			return;
 		}
 		$this->current_user = $currentUser;
-		self::$sharedCurrentUser = $currentUser;
+		if (self::$usesSharedPdo) {
+			self::$sharedCurrentUser = $currentUser;
+		}
 
 		$ex = null;
 		//Attempt a few times to connect to database
@@ -141,7 +133,7 @@ class Minz_ModelPdo {
 		$db = Minz_Configuration::get('system')->db;
 
 		throw new Minz_PDOConnectionException(
-				$ex->getMessage(),
+				$ex === null ? '' : $ex->getMessage(),
 				$db['user'], Minz_Exception::ERROR
 			);
 	}
@@ -167,6 +159,15 @@ class Minz_ModelPdo {
 		self::$sharedCurrentUser = '';
 	}
 
+	public function close(): void {
+		if ($this->current_user === self::$sharedCurrentUser) {
+			self::clean();
+		}
+		$this->current_user = '';
+		unset($this->pdo);
+		gc_collect_cycles();
+	}
+
 	/**
 	 * @param array<string,int|string|null> $values
 	 * @phpstan-return ($mode is PDO::FETCH_ASSOC ? array<array<string,int|string|null>>|null : array<int|string|null>|null)
@@ -208,9 +209,17 @@ class Minz_ModelPdo {
 			}
 		}
 
-		$callingFunction = debug_backtrace(DEBUG_BACKTRACE_IGNORE_ARGS, 3)[2]['function'] ?? '??';
+		$backtrace = debug_backtrace(DEBUG_BACKTRACE_IGNORE_ARGS, 6);
+		$calling = '';
+		for ($i = 2; $i < 6; $i++) {
+			if (empty($backtrace[$i]['function'])) {
+				break;
+			}
+			$calling .= '|' . $backtrace[$i]['function'];
+		}
+		$calling = trim($calling, '|');
 		$info = $stm == null ? $this->pdo->errorInfo() : $stm->errorInfo();
-		Minz_Log::error('SQL error ' . $callingFunction . ' ' . json_encode($info));
+		Minz_Log::error('SQL error ' . $calling . ' ' . json_encode($info));
 		return null;
 	}
 
@@ -229,4 +238,19 @@ class Minz_ModelPdo {
 	public function fetchColumn(string $sql, int $column, array $values = []): ?array {
 		return $this->fetchAny($sql, $values, PDO::FETCH_COLUMN, $column);
 	}
+
+	/** For retrieving a single value without prepared statement such as `SELECT version()` */
+	public function fetchValue(string $sql): ?string {
+		$stm = $this->pdo->query($sql);
+		if ($stm === false) {
+			Minz_Log::error('SQL error ' . json_encode($this->pdo->errorInfo()) . ' during ' . $sql);
+			return null;
+		}
+		$columns = $stm->fetchAll(PDO::FETCH_COLUMN, 0);
+		if ($columns === false) {
+			Minz_Log::error('SQL error ' . json_encode($stm->errorInfo()) . ' during ' . $sql);
+			return null;
+		}
+		return isset($columns[0]) ? (string)$columns[0] : null;
+	}
 }
