@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 
 /**
  * MINZ - Copyright 2011 Marien Fressinaud
@@ -6,7 +7,10 @@
  */
 
 abstract class Minz_Pdo extends PDO {
-	/** @param array<int,int|string|bool>|null $options */
+	/**
+	 * @param array<int,int|string|bool>|null $options
+	 * @throws PDOException
+	 */
 	public function __construct(string $dsn, ?string $username = null, ?string $passwd = null, ?array $options = null) {
 		parent::__construct($dsn, $username, $passwd, $options);
 		$this->setAttribute(PDO::ATTR_EMULATE_PREPARES, false);
@@ -14,8 +18,7 @@ abstract class Minz_Pdo extends PDO {
 
 	abstract public function dbType(): string;
 
-	/** @var string */
-	private $prefix = '';
+	private string $prefix = '';
 	public function prefix(): string {
 		return $this->prefix;
 	}
@@ -38,7 +41,9 @@ abstract class Minz_Pdo extends PDO {
 	/**
 	 * @param string|null $name
 	 * @return string|false
+	 * @throws PDOException if the attribute `PDO::ATTR_ERRMODE` is set to `PDO::ERRMODE_EXCEPTION`
 	 */
+	#[\Override]
 	#[\ReturnTypeWillChange]
 	public function lastInsertId($name = null) {
 		if ($name != null) {
@@ -52,8 +57,10 @@ abstract class Minz_Pdo extends PDO {
 	 * @param string $query
 	 * @param array<int,string> $options
 	 * @return PDOStatement|false
-	 * @phpstan-ignore-next-line
+	 * @throws PDOException if the attribute `PDO::ATTR_ERRMODE` is set to `PDO::ERRMODE_EXCEPTION`
+	 * @phpstan-ignore method.childParameterType, throws.unusedType
 	 */
+	#[\Override]
 	#[\ReturnTypeWillChange]
 	public function prepare($query, $options = []) {
 		$query = $this->preSql($query);
@@ -64,14 +71,22 @@ abstract class Minz_Pdo extends PDO {
 	/**
 	 * @param string $statement
 	 * @return int|false
+	 * @throws PDOException if the attribute `PDO::ATTR_ERRMODE` is set to `PDO::ERRMODE_EXCEPTION`
+	 * @phpstan-ignore throws.unusedType
 	 */
+	#[\Override]
 	#[\ReturnTypeWillChange]
 	public function exec($statement) {
 		$statement = $this->preSql($statement);
 		return parent::exec($statement);
 	}
 
-	/** @return PDOStatement|false */
+	/**
+	 * @return PDOStatement|false
+	 * @throws PDOException if the attribute `PDO::ATTR_ERRMODE` is set to `PDO::ERRMODE_EXCEPTION`
+	 * @phpstan-ignore throws.unusedType
+	 */
+	#[\Override]
 	#[\ReturnTypeWillChange]
 	public function query(string $query, ?int $fetch_mode = null, ...$fetch_mode_args) {
 		$query = $this->preSql($query);
