@@ -1,4 +1,5 @@
 <?php
+declare(strict_types=1);
 
 /**
  * MINZ - Copyright 2011 Marien Fressinaud
@@ -6,12 +7,16 @@
  */
 
 class Minz_PdoSqlite extends Minz_Pdo {
-	/** @param array<int,int|string|bool>|null $options */
+	/**
+	 * @param array<int,int|string|bool>|null $options
+	 * @throws PDOException
+	 */
 	public function __construct(string $dsn, ?string $username = null, ?string $passwd = null, ?array $options = null) {
 		parent::__construct($dsn, $username, $passwd, $options);
 		$this->exec('PRAGMA foreign_keys = ON;');
 	}
 
+	#[\Override]
 	public function dbType(): string {
 		return 'sqlite';
 	}
@@ -19,7 +24,9 @@ class Minz_PdoSqlite extends Minz_Pdo {
 	/**
 	 * @param string|null $name
 	 * @return string|false
+	 * @throws PDOException if the attribute `PDO::ATTR_ERRMODE` is set to `PDO::ERRMODE_EXCEPTION`
 	 */
+	#[\Override]
 	#[\ReturnTypeWillChange]
 	public function lastInsertId($name = null) {
 		return parent::lastInsertId();	//We discard the name, only used by PostgreSQL
