@@ -1,4 +1,6 @@
 <?php
+declare(strict_types=1);
+
 /**
  * MINZ - Copyright 2011 Marien Fressinaud
  * Sous licence AGPL3 <http://www.gnu.org/licenses/>
@@ -8,20 +10,17 @@
  * Request représente la requête http
  */
 class Minz_Request {
-	/** @var string */
-	private static $controller_name = '';
-	/** @var string */
-	private static $action_name = '';
+
+	private static string $controller_name = '';
+	private static string $action_name = '';
 	/** @var array<string,mixed> */
-	private static $params = array();
+	private static array $params = [];
 
-	/** @var string */
-	private static $default_controller_name = 'index';
-	/** @var string */
-	private static $default_action_name = 'index';
+	private static string $default_controller_name = 'index';
+	private static string $default_action_name = 'index';
 
-	/** @var array{'c'?:string,'a'?:string,'params'?:array<string,mixed>} */
-	private static $originalRequest = [];
+	/** @var array{c?:string,a?:string,params?:array<string,mixed>} */
+	private static array $originalRequest = [];
 
 	/**
 	 * Getteurs
@@ -36,6 +35,7 @@ class Minz_Request {
 	public static function params(): array {
 		return self::$params;
 	}
+
 	/**
 	 * Read the URL parameter
 	 * @param string $key Key name
@@ -47,10 +47,8 @@ class Minz_Request {
 	public static function param(string $key, $default = false, bool $specialchars = false) {
 		if (isset(self::$params[$key])) {
 			$p = self::$params[$key];
-			if (is_object($p) || $specialchars) {
-				return $p;
-			} elseif (is_string($p) || is_array($p)) {
-				return Minz_Helper::htmlspecialchars_utf8($p);
+			if (is_string($p) || is_array($p)) {
+				return $specialchars ? $p : Minz_Helper::htmlspecialchars_utf8($p);
 			} else {
 				return $p;
 			}
@@ -59,15 +57,27 @@ class Minz_Request {
 		}
 	}
 
-	/** @return array<string|int,string|array<string,string>> */
+	public static function hasParam(string $key): bool {
+		return isset(self::$params[$key]);
+	}
+
+	/** @return array<string|int,string|array<string,string|int|bool>> */
 	public static function paramArray(string $key, bool $specialchars = false): array {
 		if (empty(self::$params[$key]) || !is_array(self::$params[$key])) {
 			return [];
 		}
-
 		return $specialchars ? Minz_Helper::htmlspecialchars_utf8(self::$params[$key]) : self::$params[$key];
 	}
 
+	/** @return array<string> */
+	public static function paramArrayString(string $key, bool $specialchars = false): array {
+		if (empty(self::$params[$key]) || !is_array(self::$params[$key])) {
+			return [];
+		}
+		$result = array_filter(self::$params[$key], 'is_string');
+		return $specialchars ? Minz_Helper::htmlspecialchars_utf8($result) : $result;
+	}
+
 	public static function paramTernary(string $key): ?bool {
 		if (isset(self::$params[$key])) {
 			$p = self::$params[$key];
@@ -90,13 +100,13 @@ class Minz_Request {
 	}
 
 	public static function paramInt(string $key): int {
-		if (!empty(self::$params[$key])) {
-			return intval(self::$params[$key]);
+		if (!empty(self::$params[$key]) && is_numeric(self::$params[$key])) {
+			return (int)self::$params[$key];
 		}
 		return 0;
 	}
 
-	public static function paramString(string $key, bool $specialchars = false): string {
+	public static function paramStringNull(string $key, bool $specialchars = false): ?string {
 		if (isset(self::$params[$key])) {
 			$s = self::$params[$key];
 			if (is_string($s)) {
@@ -107,7 +117,11 @@ class Minz_Request {
 				return (string)$s;
 			}
 		}
-		return '';
+		return null;
+	}
+
+	public static function paramString(string $key, bool $specialchars = false): string {
+		return self::paramStringNull($key, $specialchars) ?? '';
 	}
 
 	/**
@@ -120,8 +134,8 @@ class Minz_Request {
 	 * @return array<string>
 	 */
 	public static function paramTextToArray(string $key, array $default = []): array {
-		if (isset(self::$params[$key])) {
-			return preg_split('/\R/', self::$params[$key]) ?: [];
+		if (isset(self::$params[$key]) && is_string(self::$params[$key])) {
+			return preg_split('/\R/u', self::$params[$key]) ?: [];
 		}
 		return $default;
 	}
@@ -132,7 +146,7 @@ class Minz_Request {
 	public static function defaultActionName(): string {
 		return self::$default_action_name;
 	}
-	/** @return array{'c':string,'a':string,'params':array<string,mixed>} */
+	/** @return array{c:string,a:string,params:array<string,mixed>} */
 	public static function currentRequest(): array {
 		return [
 			'c' => self::$controller_name,
@@ -141,14 +155,14 @@ class Minz_Request {
 		];
 	}
 
-	/** @return array{'c'?:string,'a'?:string,'params'?:array<string,mixed>} */
+	/** @return array{c?:string,a?:string,params?:array<string,mixed>} */
 	public static function originalRequest() {
 		return self::$originalRequest;
 	}
 
 	/**
 	 * @param array<string,mixed>|null $extraParams
-	 * @return array{'c':string,'a':string,'params':array<string,mixed>}
+	 * @return array{c:string,a:string,params:array<string,mixed>}
 	 */
 	public static function modifiedCurrentRequest(?array $extraParams = null): array {
 		unset(self::$params['ajax']);
@@ -163,21 +177,20 @@ class Minz_Request {
 	 * Setteurs
 	 */
 	public static function _controllerName(string $controller_name): void {
-		self::$controller_name = $controller_name;
+		self::$controller_name = ctype_alnum($controller_name) ? $controller_name : '';
 	}
 
 	public static function _actionName(string $action_name): void {
-		self::$action_name = $action_name;
+		self::$action_name = ctype_alnum($action_name) ? $action_name : '';
 	}
 
-	/** @param array<string,string> $params */
+	/** @param array<string,mixed> $params */
 	public static function _params(array $params): void {
 		self::$params = $params;
 	}
 
-	/** @param array|mixed $value */
-	public static function _param(string $key, $value = false): void {
-		if ($value === false) {
+	public static function _param(string $key, ?string $value = null): void {
+		if ($value === null) {
 			unset(self::$params[$key]);
 		} else {
 			self::$params[$key] = $value;
@@ -188,6 +201,7 @@ class Minz_Request {
 	 * Initialise la Request
 	 */
 	public static function init(): void {
+		self::_params($_GET);
 		self::initJSON();
 	}
 
@@ -284,6 +298,7 @@ class Minz_Request {
 
 	/**
 	 * Return the base_url from configuration
+	 * @throws Minz_ConfigurationException
 	 */
 	public static function getBaseUrl(): string {
 		$conf = Minz_Configuration::get('system');
@@ -336,7 +351,7 @@ class Minz_Request {
 
 	private static function setNotification(string $type, string $content): void {
 		Minz_Session::lock();
-		$requests = Minz_Session::param('requests', []);
+		$requests = Minz_Session::paramArray('requests');
 		$requests[self::requestId()] = [
 				'time' => time(),
 				'notification' => [ 'type' => $type, 'content' => $content ],
@@ -353,19 +368,25 @@ class Minz_Request {
 		self::setNotification('bad', $content);
 	}
 
-	/** @return array<string,string>|null */
-	public static function getNotification(): ?array {
+	/**
+	 * @param $pop true (default) to remove the notification, false to keep it.
+	 * @return array{type:string,content:string}|null
+	 */
+	public static function getNotification(bool $pop = true): ?array {
 		$notif = null;
 		Minz_Session::lock();
-		$requests = Minz_Session::param('requests');
-		if (is_array($requests)) {
+		/** @var array<string,array{time:int,notification:array{type:string,content:string}}> */
+		$requests = Minz_Session::paramArray('requests');
+		if (!empty($requests)) {
 			//Delete abandoned notifications
-			$requests = array_filter($requests, static function (array $r) { return isset($r['time']) && $r['time'] > time() - 3600; });
+			$requests = array_filter($requests, static function (array $r) { return $r['time'] > time() - 3600; });
 
 			$requestId = self::requestId();
 			if (!empty($requests[$requestId]['notification'])) {
 				$notif = $requests[$requestId]['notification'];
-				unset($requests[$requestId]);
+				if ($pop) {
+					unset($requests[$requestId]);
+				}
 			}
 			Minz_Session::_param('requests', $requests);
 		}
@@ -375,8 +396,9 @@ class Minz_Request {
 
 	/**
 	 * Restart a request
-	 * @param array{'c'?:string,'a'?:string,'params'?:array<string,mixed>} $url an array presentation of the URL to route to
+	 * @param array{c?:string,a?:string,params?:array<string,mixed>} $url an array presentation of the URL to route to
 	 * @param bool $redirect If true, uses an HTTP redirection, and if false (default), performs an internal dispatcher redirection.
+	 * @throws Minz_ConfigurationException
 	 */
 	public static function forward($url = [], bool $redirect = false): void {
 		if (empty(Minz_Request::originalRequest())) {
@@ -392,10 +414,8 @@ class Minz_Request {
 		} else {
 			self::_controllerName($url['c']);
 			self::_actionName($url['a']);
-			self::_params(array_merge(
-				self::$params,
-				$url['params']
-			));
+			$merge = array_merge(self::$params, $url['params']);
+			self::_params($merge);
 			Minz_Dispatcher::reset();
 		}
 	}
@@ -403,7 +423,7 @@ class Minz_Request {
 	/**
 	 * Wrappers good notifications + redirection
 	 * @param string $msg notification content
-	 * @param array{'c'?:string,'a'?:string,'params'?:array<string,mixed>} $url url array to where we should be forwarded
+	 * @param array{c?:string,a?:string,params?:array<string,mixed>} $url url array to where we should be forwarded
 	 */
 	public static function good(string $msg, array $url = []): void {
 		Minz_Request::setGoodNotification($msg);
@@ -413,7 +433,7 @@ class Minz_Request {
 	/**
 	 * Wrappers bad notifications + redirection
 	 * @param string $msg notification content
-	 * @param array{'c'?:string,'a'?:string,'params'?:array<string,mixed>} $url url array to where we should be forwarded
+	 * @param array{c?:string,a?:string,params?:array<string,mixed>} $url url array to where we should be forwarded
 	 */
 	public static function bad(string $msg, array $url = []): void {
 		Minz_Request::setBadNotification($msg);
@@ -424,14 +444,14 @@ class Minz_Request {
 	 * Allows receiving POST data as application/json
 	 */
 	private static function initJSON(): void {
-		if ('application/json' !== self::extractContentType()) {
+		if (!str_starts_with(self::extractContentType(), 'application/json')) {
 			return;
 		}
 		$ORIGINAL_INPUT = file_get_contents('php://input', false, null, 0, 1048576);
 		if ($ORIGINAL_INPUT == false) {
 			return;
 		}
-		if (null === $json = json_decode($ORIGINAL_INPUT, true)) {
+		if (!is_array($json = json_decode($ORIGINAL_INPUT, true))) {
 			return;
 		}
 
