@@ -1,4 +1,6 @@
 <?php
+declare(strict_types=1);
+
 /**
  * MINZ - Copyright 2011 Marien Fressinaud
  * Sous licence AGPL3 <http://www.gnu.org/licenses/>
@@ -12,25 +14,23 @@ class Minz_View {
 	private const LAYOUT_PATH_NAME = '/layout/';
 	private const LAYOUT_DEFAULT = 'layout';
 
-	/** @var string */
-	private $view_filename = '';
-	/** @var string */
-	private $layout_filename = '';
+	private string $view_filename = '';
+	private string $layout_filename = '';
 	/** @var array<string> */
-	private static $base_pathnames = array(APP_PATH);
-	/** @var string */
-	private static $title = '';
+	private static array $base_pathnames = [APP_PATH];
+	private static string $title = '';
 	/** @var array<array{'media':string,'url':string}> */
-	private static $styles = [];
+	private static array $styles = [];
 	/** @var array<array{'url':string,'id':string,'defer':bool,'async':bool}> */
-	private static $scripts = [];
+	private static array $scripts = [];
 	/** @var string|array{'dark'?:string,'light'?:string,'default'?:string} */
 	private static $themeColors;
 	/** @var array<string,mixed> */
-	private static $params = [];
+	private static array $params = [];
 
 	/**
 	 * Determines if a layout is used or not
+	 * @throws Minz_ConfigurationException
 	 */
 	public function __construct() {
 		$this->_layout(self::LAYOUT_DEFAULT);
@@ -43,7 +43,7 @@ class Minz_View {
 	 */
 	public function change_view(string $controller_name, string $action_name): void {
 		Minz_Log::warning('Minz_View::change_view is deprecated, it will be removed in a future version. Please use Minz_View::_path instead.');
-		$this->_path($controller_name. '/' . $action_name . '.phtml');
+		$this->_path($controller_name . '/' . $action_name . '.phtml');
 	}
 
 	/**
@@ -71,9 +71,9 @@ class Minz_View {
 	 */
 	public function build(): void {
 		if ($this->layout_filename !== '') {
-			$this->buildLayout ();
+			$this->buildLayout();
 		} else {
-			$this->render ();
+			$this->render();
 		}
 	}
 
@@ -158,7 +158,7 @@ class Minz_View {
 
 	/**
 	 * Choose the current view layout.
-	 * @param string|null $layout the layout name to use, false to use no layouts.
+	 * @param string|null $layout the layout name to use, null to use no layouts.
 	 */
 	public function _layout(?string $layout): void {
 		if ($layout != null) {
@@ -206,7 +206,7 @@ class Minz_View {
 	 */
 	public static function headStyle(): string {
 		$styles = '';
-		foreach(self::$styles as $style) {
+		foreach (self::$styles as $style) {
 			$styles .= '<link rel="stylesheet" ' .
 				($style['media'] === 'all' ? '' : 'media="' . $style['media'] . '" ') .
 				'href="' . $style['url'] . '" />';
@@ -221,10 +221,13 @@ class Minz_View {
 	 * @param bool $cond Conditional comment for IE, now deprecated and ignored @deprecated
 	 */
 	public static function prependStyle(string $url, string $media = 'all', bool $cond = false): void {
-		array_unshift (self::$styles, array (
+		if ($url === '') {
+			return;
+		}
+		array_unshift(self::$styles, [
 			'url' => $url,
 			'media' => $media,
-		));
+		]);
 	}
 
 	/**
@@ -234,10 +237,13 @@ class Minz_View {
 	 * @param bool $cond Conditional comment for IE, now deprecated and ignored @deprecated
 	 */
 	public static function appendStyle(string $url, string $media = 'all', bool $cond = false): void {
-		self::$styles[] = array (
+		if ($url === '') {
+			return;
+		}
+		self::$styles[] = [
 			'url' => $url,
 			'media' => $media,
-		);
+		];
 	}
 
 	/**
@@ -299,12 +305,15 @@ class Minz_View {
 	 * @param string $id Add a script `id` attribute
 	 */
 	public static function prependScript(string $url, bool $cond = false, bool $defer = true, bool $async = true, string $id = ''): void {
-		array_unshift(self::$scripts, array (
+		if ($url === '') {
+			return;
+		}
+		array_unshift(self::$scripts, [
 			'url' => $url,
 			'defer' => $defer,
 			'async' => $async,
 			'id' => $id,
-		));
+		]);
 	}
 
 	/**
@@ -316,12 +325,15 @@ class Minz_View {
 	 * @param string $id Add a script `id` attribute
 	 */
 	public static function appendScript(string $url, bool $cond = false, bool $defer = true, bool $async = true, string $id = ''): void {
-		self::$scripts[] = array (
+		if ($url === '') {
+			return;
+		}
+		self::$scripts[] = [
 			'url' => $url,
 			'defer' => $defer,
 			'async' => $async,
 			'id' => $id,
-		);
+		];
 	}
 
 	/**
@@ -334,6 +346,7 @@ class Minz_View {
 
 	public function attributeParams(): void {
 		foreach (Minz_View::$params as $key => $value) {
+			// @phpstan-ignore property.dynamicName
 			$this->$key = $value;
 		}
 	}
