@@ -1,4 +1,6 @@
 <?php
+declare(strict_types=1);
+
 const FAVICONS_DIR = DATA_PATH . '/favicons/';
 const DEFAULT_FAVICON = PUBLIC_PATH . '/themes/icons/default_favicon.ico';
 
@@ -11,16 +13,12 @@ function isImgMime(string $content): bool {
 		return true;
 	}
 	$isImage = true;
-	try {
-		/** @var finfo $fInfo */
-		$fInfo = finfo_open(FILEINFO_MIME_TYPE);
-		/** @var string $content */
-		$content = finfo_buffer($fInfo, $content);
-		$isImage = strpos($content, 'image') !== false;
-		finfo_close($fInfo);
-	} catch (Exception $e) {
-		echo 'Caught exception: ',  $e->getMessage(), "\n";
-	}
+	/** @var finfo $fInfo */
+	$fInfo = finfo_open(FILEINFO_MIME_TYPE);
+	/** @var string $content */
+	$content = finfo_buffer($fInfo, $content);
+	$isImage = strpos($content, 'image') !== false;
+	finfo_close($fInfo);
 	return $isImage;
 }
 
@@ -40,12 +38,12 @@ function downloadHttp(string &$url, array $curlOptions = []): string {
 			CURLOPT_MAXREDIRS => 10,
 			CURLOPT_FOLLOWLOCATION => true,
 			CURLOPT_ENCODING => '',	//Enable all encodings
+			//CURLOPT_VERBOSE => 1,	// To debug sent HTTP headers
 		]);
 
 	FreshRSS_Context::initSystem();
-	$system_conf = FreshRSS_Context::$system_conf;
-	if (isset($system_conf)) {
-		curl_setopt_array($ch, $system_conf->curl_options);
+	if (FreshRSS_Context::hasSystemConf()) {
+		curl_setopt_array($ch, FreshRSS_Context::systemConf()->curl_options);
 	}
 
 	curl_setopt_array($ch, $curlOptions);
@@ -68,34 +66,45 @@ function downloadHttp(string &$url, array $curlOptions = []): string {
 function searchFavicon(string &$url): string {
 	$dom = new DOMDocument();
 	$html = downloadHttp($url);
-	if ($html != '' && @$dom->loadHTML($html, LIBXML_NONET | LIBXML_NOERROR | LIBXML_NOWARNING)) {
-		$rels = array('shortcut icon', 'icon');
-		$links = $dom->getElementsByTagName('link');
-		foreach ($rels as $rel) {
-			foreach ($links as $link) {
-				if ($link->hasAttribute('rel') && $link->hasAttribute('href') &&
-					strtolower(trim($link->getAttribute('rel'))) === $rel) {
-					$href = trim($link->getAttribute('href'));
-					if (substr($href, 0, 2) === '//') {
-						// Case of protocol-relative URLs
-						if (preg_match('%^(https?:)//%i', $url, $matches) === 1) {
-							$href = $matches[1] . $href;
-						} else {
-							$href = 'https:' . $href;
-						}
-					}
-					$checkUrl = checkUrl($href, false);
-					if (is_string($checkUrl)) {
-						$href = SimplePie_IRI::absolutize($url, $href);
-					}
-					$favicon = downloadHttp($href, array(
-							CURLOPT_REFERER => $url,
-						));
-					if (isImgMime($favicon)) {
-						return $favicon;
-					}
-				}
-			}
+
+	if ($html == '' || !@$dom->loadHTML($html, LIBXML_NONET | LIBXML_NOERROR | LIBXML_NOWARNING)) {
+		return '';
+	}
+
+	$xpath = new DOMXPath($dom);
+	$links = $xpath->query('//link[@href][translate(@rel, "ABCDEFGHIJKLMNOPQRSTUVWXYZ", "abcdefghijklmnopqrstuvwxyz")="shortcut icon"'
+		. ' or translate(@rel, "ABCDEFGHIJKLMNOPQRSTUVWXYZ", "abcdefghijklmnopqrstuvwxyz")="icon"]');
+
+	if (!($links instanceof DOMNodeList)) {
+		return '';
+	}
+
+	// Use the base element for relative paths, if there is one
+	$baseElements = $xpath->query('//base[@href]');
+	$baseElement = ($baseElements !== false && $baseElements->length > 0) ? $baseElements->item(0) : null;
+	$baseUrl = ($baseElement instanceof DOMElement) ? $baseElement->getAttribute('href') : $url;
+
+	foreach ($links as $link) {
+		if (!$link instanceof DOMElement) {
+			continue;
+		}
+		$href = trim($link->getAttribute('href'));
+		$urlParts = parse_url($url);
+
+		// Handle protocol-relative URLs by adding the current URL's scheme
+		if (substr($href, 0, 2) === '//') {
+			$href = ($urlParts['scheme'] ?? 'https') . ':' . $href;
+		}
+
+		$href = SimplePie_IRI::absolutize($baseUrl, $href);
+		if ($href == false) {
+			return '';
+		}
+
+		$iri = $href->get_iri();
+		$favicon = downloadHttp($iri, array(CURLOPT_REFERER => $url));
+		if (isImgMime($favicon)) {
+			return $favicon;
 		}
 	}
 	return '';
@@ -123,3 +132,16 @@ function download_favicon(string $url, string $dest): bool {
 	return ($favicon != '' && file_put_contents($dest, $favicon) > 0) ||
 		@copy(DEFAULT_FAVICON, $dest);
 }
+
+function contentType(string $ico): string {
+	$ico_content_type = 'image/x-icon';
+	if (function_exists('mime_content_type')) {
+		$ico_content_type = mime_content_type($ico) ?: $ico_content_type;
+	}
+	switch ($ico_content_type) {
+		case 'image/svg':
+			$ico_content_type = 'image/svg+xml';
+			break;
+	}
+	return $ico_content_type;
+}
