@@ -1,8 +1,9 @@
 <?php
+declare(strict_types=1);
 require(__DIR__ . '/../../constants.php');
 require(LIB_PATH . '/lib_rss.php');	//Includes class autoloader
 
-const MAX_PAYLOAD = 3145728;
+const MAX_PAYLOAD = 3_145_728;
 
 header('Content-Type: text/plain; charset=UTF-8');
 header('X-Content-Type-Options: nosniff');
@@ -10,11 +11,11 @@ header('X-Content-Type-Options: nosniff');
 $ORIGINAL_INPUT = file_get_contents('php://input', false, null, 0, MAX_PAYLOAD) ?: '';
 
 FreshRSS_Context::initSystem();
-if (FreshRSS_Context::$system_conf == null) {
+if (!FreshRSS_Context::hasSystemConf()) {
 	header('HTTP/1.1 500 Internal Server Error');
 	die('Invalid system init!');
 }
-FreshRSS_Context::$system_conf->auth_type = 'none';	// avoid necessity to be logged in (not saved!)
+FreshRSS_Context::systemConf()->auth_type = 'none';	// avoid necessity to be logged in (not saved!)
 
 //Minz_Log::debug(print_r(array('_SERVER' => $_SERVER, '_GET' => $_GET, '_POST' => $_POST, 'INPUT' => $ORIGINAL_INPUT), true), PSHB_LOG);
 
@@ -29,8 +30,9 @@ if ($canonical === false) {
 	if (!empty($_REQUEST['hub_mode']) && $_REQUEST['hub_mode'] === 'unsubscribe') {
 		Minz_Log::warning('Warning: Accept unknown unsubscribe', PSHB_LOG);
 		header('Connection: close');
-		exit(isset($_REQUEST['hub_challenge']) ? $_REQUEST['hub_challenge'] : '');
+		exit($_REQUEST['hub_challenge'] ?? '');
 	}
+	// https://github.com/w3c/websub/issues/106 , https://w3c.github.io/websub/#content-distribution
 	header('HTTP/1.1 410 Gone');
 	Minz_Log::warning('Warning: Feed key not found!: ' . $key, PSHB_LOG);
 	die('Feed key not found!');
@@ -65,7 +67,7 @@ if (empty($users)) {
 }
 
 if (!empty($_REQUEST['hub_mode']) && $_REQUEST['hub_mode'] === 'subscribe') {
-	$leaseSeconds = empty($_REQUEST['hub_lease_seconds']) ? 0 : intval($_REQUEST['hub_lease_seconds']);
+	$leaseSeconds = empty($_REQUEST['hub_lease_seconds']) ? 0 : (int)$_REQUEST['hub_lease_seconds'];
 	if ($leaseSeconds > 60) {
 		$hubJson['lease_end'] = time() + $leaseSeconds;
 	} else {
@@ -77,13 +79,13 @@ if (!empty($_REQUEST['hub_mode']) && $_REQUEST['hub_mode'] === 'subscribe') {
 	}
 	file_put_contents('./!hub.json', json_encode($hubJson));
 	header('Connection: close');
-	exit(isset($_REQUEST['hub_challenge']) ? $_REQUEST['hub_challenge'] : '');
+	exit($_REQUEST['hub_challenge'] ?? '');
 }
 
 if (!empty($_REQUEST['hub_mode']) && $_REQUEST['hub_mode'] === 'unsubscribe') {
 	if (empty($hubJson['lease_end']) || $hubJson['lease_end'] < time()) {
 		header('Connection: close');
-		exit(isset($_REQUEST['hub_challenge']) ? $_REQUEST['hub_challenge'] : '');
+		exit($_REQUEST['hub_challenge'] ?? '');
 	} else {
 		header('HTTP/1.1 422 Unprocessable Entity');
 		die('We did not ask to unsubscribe!');
@@ -101,7 +103,7 @@ $simplePie->init();
 unset($ORIGINAL_INPUT);
 
 $links = $simplePie->get_links('self');
-$self = isset($links[0]) ? $links[0] : null;
+$self = $links[0] ?? null;
 
 if ($self !== $canonical) {
 	//header('HTTP/1.1 422 Unprocessable Entity');
@@ -124,15 +126,15 @@ foreach ($users as $userFilename) {
 
 	try {
 		FreshRSS_Context::initUser($username);
-		if (FreshRSS_Context::$user_conf == null || !FreshRSS_Context::$user_conf->enabled) {
+		if (!FreshRSS_Context::hasUserConf() || !FreshRSS_Context::userConf()->enabled) {
 			Minz_Log::warning('FreshRSS skip disabled user ' . $username);
 			continue;
 		}
-		Minz_ExtensionManager::enableByList(FreshRSS_Context::$user_conf->extensions_enabled, 'user');
-		Minz_Translate::reset(FreshRSS_Context::$user_conf->language);
+		Minz_ExtensionManager::enableByList(FreshRSS_Context::userConf()->extensions_enabled, 'user');
+		Minz_Translate::reset(FreshRSS_Context::userConf()->language);
 
-		list($updated_feeds, $feed, $nb_new_articles) = FreshRSS_feed_Controller::actualizeFeed(0, $self, false, $simplePie);
-		if ($updated_feeds > 0 || $feed != false) {
+		[$nbUpdatedFeeds, ] = FreshRSS_feed_Controller::actualizeFeedsAndCommit(null, $self, null, $simplePie);
+		if ($nbUpdatedFeeds > 0) {
 			$nb++;
 		} else {
 			Minz_Log::warning('Warning: User ' . $username . ' does not subscribe anymore to ' . $self, PSHB_LOG);
